@@ -1,26 +1,18 @@
 import json
-from functools import partial
+from typing import Any
 
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.common.parse_args import (
+    Argv,
+    InputModifiers,
+    KeyValueParser,
     group_by_keywords,
-    prepare_options,
 )
 from pcs.cli.reports.output import deprecation_warning
 from pcs.common.str_tools import indent
 
-parse_cmd_sections = partial(group_by_keywords, implicit_first_group_key="main")
 
-
-def ensure_only_allowed_options(parameter_dict, allowed_list):
-    for arg, value in parameter_dict.items():
-        if arg not in allowed_list:
-            raise CmdLineInputError(
-                "Unexpected parameter '{0}={1}'".format(arg, value)
-            )
-
-
-def alert_add(lib, argv, modifiers):
+def alert_add(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file (in lib wrapper)
@@ -29,20 +21,23 @@ def alert_add(lib, argv, modifiers):
     if not argv:
         raise CmdLineInputError()
 
-    sections = parse_cmd_sections(argv, set(["options", "meta"]))
-    main_args = prepare_options(sections["main"])
-    ensure_only_allowed_options(main_args, ["id", "description", "path"])
+    sections = group_by_keywords(
+        argv, set(["options", "meta"]), implicit_first_keyword="main"
+    )
+    parser = KeyValueParser(sections.get_args_flat("main"))
+    parser.check_allowed_keys(["id", "description", "path"])
+    main_args = parser.get_unique()
 
     lib.alert.create_alert(
         main_args.get("id", None),
         main_args.get("path", None),
-        prepare_options(sections["options"]),
-        prepare_options(sections["meta"]),
+        KeyValueParser(sections.get_args_flat("options")).get_unique(),
+        KeyValueParser(sections.get_args_flat("meta")).get_unique(),
         main_args.get("description", None),
     )
 
 
-def alert_update(lib, argv, modifiers):
+def alert_update(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file (in lib wrapper)
@@ -53,20 +48,23 @@ def alert_update(lib, argv, modifiers):
 
     alert_id = argv[0]
 
-    sections = parse_cmd_sections(argv[1:], set(["options", "meta"]))
-    main_args = prepare_options(sections["main"])
-    ensure_only_allowed_options(main_args, ["description", "path"])
+    sections = group_by_keywords(
+        argv[1:], set(["options", "meta"]), implicit_first_keyword="main"
+    )
+    parser = KeyValueParser(sections.get_args_flat("main"))
+    parser.check_allowed_keys(["description", "path"])
+    main_args = parser.get_unique()
 
     lib.alert.update_alert(
         alert_id,
         main_args.get("path", None),
-        prepare_options(sections["options"]),
-        prepare_options(sections["meta"]),
+        KeyValueParser(sections.get_args_flat("options")).get_unique(),
+        KeyValueParser(sections.get_args_flat("meta")).get_unique(),
         main_args.get("description", None),
     )
 
 
-def alert_remove(lib, argv, modifiers):
+def alert_remove(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file (in lib wrapper)
@@ -78,7 +76,7 @@ def alert_remove(lib, argv, modifiers):
     lib.alert.remove_alert(argv)
 
 
-def recipient_add(lib, argv, modifiers):
+def recipient_add(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file (in lib wrapper)
@@ -90,22 +88,25 @@ def recipient_add(lib, argv, modifiers):
 
     alert_id = argv[0]
 
-    sections = parse_cmd_sections(argv[1:], set(["options", "meta"]))
-    main_args = prepare_options(sections["main"])
-    ensure_only_allowed_options(main_args, ["description", "id", "value"])
+    sections = group_by_keywords(
+        argv[1:], set(["options", "meta"]), implicit_first_keyword="main"
+    )
+    parser = KeyValueParser(sections.get_args_flat("main"))
+    parser.check_allowed_keys(["description", "id", "value"])
+    main_args = parser.get_unique()
 
     lib.alert.add_recipient(
         alert_id,
         main_args.get("value", None),
-        prepare_options(sections["options"]),
-        prepare_options(sections["meta"]),
+        KeyValueParser(sections.get_args_flat("options")).get_unique(),
+        KeyValueParser(sections.get_args_flat("meta")).get_unique(),
         recipient_id=main_args.get("id", None),
         description=main_args.get("description", None),
         allow_same_value=modifiers.get("--force"),
     )
 
 
-def recipient_update(lib, argv, modifiers):
+def recipient_update(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file (in lib wrapper)
@@ -117,21 +118,24 @@ def recipient_update(lib, argv, modifiers):
 
     recipient_id = argv[0]
 
-    sections = parse_cmd_sections(argv[1:], set(["options", "meta"]))
-    main_args = prepare_options(sections["main"])
-    ensure_only_allowed_options(main_args, ["description", "value"])
+    sections = group_by_keywords(
+        argv[1:], set(["options", "meta"]), implicit_first_keyword="main"
+    )
+    parser = KeyValueParser(sections.get_args_flat("main"))
+    parser.check_allowed_keys(["description", "value"])
+    main_args = parser.get_unique()
 
     lib.alert.update_recipient(
         recipient_id,
-        prepare_options(sections["options"]),
-        prepare_options(sections["meta"]),
+        KeyValueParser(sections.get_args_flat("options")).get_unique(),
+        KeyValueParser(sections.get_args_flat("meta")).get_unique(),
         recipient_value=main_args.get("value", None),
         description=main_args.get("description", None),
         allow_same_value=modifiers.get("--force"),
     )
 
 
-def recipient_remove(lib, argv, modifiers):
+def recipient_remove(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file (in lib wrapper)
@@ -159,19 +163,13 @@ def _nvset_to_str(nvset_obj):
 def __description_attributes_to_str(obj):
     output = []
     if obj.get("description"):
-        output.append("Description: {desc}".format(desc=obj["description"]))
+        output.append(f"Description: {obj['description']}")
     if obj.get("instance_attributes"):
-        output.append(
-            "Options: {attributes}".format(
-                attributes=_nvset_to_str(obj["instance_attributes"])
-            )
-        )
+        attributes = _nvset_to_str(obj["instance_attributes"])
+        output.append(f"Options: {attributes}")
     if obj.get("meta_attributes"):
-        output.append(
-            "Meta options: {attributes}".format(
-                attributes=_nvset_to_str(obj["meta_attributes"])
-            )
-        )
+        attributes = _nvset_to_str(obj["meta_attributes"])
+        output.append(f"Meta options: {attributes}")
     return output
 
 
@@ -187,22 +185,16 @@ def _alert_to_str(alert):
         content.append("Recipients:")
         content.extend(indent(recipients, 1))
 
-    return [
-        "Alert: {alert_id} (path={path})".format(
-            alert_id=alert["id"], path=alert["path"]
-        )
-    ] + indent(content, 1)
+    return [f"Alert: {alert['id']} (path={alert['path']})"] + indent(content, 1)
 
 
 def _recipient_to_str(recipient):
     return [
-        "Recipient: {id} (value={value})".format(
-            value=recipient["value"], id=recipient["id"]
-        )
+        f"Recipient: {recipient['id']} (value={recipient['value']})"
     ] + indent(__description_attributes_to_str(recipient), 1)
 
 
-def print_alert_show(lib, argv, modifiers):
+def print_alert_show(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     deprecation_warning(
         "This command is deprecated and will be removed. "
         "Please use 'pcs alert config' instead."
@@ -210,7 +202,7 @@ def print_alert_show(lib, argv, modifiers):
     return print_alert_config(lib, argv, modifiers)
 
 
-def print_alert_config(lib, argv, modifiers):
+def print_alert_config(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file (in lib wrapper)
@@ -223,7 +215,7 @@ def print_alert_config(lib, argv, modifiers):
         print("\n".join(lines))
 
 
-def alert_config_lines(lib):
+def alert_config_lines(lib: Any) -> list[str]:
     lines = []
     alert_list = lib.alert.get_all_alerts()
     if alert_list:
@@ -233,7 +225,9 @@ def alert_config_lines(lib):
     return lines
 
 
-def print_alerts_in_json(lib, argv, modifiers):
+def print_alerts_in_json(
+    lib: Any, argv: Argv, modifiers: InputModifiers
+) -> None:
     """
     This is used only by pcsd, will be removed in new architecture
 
