@@ -1,8 +1,13 @@
-from pcs.cli.common import parse_args
 from pcs.cli.common.errors import CmdLineInputError
+from pcs.cli.common.parse_args import (
+    Argv,
+    KeyValueParser,
+)
 
 
-def separate_tail_option_candidates(arg_list):
+def separate_tail_option_candidates(
+    arg_list: Argv,
+) -> tuple[list[str], list[str]]:
     for i, arg in enumerate(arg_list):
         if "=" in arg:
             return arg_list[:i], arg_list[i:]
@@ -10,7 +15,7 @@ def separate_tail_option_candidates(arg_list):
     return arg_list, []
 
 
-def parse_add(arg_list):
+def parse_add(arg_list: Argv) -> tuple[str, str, str, dict[str, str]]:
     info, option_candidates = separate_tail_option_candidates(arg_list)
 
     if not info:
@@ -35,5 +40,5 @@ def parse_add(arg_list):
         ticket,
         resource_id,
         resource_role,
-        parse_args.prepare_options(option_candidates),
+        KeyValueParser(option_candidates).get_unique(),
     )
