@@ -58,7 +58,6 @@ class CliReportMessage:
 
 
 class CliReportMessageCustom(CliReportMessage):
-    # pylint: disable=no-member
     _obj: item.ReportItemMessage
 
     def __init__(self, dto_obj: dto.ReportItemMessageDto) -> None:
@@ -311,6 +310,33 @@ class CorosyncNodeConflictCheckSkipped(CliReportMessageCustom):
         ).format(reason=_skip_reason_to_string(self._obj.reason_type))
 
 
+class CorosyncNotRunningCheckFinishedRunning(CliReportMessageCustom):
+    _obj: messages.CorosyncNotRunningCheckFinishedRunning
+
+    @property
+    def message(self) -> str:
+        return self._obj.message + (
+            """ Run "pcs cluster stop {node_list}" to stop the {node} or """
+            """"pcs cluster stop --all" to stop the whole cluster."""
+        ).format(
+            node=format_plural(self._obj.node_list, "node"),
+            node_list=format_list(self._obj.node_list, separator=" "),
+        )
+
+
+class CorosyncQuorumAtbWillBeEnabledDueToSbdClusterIsRunning(
+    CliReportMessageCustom
+):
+    _obj: messages.CorosyncQuorumAtbWillBeEnabledDueToSbdClusterIsRunning
+
+    @property
+    def message(self) -> str:
+        return self._obj.message + (
+            " Use commands 'pcs cluster stop --all', 'pcs quorum update "
+            "auto_tie_breaker=1', 'pcs cluster start --all'."
+        )
+
+
 class LiveEnvironmentNotConsistent(CliReportMessageCustom):
     _obj: messages.LiveEnvironmentNotConsistent
 
@@ -592,6 +618,20 @@ class BoothUnsupportedOptionEnableAuthfile(CliReportMessageCustom):
         )
 
 
+class ResourceMoveAutocleanSimulationFailure(CliReportMessageCustom):
+    _obj: messages.ResourceMoveAutocleanSimulationFailure
+
+    @property
+    def message(self) -> str:
+        if not self._obj.move_constraint_left_in_cib:
+            return self._obj.message
+        node = format_optional(self._obj.node, " {}")
+        return (
+            f"{self._obj.message} Run 'pcs resource clear "
+            f"{self._obj.resource_id}{node}' to remove the constraint."
+        )
+
+
 def _create_report_msg_map() -> Dict[str, type]:
     result: Dict[str, type] = {}
     for report_msg_cls in get_all_subclasses(CliReportMessageCustom):
