@@ -4,10 +4,9 @@ from pcs import (
 )
 from pcs.cli.common.routing import create_router
 
-
 alert_cmd = create_router(
     {
-        "help": lambda lib, argv, modifiers: usage.alert(argv),
+        "help": lambda lib, argv, modifiers: print(usage.alert(argv)),
         "create": alert.alert_add,
         "update": alert.alert_update,
         "delete": alert.alert_remove,
@@ -18,7 +17,9 @@ alert_cmd = create_router(
         "show": alert.print_alert_show,
         "recipient": create_router(
             {
-                "help": lambda lib, argv, modifiers: usage.alert(["recipient"]),
+                "help": lambda lib, argv, modifiers: print(
+                    usage.alert(["recipient"])
+                ),
                 "add": alert.recipient_add,
                 "update": alert.recipient_update,
                 "delete": alert.recipient_remove,
