@@ -9,14 +9,16 @@ from pcs import (
     usage,
 )
 from pcs.cli.common.errors import CmdLineInputError
-from pcs.cli.common.parse_args import InputModifiers
+from pcs.cli.common.parse_args import (
+    Argv,
+    InputModifiers,
+)
 from pcs.cli.common.routing import create_router
 from pcs.cli.reports.output import deprecation_warning
-from pcs.common.types import StringSequence
 from pcs.utils import exit_on_cmdline_input_error
 
 
-def certkey(lib: Any, argv: StringSequence, modifiers: InputModifiers) -> None:
+def certkey(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     deprecation_warning(
         "This command is deprecated and will be removed. "
         "Please use 'pcs pcsd certkey' instead."
@@ -27,9 +29,7 @@ def certkey(lib: Any, argv: StringSequence, modifiers: InputModifiers) -> None:
         return exit_on_cmdline_input_error(e, "pcsd", ["certkey"])
 
 
-def pcsd_status(
-    lib: Any, argv: StringSequence, modifiers: InputModifiers
-) -> None:
+def pcsd_status(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     deprecation_warning(
         "This command is deprecated and will be removed. "
         "Please use 'pcs pcsd status' or 'pcs status pcsd' instead."
@@ -104,14 +104,16 @@ cluster_cmd = create_router(
                 "clear": cluster_command.node_clear,
                 "delete": cluster.node_remove,
                 "delete-guest": cluster_command.node_remove_guest,
+                # ignoring mypy errors, these functions need to be fixed, they
+                # are passing a function to pcs.lib
                 "delete-remote": cluster_command.create_node_remove_remote(
                     resource.resource_remove
-                ),
+                ),  # type:ignore
                 "remove": cluster.node_remove,
                 "remove-guest": cluster_command.node_remove_guest,
                 "remove-remote": cluster_command.create_node_remove_remote(
                     resource.resource_remove
-                ),
+                ),  # type:ignore
             },
             ["cluster", "node"],
         ),
