@@ -2,6 +2,7 @@ from typing import Any
 
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.common.parse_args import (
+    Argv,
     InputModifiers,
     group_by_keywords,
 )
@@ -10,14 +11,9 @@ from pcs.cli.reports.output import (
     print_to_stderr,
 )
 from pcs.common.str_tools import indent
-from pcs.common.types import StringSequence
 
 
-def tag_create(
-    lib: Any,
-    argv: StringSequence,
-    modifiers: InputModifiers,
-) -> None:
+def tag_create(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file
@@ -29,11 +25,7 @@ def tag_create(
     lib.tag.create(tag_id, idref_list)
 
 
-def tag_list_cmd(
-    lib: Any,
-    argv: StringSequence,
-    modifiers: InputModifiers,
-) -> None:
+def tag_list_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file
@@ -45,11 +37,7 @@ def tag_list_cmd(
     return tag_config(lib, argv, modifiers)
 
 
-def tag_config(
-    lib: Any,
-    argv: StringSequence,
-    modifiers: InputModifiers,
-) -> None:
+def tag_config(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file
@@ -66,11 +54,7 @@ def tag_config(
     print("\n".join(lines))
 
 
-def tag_remove(
-    lib: Any,
-    argv: StringSequence,
-    modifiers: InputModifiers,
-) -> None:
+def tag_remove(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file
@@ -81,11 +65,7 @@ def tag_remove(
     lib.tag.remove(argv)
 
 
-def tag_update(
-    lib: Any,
-    argv: StringSequence,
-    modifiers: InputModifiers,
-) -> None:
+def tag_update(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file
@@ -98,17 +78,13 @@ def tag_update(
     if not argv:
         raise CmdLineInputError()
     tag_id = argv[0]
-    parsed_args = group_by_keywords(
-        argv[1:],
-        ["add", "remove"],
-        keyword_repeat_allowed=False,
-        only_found_keywords=True,
+    parsed_args = group_by_keywords(argv[1:], ["add", "remove"])
+    parsed_args.ensure_unique_keywords()
+    no_add_remove_arguments = not (
+        parsed_args.has_keyword("add") or parsed_args.has_keyword("remove")
     )
-    no_add_remove_arguments = (
-        "add" not in parsed_args and "remove" not in parsed_args
-    )
-    no_add_id = "add" in parsed_args and not parsed_args["add"]
-    no_remove_id = "remove" in parsed_args and not parsed_args["remove"]
+    no_add_id = parsed_args.has_empty_keyword("add")
+    no_remove_id = parsed_args.has_empty_keyword("remove")
     if no_add_remove_arguments or no_add_id or no_remove_id:
         raise CmdLineInputError(
             show_both_usage_and_message=True,
@@ -126,8 +102,8 @@ def tag_update(
         after_adjacent = False
     lib.tag.update(
         tag_id,
-        parsed_args["add"] if "add" in parsed_args else [],
-        parsed_args["remove"] if "remove" in parsed_args else [],
+        parsed_args.get_args_flat("add"),
+        parsed_args.get_args_flat("remove"),
         adjacent_idref=adjacent_idref,
         put_after_adjacent=after_adjacent,
     )
