@@ -12,9 +12,9 @@ from typing import (
     Any,
     Callable,
     Iterable,
-    List,
     Mapping,
     Optional,
+    Union,
     cast,
 )
 
@@ -29,6 +29,13 @@ from pcs.cli.common.errors import (
     CmdLineInputError,
     raise_command_replaced,
 )
+from pcs.cli.common.parse_args import (
+    OUTPUT_FORMAT_VALUE_CMD,
+    OUTPUT_FORMAT_VALUE_JSON,
+    Argv,
+    InputModifiers,
+    KeyValueParser,
+)
 from pcs.cli.common.tools import print_to_stderr
 from pcs.cli.file import metadata as file_metadata
 from pcs.cli.reports import process_library_reports
@@ -54,6 +61,10 @@ from pcs.common.str_tools import (
     indent,
 )
 from pcs.common.tools import format_os_error
+from pcs.common.types import (
+    StringCollection,
+    StringIterable,
+)
 from pcs.lib import sbd as lib_sbd
 from pcs.lib.commands.remote_node import _destroy_pcmk_remote_env
 from pcs.lib.communication.nodes import CheckAuth
@@ -69,8 +80,6 @@ from pcs.lib.errors import LibraryError
 from pcs.lib.node import get_existing_nodes_names
 from pcs.utils import parallel_for_nodes
 
-# pylint: disable=too-many-branches, too-many-statements
-
 
 def _corosync_conf_local_cmd_call(
     corosync_conf_path: parse_args.ModifierValueType,
@@ -109,7 +118,9 @@ def _corosync_conf_local_cmd_call(
         ) from e
 
 
-def cluster_cib_upgrade_cmd(lib, argv, modifiers):
+def cluster_cib_upgrade_cmd(
+    lib: Any, argv: Argv, modifiers: InputModifiers
+) -> None:
     """
     Options:
       * -f - CIB file
@@ -121,7 +132,9 @@ def cluster_cib_upgrade_cmd(lib, argv, modifiers):
     utils.cluster_upgrade()
 
 
-def cluster_disable_cmd(lib, argv, modifiers):
+def cluster_disable_cmd(
+    lib: Any, argv: Argv, modifiers: InputModifiers
+) -> None:
     """
     Options:
       * --all - disable all cluster nodes
@@ -138,7 +151,7 @@ def cluster_disable_cmd(lib, argv, modifiers):
         disable_cluster(argv)
 
 
-def cluster_enable_cmd(lib, argv, modifiers):
+def cluster_enable_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --all - enable all cluster nodes
@@ -155,7 +168,7 @@ def cluster_enable_cmd(lib, argv, modifiers):
         enable_cluster(argv)
 
 
-def cluster_stop_cmd(lib, argv, modifiers):
+def cluster_stop_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --force - no error when possible quorum loss
@@ -184,7 +197,7 @@ def cluster_stop_cmd(lib, argv, modifiers):
         stop_cluster(argv)
 
 
-def cluster_start_cmd(lib, argv, modifiers):
+def cluster_start_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --wait
@@ -204,7 +217,7 @@ def cluster_start_cmd(lib, argv, modifiers):
         start_cluster(argv)
 
 
-def authkey_corosync(lib, argv, modifiers):
+def authkey_corosync(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --force - skip check for authkey length
@@ -227,18 +240,14 @@ def authkey_corosync(lib, argv, modifiers):
             with open(argv[0], "rb") as file:
                 corosync_authkey = file.read()
         except OSError as e:
-            utils.err(
-                "Unable to read file '{0}': {1}".format(
-                    argv[0], format_os_error(e)
-                )
-            )
+            utils.err(f"Unable to read file '{argv[0]}': {format_os_error(e)}")
     lib.cluster.corosync_authkey_change(
         corosync_authkey=corosync_authkey,
         force_flags=force_flags,
     )
 
 
-def sync_nodes(lib, argv, modifiers):
+def sync_nodes(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --request-timeout - timeout for HTTP requests
@@ -270,7 +279,7 @@ def sync_nodes(lib, argv, modifiers):
     )
 
 
-def start_cluster(argv):
+def start_cluster(argv: Argv) -> None:
     """
     Commandline options:
       * --wait
@@ -304,7 +313,7 @@ def start_cluster(argv):
         wait_for_nodes_started([], wait_timeout)
 
 
-def start_cluster_all():
+def start_cluster_all() -> None:
     """
     Commandline options:
       * --wait
@@ -333,7 +342,7 @@ def start_cluster_all():
         wait_for_nodes_started(all_nodes, wait_timeout)
 
 
-def start_cluster_nodes(nodes):
+def start_cluster_nodes(nodes: StringCollection) -> None:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP requests
@@ -359,7 +368,7 @@ def start_cluster_nodes(nodes):
         )
 
 
-def is_node_fully_started(node_status):
+def is_node_fully_started(node_status) -> bool:
     """
     Commandline options: no options
     """
@@ -371,7 +380,9 @@ def is_node_fully_started(node_status):
     )
 
 
-def wait_for_local_node_started(stop_at, interval):
+def wait_for_local_node_started(
+    stop_at: datetime.datetime, interval: float
+) -> tuple[int, str]:
     """
     Commandline options: no options
     """
@@ -389,7 +400,6 @@ def wait_for_local_node_started(stop_at, interval):
         return (
             1,
             "Unable to get node status: {0}".format(
-                # pylint: disable=no-member
                 "\n".join(
                     report_item_msg_from_dto(
                         cast(reports.ReportItemDto, item).message
@@ -400,7 +410,9 @@ def wait_for_local_node_started(stop_at, interval):
         )
 
 
-def wait_for_remote_node_started(node, stop_at, interval):
+def wait_for_remote_node_started(
+    node: str, stop_at: datetime.datetime, interval: float
+) -> tuple[int, str]:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP requests
@@ -424,7 +436,9 @@ def wait_for_remote_node_started(node, stop_at, interval):
             return 1, "Waiting timeout"
 
 
-def wait_for_nodes_started(node_list, timeout=None):
+def wait_for_nodes_started(
+    node_list: StringIterable, timeout: Optional[int] = None
+) -> None:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP request, effective only if
@@ -449,7 +463,7 @@ def wait_for_nodes_started(node_list, timeout=None):
             utils.err("unable to verify all nodes have started")
 
 
-def stop_cluster_all():
+def stop_cluster_all() -> None:
     """
     Commandline options:
       * --force - no error when possible quorum loss
@@ -470,12 +484,13 @@ def stop_cluster_all():
     stop_cluster_nodes(all_nodes)
 
 
-def stop_cluster_nodes(nodes):
+def stop_cluster_nodes(nodes: StringCollection) -> None:
     """
     Commandline options:
       * --force - no error when possible quorum loss
       * --request-timeout - timeout for HTTP requests
     """
+    # pylint: disable=too-many-branches
     all_nodes, report_list = get_existing_nodes_names(
         utils.get_corosync_conf_facade()
     )
@@ -553,7 +568,7 @@ def stop_cluster_nodes(nodes):
         utils.err("unable to stop all nodes")
 
 
-def enable_cluster(argv):
+def enable_cluster(argv: Argv) -> None:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP requests, effective only if at
@@ -566,10 +581,10 @@ def enable_cluster(argv):
     try:
         utils.enableServices()
     except LibraryError as e:
-        process_library_reports(e.args)
+        process_library_reports(list(e.args))
 
 
-def disable_cluster(argv):
+def disable_cluster(argv: Argv) -> None:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP requests, effective only if at
@@ -582,10 +597,10 @@ def disable_cluster(argv):
     try:
         utils.disableServices()
     except LibraryError as e:
-        process_library_reports(e.args)
+        process_library_reports(list(e.args))
 
 
-def enable_cluster_all():
+def enable_cluster_all() -> None:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP requests
@@ -605,7 +620,7 @@ def enable_cluster_all():
     enable_cluster_nodes(all_nodes)
 
 
-def disable_cluster_all():
+def disable_cluster_all() -> None:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP requests
@@ -625,7 +640,7 @@ def disable_cluster_all():
     disable_cluster_nodes(all_nodes)
 
 
-def enable_cluster_nodes(nodes):
+def enable_cluster_nodes(nodes: StringIterable) -> None:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP requests
@@ -635,7 +650,7 @@ def enable_cluster_nodes(nodes):
         utils.err("unable to enable all nodes\n" + "\n".join(error_list))
 
 
-def disable_cluster_nodes(nodes):
+def disable_cluster_nodes(nodes: StringIterable) -> None:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP requests
@@ -645,7 +660,7 @@ def disable_cluster_nodes(nodes):
         utils.err("unable to disable all nodes\n" + "\n".join(error_list))
 
 
-def destroy_cluster(argv):
+def destroy_cluster(argv: Argv) -> None:
     """
     Commandline options:
       * --request-timeout - timeout for HTTP requests
@@ -668,7 +683,7 @@ def destroy_cluster(argv):
             )
 
 
-def stop_cluster(argv):
+def stop_cluster(argv: Argv) -> None:
     """
     Commandline options:
       * --force - no error when possible quorum loss
@@ -716,7 +731,7 @@ def stop_cluster(argv):
         stop_cluster_corosync()
 
 
-def stop_cluster_pacemaker():
+def stop_cluster_pacemaker() -> None:
     """
     Commandline options: no options
     """
@@ -724,7 +739,7 @@ def stop_cluster_pacemaker():
     utils.stop_service("pacemaker")
 
 
-def stop_cluster_corosync():
+def stop_cluster_corosync() -> None:
     """
     Commandline options: no options
     """
@@ -737,7 +752,7 @@ def stop_cluster_corosync():
         utils.stop_service(service)
 
 
-def kill_cluster(lib, argv, modifiers):
+def kill_cluster(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options: no options
     """
@@ -754,7 +769,7 @@ def kill_cluster(lib, argv, modifiers):
 #        sys.exit(1)
 
 
-def kill_local_cluster_services():
+def kill_local_cluster_services() -> tuple[str, int]:
     """
     Commandline options: no options
     """
@@ -774,17 +789,19 @@ def kill_local_cluster_services():
         "corosync-qdevice",
         "corosync",
     ]
-    return utils.run([settings.killall_executable, "-9"] + all_cluster_daemons)
+    return utils.run([settings.killall_exec, "-9"] + all_cluster_daemons)
 
 
-def cluster_push(lib, argv, modifiers):
+def cluster_push(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --wait
       * --config - push only configuration section of CIB
       * -f - CIB file
     """
-    # pylint: disable=too-many-locals,
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
     del lib
     modifiers.ensure_only_supported("--wait", "--config", "-f")
     if len(argv) > 2:
@@ -832,7 +849,7 @@ def cluster_push(lib, argv, modifiers):
     if diff_against:
         runner = utils.cmd_runner()
         command = [
-            settings.crm_diff,
+            settings.crm_diff_exec,
             "--original",
             diff_against,
             "--new",
@@ -853,7 +870,7 @@ def cluster_push(lib, argv, modifiers):
             sys.exit(0)
 
         command = [
-            settings.cibadmin,
+            settings.cibadmin_exec,
             "--patch",
             "--xml-pipe",
         ]
@@ -896,13 +913,14 @@ def cluster_push(lib, argv, modifiers):
         utils.err("\n".join(msg).strip())
 
 
-def cluster_edit(lib, argv, modifiers):
+def cluster_edit(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --config - edit configuration section of CIB
       * -f - CIB file
       * --wait
     """
+    # pylint: disable=too-many-branches
     modifiers.ensure_only_supported("--config", "--wait", "-f")
     if "EDITOR" in os.environ:
         if len(argv) > 1:
@@ -953,12 +971,13 @@ def cluster_edit(lib, argv, modifiers):
         utils.err("$EDITOR environment variable is not set")
 
 
-def get_cib(lib, argv, modifiers):
+def get_cib(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --config show configuration section of CIB
       * -f - CIB file
     """
+    # pylint: disable=too-many-branches
     del lib
     modifiers.ensure_only_supported("--config", "-f")
     if len(argv) > 2:
@@ -1053,7 +1072,9 @@ class RemoteAddNodes(RunRemotelyBase):
         return self._success
 
 
-def node_add_outside_cluster(lib, argv, modifiers):
+def node_add_outside_cluster(
+    lib: Any, argv: Argv, modifiers: InputModifiers
+) -> None:
     """
     Options:
       * --wait - wait until new node will start up, effective only when --start
@@ -1120,7 +1141,7 @@ def node_add_outside_cluster(lib, argv, modifiers):
         raise LibraryError()
 
 
-def node_remove(lib, argv, modifiers):
+def node_remove(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --force - continue even though the action may cause qourum loss
@@ -1144,11 +1165,14 @@ def node_remove(lib, argv, modifiers):
     lib.cluster.remove_nodes(argv, force_flags=force_flags)
 
 
-def cluster_uidgid(lib, argv, modifiers, silent_list=False):
+def cluster_uidgid(
+    lib: Any, argv: Argv, modifiers: InputModifiers, silent_list: bool = False
+) -> None:
     """
     Options: no options
     """
-    # pylint: disable=too-many-locals,
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
     del lib
     modifiers.ensure_only_supported()
     if not argv:
@@ -1215,7 +1239,9 @@ def cluster_uidgid(lib, argv, modifiers, silent_list=False):
         raise CmdLineInputError()
 
 
-def cluster_get_corosync_conf(lib, argv, modifiers):
+def cluster_get_corosync_conf(
+    lib: Any, argv: Argv, modifiers: InputModifiers
+) -> None:
     """
     Options:
       * --request-timeout - timeout for HTTP requests, effetive only when at
@@ -1238,7 +1264,7 @@ def cluster_get_corosync_conf(lib, argv, modifiers):
         print(output.rstrip())
 
 
-def cluster_reload(lib, argv, modifiers):
+def cluster_reload(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options: no options
     """
@@ -1255,13 +1281,14 @@ def cluster_reload(lib, argv, modifiers):
 
 # Completely tear down the cluster & remove config files
 # Code taken from cluster-clean script in pacemaker
-def cluster_destroy(lib, argv, modifiers):
+def cluster_destroy(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --all - destroy cluster on all cluster nodes => destroy whole cluster
       * --request-timeout - timeout of HTTP requests, effective only with --all
     """
-    # pylint: disable=bare-except
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-statements
     del lib
     modifiers.ensure_only_supported("--all", "--request-timeout", "--force")
     if argv:
@@ -1274,7 +1301,7 @@ def cluster_destroy(lib, argv, modifiers):
         if not utils.get_continue_confirmation_or_force(
             "This would kill all cluster processes and then PERMANENTLY remove "
             "cluster state and configuration",
-            modifiers.get("--force"),
+            bool(modifiers.get("--force")),
         ):
             return
     if modifiers.get("--all"):
@@ -1316,7 +1343,7 @@ def cluster_destroy(lib, argv, modifiers):
                         allow_fails=True,
                     )
             except LibraryError as e:
-                process_library_reports(e.args)
+                process_library_reports(list(e.args))
 
         # destroy full-stack nodes
         destroy_cluster(corosync_nodes)
@@ -1333,6 +1360,7 @@ def cluster_destroy(lib, argv, modifiers):
         kill_local_cluster_services()
         try:
             utils.disableServices()
+        # pylint: disable=bare-except
         except:
             # previously errors were suppressed in here, let's keep it that way
             # for now
@@ -1342,6 +1370,7 @@ def cluster_destroy(lib, argv, modifiers):
             service_manager.disable(
                 lib_sbd.get_sbd_service_name(service_manager)
             )
+        # pylint: disable=bare-except
         except:
             # it's not a big deal if sbd disable fails
             pass
@@ -1349,7 +1378,7 @@ def cluster_destroy(lib, argv, modifiers):
         print_to_stderr("Removing all cluster configuration files...")
         dummy_output, dummy_retval = utils.run(
             [
-                settings.rm_executable,
+                settings.rm_exec,
                 "-f",
                 settings.corosync_conf_file,
                 settings.corosync_authkey_file,
@@ -1369,12 +1398,12 @@ def cluster_destroy(lib, argv, modifiers):
         for name in state_files:
             dummy_output, dummy_retval = utils.run(
                 [
-                    settings.find_executable,
+                    settings.find_exec,
                     settings.pacemaker_local_state_dir,
                     "-name",
                     name,
                     "-exec",
-                    settings.rm_executable,
+                    settings.rm_exec,
                     "-f",
                     "{}",
                     ";",
@@ -1382,13 +1411,14 @@ def cluster_destroy(lib, argv, modifiers):
             )
         try:
             qdevice_net.client_destroy()
+        # pylint: disable=bare-except
         except:
             # errors from deleting other files are suppressed as well
             # we do not want to fail if qdevice was not set up
             pass
 
 
-def cluster_verify(lib, argv, modifiers):
+def cluster_verify(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * -f - CIB file
@@ -1401,13 +1431,14 @@ def cluster_verify(lib, argv, modifiers):
     lib.cluster.verify(verbose=modifiers.get("--full"))
 
 
-def cluster_report(lib, argv, modifiers):
+def cluster_report(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --force - overwrite existing file
       * --from - timestamp
       * --to - timestamp
     """
+    # pylint: disable=too-many-branches
     del lib
     modifiers.ensure_only_supported("--force", "--from", "--to")
     if len(argv) != 1:
@@ -1431,16 +1462,16 @@ def cluster_report(lib, argv, modifiers):
 
     crm_report_opts.append("-f")
     if modifiers.is_specified("--from"):
-        crm_report_opts.append(modifiers.get("--from"))
+        crm_report_opts.append(str(modifiers.get("--from")))
         if modifiers.is_specified("--to"):
             crm_report_opts.append("-t")
-            crm_report_opts.append(modifiers.get("--to"))
+            crm_report_opts.append(str(modifiers.get("--to")))
     else:
         yesterday = datetime.datetime.now() - datetime.timedelta(1)
         crm_report_opts.append(yesterday.strftime("%Y-%m-%d %H:%M"))
 
     crm_report_opts.append(outfile)
-    output, retval = utils.run([settings.crm_report] + crm_report_opts)
+    output, retval = utils.run([settings.crm_report_exec] + crm_report_opts)
     if retval != 0 and (
         "ERROR: Cannot determine nodes; specify --nodes or --single-node"
         in output
@@ -1471,13 +1502,14 @@ def cluster_report(lib, argv, modifiers):
 
 
 def send_local_configs(
-    node_name_list, clear_local_cluster_permissions=False, force=False
-):
+    node_name_list: StringIterable,
+    clear_local_cluster_permissions: bool = False,
+    force: bool = False,
+) -> list[str]:
     """
     Commandline options:
       * --request-timeout - timeout of HTTP requests
     """
-    # pylint: disable=bare-except
     pcsd_data = {
         "nodes": node_name_list,
         "force": force,
@@ -1500,6 +1532,7 @@ def send_local_configs(
                     err_msgs.append(
                         "Unable to set pcsd configs on {0}".format(node_name)
                     )
+        # pylint: disable=bare-except
         except:
             err_msgs.append("Unable to communicate with pcsd")
     else:
@@ -1507,7 +1540,7 @@ def send_local_configs(
     return err_msgs
 
 
-def cluster_auth_cmd(lib, argv, modifiers):
+def cluster_auth_cmd(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --corosync_conf - corosync.conf file
@@ -1515,7 +1548,8 @@ def cluster_auth_cmd(lib, argv, modifiers):
       * -u - username
       * -p - password
     """
-    # pylint: disable=too-many-locals,
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
     del lib
     modifiers.ensure_only_supported(
         "--corosync_conf", "--request-timeout", "-u", "-p"
@@ -1592,28 +1626,32 @@ def cluster_auth_cmd(lib, argv, modifiers):
 
 
 def _parse_node_options(
-    node, options, additional_options=(), additional_repeatable_options=()
-):
+    node: str,
+    options: Argv,
+    additional_options: StringCollection = (),
+    additional_repeatable_options: StringCollection = (),
+) -> dict[str, Union[str, list[str]]]:
     """
     Commandline options: no options
     """
-    # pylint: disable=invalid-name
-    ADDR_OPT_KEYWORD = "addr"
+    ADDR_OPT_KEYWORD = "addr"  # pylint: disable=invalid-name
     supported_options = {ADDR_OPT_KEYWORD} | set(additional_options)
     repeatable_options = {ADDR_OPT_KEYWORD} | set(additional_repeatable_options)
-    parsed_options = parse_args.prepare_options(options, repeatable_options)
-    unknown_options = set(parsed_options.keys()) - supported_options
+    parser = KeyValueParser(options, repeatable_options)
+    parsed_unique = parser.get_unique()
+    parsed_repeatable = parser.get_repeatable()
+    unknown_options = (
+        set(parsed_unique.keys()) | set(parsed_repeatable)
+    ) - supported_options
     if unknown_options:
         raise CmdLineInputError(
-            "Unknown options '{}' for node '{}'".format(
-                "', '".join(sorted(unknown_options)), node
-            )
+            f"Unknown options {format_list(unknown_options)} for node '{node}'"
         )
-    parsed_options["name"] = node
-    if ADDR_OPT_KEYWORD in parsed_options:
-        parsed_options["addrs"] = parsed_options[ADDR_OPT_KEYWORD]
-        del parsed_options[ADDR_OPT_KEYWORD]
-    return parsed_options
+    parsed_unique["name"] = node
+    if ADDR_OPT_KEYWORD in parsed_repeatable:
+        parsed_repeatable["addrs"] = parsed_repeatable[ADDR_OPT_KEYWORD]
+        del parsed_repeatable[ADDR_OPT_KEYWORD]
+    return parsed_unique | parsed_repeatable
 
 
 TRANSPORT_KEYWORD = "transport"
@@ -1621,13 +1659,15 @@ TRANSPORT_DEFAULT_SECTION = "__default__"
 LINK_KEYWORD = "link"
 
 
-def _parse_transport(transport_args):
+def _parse_transport(
+    transport_args: Argv,
+) -> tuple[str, dict[str, Union[dict[str, str], list[dict[str, str]]]]]:
     """
     Commandline options: no options
     """
     if not transport_args:
         raise CmdLineInputError(
-            "{} type not defined".format(TRANSPORT_KEYWORD.capitalize())
+            f"{TRANSPORT_KEYWORD.capitalize()} type not defined"
         )
     transport_type, *transport_options = transport_args
 
@@ -1635,23 +1675,24 @@ def _parse_transport(transport_args):
     parsed_options = parse_args.group_by_keywords(
         transport_options,
         keywords,
-        implicit_first_group_key=TRANSPORT_DEFAULT_SECTION,
-        group_repeated_keywords=[LINK_KEYWORD],
+        implicit_first_keyword=TRANSPORT_DEFAULT_SECTION,
     )
-    options = {
-        section: parse_args.prepare_options(parsed_options[section])
+    options: dict[str, Union[dict[str, str], list[dict[str, str]]]] = {
+        section: KeyValueParser(
+            parsed_options.get_args_flat(section)
+        ).get_unique()
         for section in keywords | {TRANSPORT_DEFAULT_SECTION}
         if section != LINK_KEYWORD
     }
     options[LINK_KEYWORD] = [
-        parse_args.prepare_options(link_options)
-        for link_options in parsed_options[LINK_KEYWORD]
+        KeyValueParser(link_options).get_unique()
+        for link_options in parsed_options.get_args_groups(LINK_KEYWORD)
     ]
 
     return transport_type, options
 
 
-def cluster_setup(lib, argv, modifiers):
+def cluster_setup(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --wait - only effective when used with --start
@@ -1684,10 +1725,8 @@ def cluster_setup(lib, argv, modifiers):
     )
     if is_local and modifiers.is_specified_any(allowed_options_live):
         raise CmdLineInputError(
-            (
-                "Cannot specify any of {banned} when '--corosync_conf' is "
-                "specified"
-            ).format(banned=format_list(allowed_options_live))
+            f"Cannot specify any of {format_list(allowed_options_live)} "
+            "when '--corosync_conf' is specified"
         )
     if not is_local and modifiers.is_specified("--overwrite"):
         raise CmdLineInputError(
@@ -1700,32 +1739,37 @@ def cluster_setup(lib, argv, modifiers):
     cluster_name, *argv = argv
     keywords = [TRANSPORT_KEYWORD, "totem", "quorum"]
     parsed_args = parse_args.group_by_keywords(
-        argv,
-        keywords,
-        implicit_first_group_key="nodes",
-        keyword_repeat_allowed=False,
-        only_found_keywords=True,
+        argv, keywords, implicit_first_keyword="nodes"
     )
+    parsed_args.ensure_unique_keywords()
     nodes = [
         _parse_node_options(node, options)
         for node, options in parse_args.split_list_by_any_keywords(
-            parsed_args["nodes"],
-            "node name",
+            parsed_args.get_args_flat("nodes"), "node name"
         ).items()
     ]
 
     transport_type = None
-    transport_options = {}
+    transport_options: dict[
+        str, Union[dict[str, str], list[dict[str, str]]]
+    ] = {}
 
-    if TRANSPORT_KEYWORD in parsed_args:
+    if parsed_args.has_keyword(TRANSPORT_KEYWORD):
         transport_type, transport_options = _parse_transport(
-            parsed_args[TRANSPORT_KEYWORD]
+            parsed_args.get_args_flat(TRANSPORT_KEYWORD)
         )
 
     force_flags = []
     if modifiers.get("--force"):
         force_flags.append(reports.codes.FORCE)
 
+    totem_options = KeyValueParser(
+        parsed_args.get_args_flat("totem")
+    ).get_unique()
+    quorum_options = KeyValueParser(
+        parsed_args.get_args_flat("quorum")
+    ).get_unique()
+
     if not is_local:
         lib.cluster.setup(
             cluster_name,
@@ -1737,12 +1781,8 @@ def cluster_setup(lib, argv, modifiers):
             link_list=transport_options.get(LINK_KEYWORD, []),
             compression_options=transport_options.get("compression", {}),
             crypto_options=transport_options.get("crypto", {}),
-            totem_options=parse_args.prepare_options(
-                parsed_args.get("totem", [])
-            ),
-            quorum_options=parse_args.prepare_options(
-                parsed_args.get("quorum", [])
-            ),
+            totem_options=totem_options,
+            quorum_options=quorum_options,
             wait=modifiers.get("--wait"),
             start=modifiers.get("--start"),
             enable=modifiers.get("--enable"),
@@ -1760,10 +1800,8 @@ def cluster_setup(lib, argv, modifiers):
         link_list=transport_options.get(LINK_KEYWORD, []),
         compression_options=transport_options.get("compression", {}),
         crypto_options=transport_options.get("crypto", {}),
-        totem_options=parse_args.prepare_options(parsed_args.get("totem", [])),
-        quorum_options=parse_args.prepare_options(
-            parsed_args.get("quorum", [])
-        ),
+        totem_options=totem_options,
+        quorum_options=quorum_options,
         no_cluster_uuid=modifiers.is_specified("--no-cluster-uuid"),
         force_flags=force_flags,
     )
@@ -1795,9 +1833,7 @@ def cluster_setup(lib, argv, modifiers):
         )
 
 
-def config_update(
-    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
-) -> None:
+def config_update(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --corosync_conf - corosync.conf file path, do not talk to cluster nodes
@@ -1807,12 +1843,26 @@ def config_update(
         argv,
         ["transport", "compression", "crypto", "totem"],
     )
+
+    transport_options = KeyValueParser(
+        parsed_args.get_args_flat("transport")
+    ).get_unique()
+    compression_options = KeyValueParser(
+        parsed_args.get_args_flat("compression")
+    ).get_unique()
+    crypto_options = KeyValueParser(
+        parsed_args.get_args_flat("crypto")
+    ).get_unique()
+    totem_options = KeyValueParser(
+        parsed_args.get_args_flat("totem")
+    ).get_unique()
+
     if not modifiers.is_specified("--corosync_conf"):
         lib.cluster.config_update(
-            parse_args.prepare_options(parsed_args["transport"]),
-            parse_args.prepare_options(parsed_args["compression"]),
-            parse_args.prepare_options(parsed_args["crypto"]),
-            parse_args.prepare_options(parsed_args["totem"]),
+            transport_options,
+            compression_options,
+            crypto_options,
+            totem_options,
         )
         return
 
@@ -1820,15 +1870,15 @@ def config_update(
         modifiers.get("--corosync_conf"),
         lambda corosync_conf_content: lib.cluster.config_update_local(
             corosync_conf_content,
-            parse_args.prepare_options(parsed_args["transport"]),
-            parse_args.prepare_options(parsed_args["compression"]),
-            parse_args.prepare_options(parsed_args["crypto"]),
-            parse_args.prepare_options(parsed_args["totem"]),
+            transport_options,
+            compression_options,
+            crypto_options,
+            totem_options,
         ),
     )
 
 
-def _format_options(label: str, options: Mapping[str, str]) -> List[str]:
+def _format_options(label: str, options: Mapping[str, str]) -> list[str]:
     output = []
     if options:
         output.append(f"{label}:")
@@ -1838,7 +1888,7 @@ def _format_options(label: str, options: Mapping[str, str]) -> List[str]:
     return output
 
 
-def _format_nodes(nodes: Iterable[CorosyncNodeDto]) -> List[str]:
+def _format_nodes(nodes: Iterable[CorosyncNodeDto]) -> list[str]:
     output = ["Nodes:"]
     for node in sorted(nodes, key=lambda node: node.name):
         node_attrs = [
@@ -1850,7 +1900,7 @@ def _format_nodes(nodes: Iterable[CorosyncNodeDto]) -> List[str]:
 
 
 def config_show(
-    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
+    lib: Any, argv: Argv, modifiers: parse_args.InputModifiers
 ) -> None:
     """
     Options:
@@ -1864,25 +1914,25 @@ def config_show(
         raise CmdLineInputError()
     output_format = modifiers.get_output_format()
     corosync_conf_dto = lib.cluster.get_corosync_conf_struct()
-    if output_format == "cmd":
+    if output_format == OUTPUT_FORMAT_VALUE_CMD:
         if corosync_conf_dto.quorum_device is not None:
             warn(
                 "Quorum device configuration detected but not yet supported by "
                 "this command."
             )
         output = " \\\n".join(_config_get_cmd(corosync_conf_dto))
-    elif output_format == "json":
+    elif output_format == OUTPUT_FORMAT_VALUE_JSON:
         output = json.dumps(dto.to_dict(corosync_conf_dto))
     else:
         output = "\n".join(_config_get_text(corosync_conf_dto))
     print(output)
 
 
-def _config_get_text(corosync_conf: CorosyncConfDto) -> List[str]:
+def _config_get_text(corosync_conf: CorosyncConfDto) -> list[str]:
     lines = [f"Cluster Name: {corosync_conf.cluster_name}"]
     if corosync_conf.cluster_uuid:
         lines.append(f"Cluster UUID: {corosync_conf.cluster_uuid}")
-    lines.append("Transport: {}".format(corosync_conf.transport.lower()))
+    lines.append(f"Transport: {corosync_conf.transport.lower()}")
     lines.extend(_format_nodes(corosync_conf.nodes))
     if corosync_conf.links_options:
         lines.append("Links:")
@@ -1948,8 +1998,8 @@ def _corosync_node_to_cmd_line(node: CorosyncNodeDto) -> str:
 
 def _section_to_lines(
     options: Mapping[str, str], keyword: Optional[str] = None
-) -> List[str]:
-    output: List[str] = []
+) -> list[str]:
+    output: list[str] = []
     if options:
         if keyword:
             output.append(keyword)
@@ -1959,7 +2009,7 @@ def _section_to_lines(
     return indent(output)
 
 
-def _config_get_cmd(corosync_conf: CorosyncConfDto) -> List[str]:
+def _config_get_cmd(corosync_conf: CorosyncConfDto) -> list[str]:
     lines = [f"pcs cluster setup {corosync_conf.cluster_name}"]
     lines += indent(
         [
@@ -1987,10 +2037,9 @@ def _config_get_cmd(corosync_conf: CorosyncConfDto) -> List[str]:
     return lines
 
 
-def _parse_add_node(argv):
-    # pylint: disable=invalid-name
-    DEVICE_KEYWORD = "device"
-    WATCHDOG_KEYWORD = "watchdog"
+def _parse_add_node(argv: Argv) -> dict[str, Union[str, list[str]]]:
+    DEVICE_KEYWORD = "device"  # pylint: disable=invalid-name
+    WATCHDOG_KEYWORD = "watchdog"  # pylint: disable=invalid-name
     hostname, *argv = argv
     node_dict = _parse_node_options(
         hostname,
@@ -2004,7 +2053,7 @@ def _parse_add_node(argv):
     return node_dict
 
 
-def node_add(lib, argv, modifiers):
+def node_add(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --wait - wait until new node will start up, effective only when --start
@@ -2047,7 +2096,9 @@ def node_add(lib, argv, modifiers):
     )
 
 
-def remove_nodes_from_cib(lib, argv, modifiers):
+def remove_nodes_from_cib(
+    lib: Any, argv: Argv, modifiers: InputModifiers
+) -> None:
     """
     Options: no options
     """
@@ -2057,7 +2108,7 @@ def remove_nodes_from_cib(lib, argv, modifiers):
     lib.cluster.remove_nodes_from_cib(argv)
 
 
-def link_add(lib, argv, modifiers):
+def link_add(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --force - treat validation issues and not resolvable addresses as
@@ -2078,20 +2129,18 @@ def link_add(lib, argv, modifiers):
         force_flags.append(reports.codes.SKIP_OFFLINE_NODES)
 
     parsed = parse_args.group_by_keywords(
-        argv,
-        {"options"},
-        implicit_first_group_key="nodes",
-        keyword_repeat_allowed=False,
+        argv, {"options"}, implicit_first_keyword="nodes"
     )
+    parsed.ensure_unique_keywords()
 
     lib.cluster.add_link(
-        parse_args.prepare_options(parsed["nodes"]),
-        parse_args.prepare_options(parsed["options"]),
+        KeyValueParser(parsed.get_args_flat("nodes")).get_unique(),
+        KeyValueParser(parsed.get_args_flat("options")).get_unique(),
         force_flags=force_flags,
     )
 
 
-def link_remove(lib, argv, modifiers):
+def link_remove(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --skip-offline - skip unreachable nodes
@@ -2108,7 +2157,7 @@ def link_remove(lib, argv, modifiers):
     lib.cluster.remove_links(argv, force_flags=force_flags)
 
 
-def link_update(lib, argv, modifiers):
+def link_update(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --force - treat validation issues and not resolvable addresses as
@@ -2130,23 +2179,19 @@ def link_update(lib, argv, modifiers):
 
     linknumber = argv[0]
     parsed = parse_args.group_by_keywords(
-        argv[1:],
-        {"options"},
-        implicit_first_group_key="nodes",
-        keyword_repeat_allowed=False,
+        argv[1:], {"options"}, implicit_first_keyword="nodes"
     )
+    parsed.ensure_unique_keywords()
 
     lib.cluster.update_link(
         linknumber,
-        parse_args.prepare_options(parsed["nodes"]),
-        parse_args.prepare_options(parsed["options"]),
+        KeyValueParser(parsed.get_args_flat("nodes")).get_unique(),
+        KeyValueParser(parsed.get_args_flat("options")).get_unique(),
         force_flags=force_flags,
     )
 
 
-def generate_uuid(
-    lib: Any, argv: List[str], modifiers: parse_args.InputModifiers
-):
+def generate_uuid(lib: Any, argv: Argv, modifiers: InputModifiers) -> None:
     """
     Options:
       * --force - allow to rewrite an existing UUID in corosync.conf
