@@ -5,14 +5,17 @@ from . import (
     messages,
     types,
 )
-from .item import (
-    get_severity,
-    ReportItem,
-    ReportItemList,
-    ReportItemSeverity,
-)
+from .conversions import report_dto_to_item
 from .dto import ReportItemDto
+from .item import (
+    ReportItem,
+    ReportItemContext,
+    ReportItemList,
+    ReportItemMessage,
+    ReportItemSeverity,
+    get_severity,
+)
 from .processor import (
+    ReportProcessor,
     has_errors,
-    ReportProcessor,
 )
