@@ -1,4 +1,5 @@
-# pylint: disable=wildcard-import, unused-wildcard-import
+# pylint: disable=unused-wildcard-import
+# pylint: disable=wildcard-import
 # Wildcard import of deprecated report codes will prevent creation of a new
 # report with the code of deprecated report
 from .deprecated_codes import *
@@ -76,9 +77,13 @@ BOOTH_TICKET_NAME_INVALID = M("BOOTH_TICKET_NAME_INVALID")
 BOOTH_TICKET_OPERATION_FAILED = M("BOOTH_TICKET_OPERATION_FAILED")
 BOOTH_TICKET_STATUS_ERROR = M("BOOTH_TICKET_STATUS_ERROR")
 BOOTH_UNSUPPORTED_FILE_LOCATION = M("BOOTH_UNSUPPORTED_FILE_LOCATION")
+CANNOT_BAN_RESOURCE_BUNDLE_INNER = M("CANNOT_BAN_RESOURCE_BUNDLE_INNER")
 CANNOT_BAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE = M(
     "CANNOT_BAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE"
 )
+CANNOT_BAN_RESOURCE_MULTIPLE_INSTANCES_NO_NODE_SPECIFIED = M(
+    "CANNOT_BAN_RESOURCE_MULTIPLE_INSTANCES_NO_NODE_SPECIFIED"
+)
 CANNOT_BAN_RESOURCE_STOPPED_NO_NODE_SPECIFIED = M(
     "CANNOT_BAN_RESOURCE_STOPPED_NO_NODE_SPECIFIED"
 )
@@ -87,11 +92,17 @@ CANNOT_CREATE_DEFAULT_CLUSTER_PROPERTY_SET = M(
 )
 CANNOT_GROUP_RESOURCE_WRONG_TYPE = M("CANNOT_GROUP_RESOURCE_WRONG_TYPE")
 CANNOT_LEAVE_GROUP_EMPTY_AFTER_MOVE = M("CANNOT_LEAVE_GROUP_EMPTY_AFTER_MOVE")
-CANNOT_MOVE_RESOURCE_BUNDLE = M("CANNOT_MOVE_RESOURCE_BUNDLE")
-CANNOT_MOVE_RESOURCE_CLONE = M("CANNOT_MOVE_RESOURCE_CLONE")
+CANNOT_MOVE_RESOURCE_BUNDLE_INNER = M("CANNOT_MOVE_RESOURCE_BUNDLE_INNER")
+CANNOT_MOVE_RESOURCE_CLONE_INNER = M("CANNOT_MOVE_RESOURCE_CLONE_INNER")
 CANNOT_MOVE_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE = M(
     "CANNOT_MOVE_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE"
 )
+CANNOT_MOVE_RESOURCE_MULTIPLE_INSTANCES = M(
+    "CANNOT_MOVE_RESOURCE_MULTIPLE_INSTANCES"
+)
+CANNOT_MOVE_RESOURCE_MULTIPLE_INSTANCES_NO_NODE_SPECIFIED = M(
+    "CANNOT_MOVE_RESOURCE_MULTIPLE_INSTANCES_NO_NODE_SPECIFIED"
+)
 CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER = M(
     "CANNOT_MOVE_RESOURCE_PROMOTABLE_INNER"
 )
@@ -127,6 +138,7 @@ CIB_LOAD_ERROR_GET_NODES_FOR_VALIDATION = M(
 CIB_NVSET_AMBIGUOUS_PROVIDE_NVSET_ID = M("CIB_NVSET_AMBIGUOUS_PROVIDE_NVSET_ID")
 CIB_LOAD_ERROR_SCOPE_MISSING = M("CIB_LOAD_ERROR_SCOPE_MISSING")
 CIB_PUSH_ERROR = M("CIB_PUSH_ERROR")
+CIB_REMOVE_DEPENDANT_ELEMENTS = M("CIB_REMOVE_DEPENDANT_ELEMENTS")
 CIB_SAVE_TMP_ERROR = M("CIB_SAVE_TMP_ERROR")
 CIB_SIMULATE_ERROR = M("CIB_SIMULATE_ERROR")
 CIB_UPGRADE_FAILED = M("CIB_UPGRADE_FAILED")
@@ -206,11 +218,19 @@ COROSYNC_LINK_NUMBER_DUPLICATION = M("COROSYNC_LINK_NUMBER_DUPLICATION")
 COROSYNC_NODE_ADDRESS_COUNT_MISMATCH = M("COROSYNC_NODE_ADDRESS_COUNT_MISMATCH")
 COROSYNC_NODE_CONFLICT_CHECK_SKIPPED = M("COROSYNC_NODE_CONFLICT_CHECK_SKIPPED")
 COROSYNC_NODES_MISSING = M("COROSYNC_NODES_MISSING")
+COROSYNC_NOT_RUNNING_CHECK_FINISHED_RUNNING = M(
+    "COROSYNC_NOT_RUNNING_CHECK_FINISHED_RUNNING"
+)
 COROSYNC_NOT_RUNNING_CHECK_NODE_ERROR = M(
     "COROSYNC_NOT_RUNNING_CHECK_NODE_ERROR"
 )
+COROSYNC_NOT_RUNNING_CHECK_NODE_RUNNING = M(
+    "COROSYNC_NOT_RUNNING_CHECK_NODE_RUNNING"
+)
+COROSYNC_NOT_RUNNING_CHECK_NODE_STOPPED = M(
+    "COROSYNC_NOT_RUNNING_CHECK_NODE_STOPPED"
+)
 COROSYNC_NOT_RUNNING_CHECK_STARTED = M("COROSYNC_NOT_RUNNING_CHECK_STARTED")
-COROSYNC_NOT_RUNNING_ON_NODE = M("COROSYNC_NOT_RUNNING_ON_NODE")
 COROSYNC_OPTIONS_INCOMPATIBLE_WITH_QDEVICE = M(
     "COROSYNC_OPTIONS_INCOMPATIBLE_WITH_QDEVICE"
 )
@@ -220,6 +240,9 @@ COROSYNC_QUORUM_ATB_CANNOT_BE_DISABLED_DUE_TO_SBD = M(
 COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD = M(
     "COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD"
 )
+COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD_CLUSTER_IS_RUNNING = M(
+    "COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD_CLUSTER_IS_RUNNING"
+)
 COROSYNC_QUORUM_GET_STATUS_ERROR = M("COROSYNC_QUORUM_GET_STATUS_ERROR")
 COROSYNC_QUORUM_HEURISTICS_ENABLED_WITH_NO_EXEC = M(
     "COROSYNC_QUORUM_HEURISTICS_ENABLED_WITH_NO_EXEC"
@@ -229,7 +252,6 @@ COROSYNC_QUORUM_SET_EXPECTED_VOTES_ERROR = M(
     "COROSYNC_QUORUM_SET_EXPECTED_VOTES_ERROR"
 )
 COROSYNC_QUORUM_WILL_BE_LOST = M("COROSYNC_QUORUM_WILL_BE_LOST")
-COROSYNC_RUNNING_ON_NODE = M("COROSYNC_RUNNING_ON_NODE")
 COROSYNC_TOO_MANY_LINKS_OPTIONS = M("COROSYNC_TOO_MANY_LINKS_OPTIONS")
 COROSYNC_TRANSPORT_UNSUPPORTED_OPTIONS = M(
     "COROSYNC_TRANSPORT_UNSUPPORTED_OPTIONS"
