@@ -9,11 +9,11 @@ def constraint_plain(constraint_info):
     co_score = options_dict.get("score", "")
     score_text = "(score:" + co_score + ")"
     console_option_list = [
-        "(%s:%s)" % (option[0], option[1])
+        f"({option[0]}:{option[1]})"
         for option in sorted(options_dict.items())
         if option[0] not in ("rsc", "with-rsc", "id", "score")
     ]
-    console_option_list.append("(id:%s)" % co_id)
+    console_option_list.append(f"(id:{co_id})")
     return " ".join(
         [co_resource1, "with", co_resource2, score_text] + console_option_list
     )
