@@ -7,6 +7,7 @@ DefaultAddressSource = NewType("DefaultAddressSource", str)
 FenceHistoryCommandType = NewType("FenceHistoryCommandType", str)
 ForceCode = NewType("ForceCode", str)
 MessageCode = NewType("MessageCode", str)
+DeprecatedMessageCode = NewType("DeprecatedMessageCode", str)
 PcsCommand = NewType("PcsCommand", str)
 ReasonType = NewType("ReasonType", str)
 ServiceAction = NewType("ServiceAction", str)
@@ -14,3 +15,6 @@ SeverityLevel = NewType("SeverityLevel", str)
 StonithRestartlessUpdateUnableToPerformReason = NewType(
     "StonithRestartlessUpdateUnableToPerformReason", str
 )
+StonithWatchdogTimeoutCannotBeSetReason = NewType(
+    "StonithWatchdogTimeoutCannotBeSetReason", str
+)
