@@ -1,7 +1,7 @@
 from collections.abc import Iterable as IterableAbc
+from collections.abc import Sized
 from typing import (
     Any,
-    Iterable,
     List,
     Mapping,
     Optional,
@@ -11,7 +11,10 @@ from typing import (
     Union,
 )
 
-from pcs.common.types import StringSequence
+from pcs.common.types import (
+    StringIterable,
+    StringSequence,
+)
 
 
 def indent(line_list: StringSequence, indent_step: int = 2) -> List[str]:
@@ -36,29 +39,23 @@ def outdent(line_list: StringSequence) -> List[str]:
     return [line[smallest_indentation:] for line in line_list]
 
 
-def format_list_base(
-    item_list: StringSequence,
-    separator: str = ", ",
-) -> str:
+def format_list_base(item_list: StringIterable, separator: str = ", ") -> str:
     return separator.join(item_list)
 
 
 def format_list_dont_sort(
-    item_list: StringSequence,
+    item_list: StringIterable,
     separator: str = ", ",
 ) -> str:
     return format_list_base(quote_items(item_list), separator)
 
 
-def format_list(
-    item_list: StringSequence,
-    separator: str = ", ",
-) -> str:
+def format_list(item_list: StringIterable, separator: str = ", ") -> str:
     return format_list_dont_sort(sorted(item_list), separator)
 
 
 def format_list_custom_last_separator(
-    item_list: StringSequence,
+    item_list: StringIterable,
     last_separator: str,
     separator: str = ", ",
 ) -> str:
@@ -83,7 +80,7 @@ def format_list_custom_last_separator_dont_sort(
     )
 
 
-def quote_items(item_list: StringSequence) -> List[str]:
+def quote_items(item_list: StringIterable) -> List[str]:
     return [f"'{item}'" for item in item_list]
 
 
@@ -180,11 +177,11 @@ def format_optional(
     return empty_case
 
 
-def _is_multiple(what):
+def _is_multiple(what: Union[int, Sized]):
     """
     Return True if 'what' does not mean one item, False otherwise
 
-    iterable/int what -- this will be counted
+    what -- this will be counted
     """
     retval = False
     if isinstance(what, int):
@@ -227,7 +224,7 @@ def get_plural(singular: str) -> str:
 
 
 def format_plural(
-    depends_on: Union[int, Iterable[Any]],
+    depends_on: Union[int, Sized],
     singular: str,
     plural: Optional[str] = None,
 ) -> str:
@@ -235,8 +232,7 @@ def format_plural(
     Takes the singular word form and returns its plural form if depends_on
     is not equal to one/contains one item
 
-    iterable/int/string depends_on -- if number (of items) isn't equal to one,
-        returns plural
+    depends_on -- if number (of items) isn't equal to one, return plural
     singular -- singular word (like: is, do, node)
     plural -- optional irregular plural form
     """
