@@ -52,8 +52,6 @@ from pcs.common.str_tools import indent
 from pcs.lib.errors import LibraryError
 from pcs.lib.node import get_existing_nodes_names
 
-# pylint: disable=too-many-branches, too-many-locals, too-many-statements
-
 
 def config_show(lib, argv, modifiers):
     """
@@ -115,6 +113,10 @@ def _config_show_cib_lines(lib, properties_facade=None):
     Commandline options:
       * -f - CIB file
     """
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
+
     # update of pcs_options will change output of constraint show and
     # displaying resources and operations defaults
     utils.pcs_options["--full"] = 1
@@ -336,6 +338,8 @@ def config_restore_remote(infile_name, infile_obj):
     Commandline options:
       * --request-timeout - timeout for HTTP requests
     """
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
     extracted = {
         "version.txt": "",
         "corosync.conf": "",
@@ -422,6 +426,9 @@ def config_restore_local(infile_name, infile_obj):
     """
     Commandline options: no options
     """
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
     service_manager = utils.get_service_manager()
     if (
         service_manager.is_running("corosync")
@@ -488,14 +495,36 @@ def config_restore_local(infile_name, infile_obj):
                 if "rename" in extract_info and extract_info["rename"]:
                     if tmp_dir is None:
                         tmp_dir = tempfile.mkdtemp()
-                    tarball.extractall(tmp_dir, [tar_member_info])
+                    if hasattr(tarfile, "data_filter"):
+                        # Safe way of extraction is available since Python 3.12,
+                        # hasattr above checks if it's available.
+                        # It's also backported to 3.11.4, 3.10.12, 3.9.17.
+                        # It may be backported to older versions in downstream.
+                        tarball.extractall(
+                            tmp_dir, [tar_member_info], filter="data"
+                        )
+                    else:
+                        # Unsafe way of extraction
+                        # Remove once we don't support Python 3.8 and older
+                        tarball.extractall(tmp_dir, [tar_member_info])
                     path_full = extract_info["path"]
                     shutil.move(
                         os.path.join(tmp_dir, tar_member_info.name), path_full
                     )
                 else:
                     dir_path = os.path.dirname(extract_info["path"])
-                    tarball.extractall(dir_path, [tar_member_info])
+                    if hasattr(tarfile, "data_filter"):
+                        # Safe way of extraction is available since Python 3.12,
+                        # hasattr above checks if it's available.
+                        # It's also backported to 3.11.4, 3.10.12, 3.9.17.
+                        # It may be backported to older versions in downstream.
+                        tarball.extractall(
+                            dir_path, [tar_member_info], filter="data"
+                        )
+                    else:
+                        # Unsafe way of extracting
+                        # Remove once we don't support Python 3.8 and older
+                        tarball.extractall(dir_path, [tar_member_info])
                     path_full = os.path.join(dir_path, tar_member_info.name)
                 file_attrs = extract_info["attrs"]
                 os.chmod(path_full, file_attrs["mode"])
@@ -804,7 +833,6 @@ def config_checkpoint_restore(lib, argv, modifiers):
     Options:
       * -f - CIB file, a checkpoint will be restored into a specified file
     """
-    # pylint: disable=broad-except
     del lib
     modifiers.ensure_only_supported("-f")
     if len(argv) != 1:
@@ -814,6 +842,7 @@ def config_checkpoint_restore(lib, argv, modifiers):
     cib_path = os.path.join(settings.cib_dir, "cib-%s.raw" % argv[0])
     try:
         snapshot_dom = parse(cib_path)
+    # pylint: disable=broad-except
     except Exception as e:
         utils.err("unable to read the checkpoint: %s" % e)
     utils.replace_cib_configuration(snapshot_dom)
