@@ -1,18 +1,19 @@
 from functools import partial
+
 from lxml import etree
 
 from pcs.common import reports
 from pcs.common.reports import ReportProcessor
 from pcs.common.reports.item import ReportItem
-from pcs.lib.errors import LibraryError
 from pcs.lib.cib.nvpair import get_nvset
 from pcs.lib.cib.tools import (
     check_new_id_applicable,
+    find_element_by_tag_and_id,
     find_unique_id,
     get_alerts,
     validate_id_does_not_exist,
-    find_element_by_tag_and_id,
 )
+from pcs.lib.errors import LibraryError
 from pcs.lib.xml_tools import get_sub_element
 
 TAG_ALERT = "alert"
@@ -57,15 +58,15 @@ def ensure_recipient_value_is_unique(
         exists
     """
     recipient_list = alert.xpath(
-        "./recipient[@value='{value}' and @id!='{id}']".format(
-            value=recipient_value, id=recipient_id
-        )
+        "./recipient[@value=$value and @id!=$id]",
+        value=recipient_value,
+        id=recipient_id,
     )
     if recipient_list:
         reporter.report(
             ReportItem(
                 severity=reports.item.get_severity(
-                    reports.codes.FORCE_ALERT_RECIPIENT_VALUE_NOT_UNIQUE,
+                    reports.codes.FORCE,
                     allow_duplicity,
                 ),
                 message=reports.messages.CibAlertRecipientAlreadyExists(
@@ -153,7 +154,7 @@ def add_recipient(
     allow_same_value -- if True unique recipient value is not required
     """
     if recipient_id is None:
-        recipient_id = find_unique_id(tree, "{0}-recipient".format(alert_id))
+        recipient_id = find_unique_id(tree, f"{alert_id}-recipient")
     else:
         validate_id_does_not_exist(tree, recipient_id)
 
