@@ -43,6 +43,10 @@ ATTRIB_PLAIN = {
 }
 
 
+def is_ticket_constraint(element: _Element) -> bool:
+    return element.tag == TAG_NAME
+
+
 def _validate_options_common(options):
     report_list = []
     if "loss-policy" in options:
@@ -65,7 +69,7 @@ def _create_id(cib, ticket, resource_id, resource_role):
     return tools.find_unique_id(
         cib,
         "-".join(("ticket", ticket, resource_id))
-        + ("-{0}".format(resource_role) if resource_role else ""),
+        + (f"-{resource_role}" if resource_role else ""),
     )
 
 
