@@ -80,6 +80,18 @@ def is_bundle(resource_el: _Element) -> bool:
     return resource_el.tag == TAG
 
 
+def get_parent_bundle(resource_el: _Element) -> Optional[_Element]:
+    """
+    Get a parent bundle of a primitive or None
+
+    resource_el -- the primitive to get its parent bundle
+    """
+    parent_el = resource_el.getparent()
+    if parent_el is not None and is_bundle(parent_el):
+        return parent_el
+    return None
+
+
 def bundle_element_to_dto(
     bundle_element: _Element,
     rule_eval: Optional[rule.RuleInEffectEval] = None,
@@ -382,7 +394,7 @@ def update(
     storage_map_remove,
     meta_attributes,
 ):
-    # pylint: disable=too-many-arguments, too-many-locals
+    # pylint: disable=too-many-arguments
     """
     Modify an existing bundle (does not touch encapsulated resources)
 
@@ -865,7 +877,7 @@ def _append_port_map(parent_element, id_provider, id_base, port_map_options):
             id_suffix = port_map_options["range"]
         if id_suffix:
             port_map_options["id"] = id_provider.allocate_id(
-                sanitize_id("{0}-port-map-{1}".format(id_base, id_suffix))
+                sanitize_id(f"{id_base}-port-map-{id_suffix}")
             )
     port_map_element = etree.SubElement(parent_element, "port-mapping")
     # Do not add options with empty values. When updating, an empty value means
@@ -891,7 +903,7 @@ def _append_storage_map(
     if "id" not in storage_map_options:
         storage_map_options["id"] = id_provider.allocate_id(
             # use just numbers to keep the ids reasonably short
-            "{0}-storage-map".format(id_base)
+            f"{id_base}-storage-map"
         )
     storage_map_element = etree.SubElement(parent_element, "storage-mapping")
     # Do not add options with empty values. When updating, an empty value means
