@@ -1,16 +1,21 @@
 from typing import (
-    Iterable,
     List,
+    Mapping,
     Optional,
     Set,
     Tuple,
+    cast,
 )
 
 from lxml.etree import _Element
 
 from pcs.common.reports.item import ReportItemList
+from pcs.common.types import StringCollection
 from pcs.lib.cib import nvpair
-from pcs.lib.cib.tools import ElementSearcher
+from pcs.lib.cib.tools import (
+    ElementSearcher,
+    IdProvider,
+)
 from pcs.lib.xml_tools import find_parent
 
 from .bundle import TAG as TAG_BUNDLE
@@ -30,16 +35,18 @@ ALL_RESOURCE_XML_TAGS = sorted(
 )
 
 
-def are_meta_disabled(meta_attributes):
+def are_meta_disabled(meta_attributes: Mapping[str, str]) -> bool:
     return meta_attributes.get("target-role", "Started").lower() == "stopped"
 
 
-def _can_be_evaluated_as_positive_num(value):
+def _can_be_evaluated_as_positive_num(value: str) -> bool:
     string_wo_leading_zeros = str(value).lstrip("0")
-    return string_wo_leading_zeros and string_wo_leading_zeros[0].isdigit()
+    return (
+        bool(string_wo_leading_zeros) and string_wo_leading_zeros[0].isdigit()
+    )
 
 
-def is_clone_deactivated_by_meta(meta_attributes):
+def is_clone_deactivated_by_meta(meta_attributes: Mapping[str, str]) -> bool:
     return are_meta_disabled(meta_attributes) or any(
         not _can_be_evaluated_as_positive_num(meta_attributes.get(key, "1"))
         for key in ["clone-max", "clone-node-max"]
@@ -49,7 +56,7 @@ def is_clone_deactivated_by_meta(meta_attributes):
 def find_one_resource(
     context_element: _Element,
     resource_id: str,
-    resource_tags: Optional[Iterable[str]] = None,
+    resource_tags: Optional[StringCollection] = None,
 ) -> Tuple[Optional[_Element], ReportItemList]:
     """
     Find a single resource or return None if not found
@@ -69,11 +76,11 @@ def find_one_resource(
 
 def find_resources(
     context_element: _Element,
-    resource_ids: Iterable[str],
-    resource_tags: Optional[Iterable[str]] = None,
+    resource_ids: StringCollection,
+    resource_tags: Optional[StringCollection] = None,
 ) -> Tuple[List[_Element], ReportItemList]:
     """
-    Find a list of resource
+    Find a list of resources
 
     context_element -- an element to be searched in
     resource_id -- id of an element to find
@@ -95,7 +102,8 @@ def find_resources(
 def find_primitives(resource_el: _Element) -> List[_Element]:
     """
     Get list of primitives contained in a given resource
-    etree resource_el -- resource element
+
+    resource_el -- resource element
     """
     if is_bundle(resource_el):
         in_bundle = get_bundle_inner_resource(resource_el)
@@ -183,10 +191,11 @@ def get_parent_resource(resource_el: _Element) -> Optional[_Element]:
     return None
 
 
-def find_resources_to_enable(resource_el):
+def find_resources_to_enable(resource_el: _Element) -> List[_Element]:
     """
     Get resources to enable in order to enable specified resource successfully
-    etree resource_el -- resource element
+
+    resource_el -- resource element
     """
     if is_bundle(resource_el):
         to_enable = [resource_el]
@@ -200,43 +209,42 @@ def find_resources_to_enable(resource_el):
 
     to_enable = [resource_el]
     parent = resource_el.getparent()
-    if is_any_clone(parent) or is_bundle(parent):
+    if parent is not None and (is_any_clone(parent) or is_bundle(parent)):
         to_enable.append(parent)
     return to_enable
 
 
-def enable(resource_el, id_provider):
+def enable(resource_el: _Element, id_provider: IdProvider) -> None:
     """
     Enable specified resource
-    etree resource_el -- resource element
+
+    resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
         resource_el,
-        {
-            "target-role": "",
-        },
+        {"target-role": ""},
         id_provider,
     )
 
 
-def disable(resource_el, id_provider):
+def disable(resource_el: _Element, id_provider: IdProvider) -> None:
     """
     Disable specified resource
-    etree resource_el -- resource element
+
+    resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
         resource_el,
-        {
-            "target-role": "Stopped",
-        },
+        {"target-role": "Stopped"},
         id_provider,
     )
 
 
-def find_resources_to_manage(resource_el):
+def find_resources_to_manage(resource_el: _Element) -> List[_Element]:
     """
-    Get resources to manage to manage the specified resource successfully
-    etree resource_el -- resource element
+    Get resources to set to managed for the specified resource to become managed
+
+    resource_el -- resource element
     """
     # If the resource_el is a primitive in a group, we set both the group and
     # the primitive to managed mode. Otherwise the resource_el, all its
@@ -246,37 +254,41 @@ def find_resources_to_manage(resource_el):
     # as a managed primitive in an unmanaged clone / group is still unmanaged
     # and vice versa.
     res_id = resource_el.attrib["id"]
-    return (
-        [resource_el]  # the resource itself
-        +
-        # its parents
-        find_parent(resource_el, "resources").xpath(
-            # a master or a clone which contains a group, a primitive, or a
-            # grouped primitive with the specified id
-            # OR
-            # a group (in a clone, master, etc. - hence //) which contains a
-            # primitive with the specified id
-            # OR
-            # a bundle which contains a primitive with the specified id
-            """
+    parent_el = []
+    top_element = find_parent(resource_el, {"resources"})
+    if top_element is not None:
+        parent_el = cast(
+            List[_Element],
+            top_element.xpath(
+                # a master or a clone which contains a group, a primitive, or a
+                # grouped primitive with the specified id
+                # OR
+                # a group (in a clone, master, etc. - hence //) which contains a
+                # primitive with the specified id
+                # OR
+                # a bundle which contains a primitive with the specified id
+                """
                 (./master|./clone)[(group|group/primitive|primitive)[@id=$r]]
                 |
                 //group[primitive[@id=$r]]
                 |
                 ./bundle[primitive[@id=$r]]
-            """,
-            r=res_id,
+                """,
+                r=res_id,
+            ),
         )
-        +
-        # its children
-        resource_el.xpath("(./group|./primitive|./group/primitive)")
+    children_el = cast(
+        List[_Element],
+        resource_el.xpath("(./group|./primitive|./group/primitive)"),
     )
+    return [resource_el] + parent_el + children_el
 
 
-def find_resources_to_unmanage(resource_el):
+def find_resources_to_unmanage(resource_el: _Element) -> List[_Element]:
     """
     Get resources to unmanage to unmanage the specified resource successfully
-    etree resource_el -- resource element
+
+    resource_el -- resource element
     """
     # resource hierarchy - specified resource - what to return
     # a primitive - the primitive - the primitive
@@ -328,30 +340,28 @@ def find_resources_to_unmanage(resource_el):
     return []
 
 
-def manage(resource_el, id_provider):
+def manage(resource_el: _Element, id_provider: IdProvider) -> None:
     """
     Set the resource to be managed by the cluster
-    etree resource_el -- resource element
+
+    resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
         resource_el,
-        {
-            "is-managed": "",
-        },
+        {"is-managed": ""},
         id_provider,
     )
 
 
-def unmanage(resource_el, id_provider):
+def unmanage(resource_el: _Element, id_provider: IdProvider) -> None:
     """
     Set the resource not to be managed by the cluster
-    etree resource_el -- resource element
+
+    resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
         resource_el,
-        {
-            "is-managed": "false",
-        },
+        {"is-managed": "false"},
         id_provider,
     )
 
