@@ -7,10 +7,12 @@ from typing import (
 from lxml.etree import _Element
 
 from pcs.common import reports
+from pcs.common.types import StringCollection
 from pcs.lib.cib.node import PacemakerNode
 from pcs.lib.cib.resource import primitive
 from pcs.lib.cib.resource.types import ResourceOperationIn
 from pcs.lib.cib.tools import IdProvider
+from pcs.lib.external import CommandRunner
 from pcs.lib.resource_agent import (
     ResourceAgentFacade,
     ResourceAgentMetadata,
@@ -132,8 +134,10 @@ def _validate_server_not_used(
 
 
 def validate_host_not_conflicts(
-    existing_nodes_addrs, node_name, instance_attributes
-):
+    existing_nodes_addrs: StringCollection,
+    node_name: str,
+    instance_attributes: Mapping[str, str],
+) -> reports.ReportItemList:
     host = instance_attributes.get("server", node_name)
     if host in existing_nodes_addrs:
         return [
@@ -143,8 +147,8 @@ def validate_host_not_conflicts(
 
 
 def validate_create(
-    existing_nodes_names: Iterable[str],
-    existing_nodes_addrs: Iterable[str],
+    existing_nodes_names: StringCollection,
+    existing_nodes_addrs: StringCollection,
     resource_agent: ResourceAgentMetadata,
     new_node_name: str,
     new_node_addr: str,
@@ -195,6 +199,7 @@ def _prepare_instance_attributes(
 
 def create(
     report_processor: reports.ReportProcessor,
+    cmd_runner: CommandRunner,
     resource_agent_facade: ResourceAgentFacade,
     resources_section: _Element,
     id_provider: IdProvider,
@@ -228,6 +233,7 @@ def create(
     )
     return primitive.create(
         report_processor,
+        cmd_runner,
         resources_section,
         id_provider,
         node_name,
@@ -250,4 +256,5 @@ def create(
         # 3) call the validation from here and handle the results or config
         #    the validator before / when running it
         do_not_report_instance_attribute_server_exists=True,
+        enable_agent_self_validation=False,
     )
