@@ -43,6 +43,10 @@ from .const import (
 )
 
 
+def is_tag(element: _Element) -> bool:
+    return element.tag == TAG_TAG
+
+
 def _validate_tag_id(tag_id: str, id_provider: IdProvider) -> ReportItemList:
     """
     Validate that tag_id is a valid xml id and it is unique in the cib.
@@ -403,7 +407,6 @@ class ValidateTagUpdateByIds:
             if self._adjacent_idref is None and existing_element_id_list:
                 report_list.append(
                     ReportItem.error(
-                        # pylint: disable=line-too-long
                         reports.messages.TagCannotAddReferenceIdsAlreadyInTheTag(
                             self._tag_id,
                             sorted(existing_element_id_list),
@@ -452,7 +455,6 @@ class ValidateTagUpdateByIds:
             if not remove_difference:
                 report_list.append(
                     ReportItem.error(
-                        # pylint: disable=line-too-long
                         reports.messages.TagCannotRemoveReferencesWithoutRemovingTag(
                             self._tag_id,
                         )
@@ -487,6 +489,7 @@ def find_constraints_referencing_tag(
     constraints_section -- element constraints
     tag_id -- tag id
     """
+    # TODO: replace by find_elements_referencing_id
     constraint_list = constraints_section.xpath(
         """
         ./rsc_colocation[
