@@ -33,9 +33,17 @@ from pcs.lib.pacemaker.values import (
 from pcs.lib.xml_tools import (
     get_root,
     get_sub_element,
+    remove_one_element,
 )
 
 _VERSION_FORMAT = r"(?P<major>\d+)\.(?P<minor>\d+)(\.(?P<rev>\d+))?$"
+_ELEMENTS_WITH_IDREF_WITHOUT_ID_XPATH = """
+    ./constraints/*/resource_set/resource_ref[@id=$referenced_id]
+    |
+    ./tags/tag/obj_ref[@id=$referenced_id]
+    |
+    ./acls/*/role[@id=$referenced_id]
+"""
 
 
 class ElementNotFound(Exception):
@@ -343,7 +351,7 @@ def find_unique_id(tree, check_id, reserved_ids=None):
     counter = 1
     temp_id = check_id
     while temp_id in reserved_ids or does_id_exist(tree, temp_id):
-        temp_id = "{0}-{1}".format(check_id, counter)
+        temp_id = f"{check_id}-{counter}"
         counter += 1
     return temp_id
 
@@ -521,7 +529,7 @@ def get_pacemaker_version_by_which_cib_was_validated(cib: _Element) -> Version:
     return _get_cib_version(
         cib.getroottree(),
         "validate-with",
-        re.compile(r"pacemaker-{0}".format(_VERSION_FORMAT)),
+        re.compile(f"pacemaker-{_VERSION_FORMAT}"),
     )
 
 
@@ -545,3 +553,86 @@ def are_new_role_names_supported(cib: _Element) -> bool:
 
 def role_constructor(value: str) -> const.PcmkRoleType:
     return role.get_value_primary(const.PcmkRoleType(value))
+
+
+def _get_configuration(element: _Element) -> _Element:
+    return get_configuration(get_root(element))
+
+
+def _find_elements_without_id_referencing_id(
+    element: _Element,
+    referenced_id: str,
+) -> list[_Element]:
+    """
+    Find elements which are referencing specified id (resource or tag).
+
+    element -- any element within CIB tree
+    referenced_id -- id which references should be found
+    """
+    return cast(
+        list[_Element],
+        _get_configuration(element).xpath(
+            _ELEMENTS_WITH_IDREF_WITHOUT_ID_XPATH,
+            referenced_id=referenced_id,
+        ),
+    )
+
+
+def find_elements_referencing_id(
+    element: _Element,
+    referenced_id: str,
+) -> list[_Element]:
+    """
+    Find elements which are referencing specified id (resource or tag).
+
+    element -- any element within CIB tree
+    referenced_id -- id which references should be found
+    """
+    return cast(
+        list[_Element],
+        _get_configuration(element).xpath(
+            """
+        ./constraints/rsc_colocation[
+            not (descendant::resource_set)
+            and
+            (@rsc=$referenced_id or @with-rsc=$referenced_id)
+        ]
+        |
+        ./constraints/rsc_location[
+            not (descendant::resource_set)
+            and
+            @rsc=$referenced_id
+        ]
+        |
+        ./constraints/rsc_order[
+            not (descendant::resource_set)
+            and
+            (@first=$referenced_id or @then=$referenced_id)
+        ]
+        |
+        ./constraints/rsc_ticket[
+            not (descendant::resource_set)
+            and
+            @rsc=$referenced_id
+        ]
+        |
+        ./acls/acl_role/acl_permission[@reference=$referenced_id]
+        |
+        """
+            + _ELEMENTS_WITH_IDREF_WITHOUT_ID_XPATH,
+            referenced_id=referenced_id,
+        ),
+    )
+
+
+def remove_element_by_id(cib: _Element, element_id: str) -> None:
+    """
+    Remove element with specified id from cib element.
+    """
+    for ref_el in _find_elements_without_id_referencing_id(cib, element_id):
+        remove_one_element(ref_el)
+
+    try:
+        remove_one_element(get_element_by_id(cib, element_id))
+    except ElementNotFound:
+        pass
