@@ -336,9 +336,6 @@ def config_text(env: LibraryEnvironment, instance_name=None, node_name=None):
     com_cmd.set_targets(
         [env.get_node_target_factory().get_target_from_hostname(node_name)]
     )
-    # pylint: disable=unsubscriptable-object
-    # In general, pylint is right. And it cannot know in this case code is OK.
-    # It is covered by tests.
     remote_data = run_and_raise(env.get_node_communicator(), com_cmd)[0][1]
     try:
         # TODO switch to new file transfer commands (not implemented yet)
@@ -629,19 +626,25 @@ def _ticket_operation(
     _ensure_live_env(env, booth_env)
 
     if not site_ip:
+        site_error = LibraryError(
+            ReportItem.error(reports.messages.BoothCannotDetermineLocalSiteIp())
+        )
+
+        try:
+            cib = env.get_cib()
+        except LibraryError as e:
+            raise site_error from e
+
         site_ip_list = resource.find_bound_ip(
-            get_resources(env.get_cib()), booth_env.config_path
+            get_resources(cib), booth_env.config_path
         )
         if len(site_ip_list) != 1:
-            raise LibraryError(
-                ReportItem.error(
-                    reports.messages.BoothCannotDetermineLocalSiteIp()
-                )
-            )
+            raise site_error
+
         site_ip = site_ip_list[0]
 
     stdout, stderr, return_code = env.cmd_runner().run(
-        [settings.booth_binary, operation, "-s", site_ip, ticket_name]
+        [settings.booth_exec, operation, "-s", site_ip, ticket_name]
     )
 
     if return_code != 0:
@@ -866,9 +869,6 @@ def pull_config(env: LibraryEnvironment, node_name, instance_name=None):
     com_cmd.set_targets(
         [env.get_node_target_factory().get_target_from_hostname(node_name)]
     )
-    # pylint: disable=unsubscriptable-object
-    # In general, pylint is right. And it cannot know in this case code is OK.
-    # It is covered by tests.
     output = run_and_raise(env.get_node_communicator(), com_cmd)[0][1]
     try:
         # TODO adapt to new file transfer framework once it is written
