@@ -209,7 +209,6 @@ def setup(
     # pylint: disable=too-many-arguments
     # pylint: disable=too-many-locals
     # pylint: disable=too-many-statements
-    # pylint: disable=too-many-branches
     """
     Set up cluster on specified nodes.
     Validation of the inputs is done here. Possible existing clusters are
@@ -846,7 +845,9 @@ def add_nodes(
     no_watchdog_validation=False,
     force_flags: Collection[reports.types.ForceCode] = (),
 ):
-    # pylint: disable=too-many-locals, too-many-statements, too-many-branches
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
     """
     Add specified nodes to the local cluster
     Raise LibraryError on any error.
@@ -1080,18 +1081,26 @@ def add_nodes(
         env.service_manager, corosync_conf, len(new_nodes)
     )
     if atb_has_to_be_enabled:
-        report_processor.report(
-            ReportItem.warning(
-                reports.messages.CorosyncQuorumAtbWillBeEnabledDueToSbd()
-            )
-        )
         if online_cluster_target_list:
             com_cmd = CheckCorosyncOffline(
-                report_processor,
-                allow_skip_offline=False,
+                report_processor, allow_skip_offline=False
             )
             com_cmd.set_targets(online_cluster_target_list)
-            run_com(env.get_node_communicator(), com_cmd)
+            cluster_running_target_list = run_com(
+                env.get_node_communicator(), com_cmd
+            )
+            if cluster_running_target_list:
+                report_processor.report(
+                    ReportItem.error(
+                        reports.messages.CorosyncQuorumAtbWillBeEnabledDueToSbdClusterIsRunning()
+                    )
+                )
+            else:
+                report_processor.report(
+                    ReportItem.warning(
+                        reports.messages.CorosyncQuorumAtbWillBeEnabledDueToSbd()
+                    )
+                )
 
     # Validate new nodes. All new nodes have to be online.
     com_cmd = GetHostInfo(report_processor)
@@ -1120,7 +1129,6 @@ def add_nodes(
             # Do not send watchdog if validation is turned off. Listing of
             # available watchdogs in pcsd may restart the machine in some
             # corner cases.
-            # pylint: disable=unexpected-keyword-arg
             com_cmd_sbd.add_request(
                 new_node_target,
                 watchdog="" if no_watchdog_validation else new_node["watchdog"],
@@ -1177,7 +1185,6 @@ def add_nodes(
         com_cmd_sbd_cfg = SetSbdConfig(env.report_processor)
         for new_node_target in new_nodes_target_list:
             new_node = new_nodes_dict[new_node_target.label]
-            # pylint: disable=too-many-function-args
             com_cmd_sbd_cfg.add_request(
                 new_node_target,
                 sbd.create_sbd_config(
@@ -1712,7 +1719,9 @@ def remove_nodes(
     node_list,
     force_flags: Collection[reports.types.ForceCode] = (),
 ):
-    # pylint: disable=too-many-locals, too-many-branches, too-many-statements
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
     """
     Remove nodes from a cluster.
 
@@ -1818,17 +1827,25 @@ def remove_nodes(
         env.service_manager, corosync_conf, -len(node_list)
     )
     if atb_has_to_be_enabled:
-        report_processor.report(
-            ReportItem.warning(
-                reports.messages.CorosyncQuorumAtbWillBeEnabledDueToSbd()
-            )
-        )
         com_cmd = CheckCorosyncOffline(
-            report_processor,
-            allow_skip_offline=False,
+            report_processor, allow_skip_offline=False
         )
         com_cmd.set_targets(staying_online_target_list)
-        run_com(env.get_node_communicator(), com_cmd)
+        cluster_running_target_list = run_com(
+            env.get_node_communicator(), com_cmd
+        )
+        if cluster_running_target_list:
+            report_processor.report(
+                ReportItem.error(
+                    reports.messages.CorosyncQuorumAtbWillBeEnabledDueToSbdClusterIsRunning()
+                )
+            )
+        else:
+            report_processor.report(
+                ReportItem.warning(
+                    reports.messages.CorosyncQuorumAtbWillBeEnabledDueToSbd()
+                )
+            )
     else:
         # Check if removing the nodes would cause quorum loss. We ask the nodes
         # to be removed for their view of quorum. If they are all stopped or
@@ -1937,7 +1954,7 @@ def remove_nodes_from_cib(env: LibraryEnvironment, node_list):
     for node in node_list:
         stdout, stderr, retval = env.cmd_runner().run(
             [
-                settings.cibadmin,
+                settings.cibadmin_exec,
                 "--delete-all",
                 "--force",
                 f"--xpath=/cib/configuration/nodes/node[@uname='{node}']",
