@@ -3,52 +3,68 @@ import binascii
 from typing import List
 
 from pcs.common import reports
-from pcs.common.reports import (
-    codes as report_codes,
-    ReportProcessor,
-)
+from pcs.common.file import RawFileError
+from pcs.common.reports import ReportProcessor
+from pcs.common.reports import codes as report_codes
 from pcs.common.reports.item import (
-    get_severity,
     ReportItem,
+    get_severity,
 )
+from pcs.common.services.errors import ManageServiceError
+from pcs.common.services.interfaces import ServiceManagerInterface
 from pcs.lib import external
 from pcs.lib.corosync import qdevice_net
 from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
+from pcs.lib.file.instance import FileInstance
+from pcs.lib.file.raw_file import raw_file_error_report
+from pcs.lib.services import service_exception_to_report
 
 
 def qdevice_setup(lib_env: LibraryEnvironment, model, enable, start):
     """
     Initialize qdevice on local host with specified model
-    string model qdevice model to initialize
-    bool enable make qdevice service start on boot
-    bool start start qdevice now
+
+    string model -- qdevice model to initialize
+    bool enable -- make qdevice service start on boot
+    bool start -- start qdevice now
     """
     _check_model(model)
     qdevice_net.qdevice_setup(lib_env.cmd_runner())
-    lib_env.report_processor.report(
+    report_processor = lib_env.report_processor
+    service_manager = lib_env.service_manager
+    report_processor.report(
         ReportItem.info(reports.messages.QdeviceInitializationSuccess(model))
     )
     if enable:
-        _service_enable(lib_env, qdevice_net.qdevice_enable)
+        _service_enable(
+            report_processor, service_manager, qdevice_net.SERVICE_NAME
+        )
     if start:
-        _service_start(lib_env, qdevice_net.qdevice_start)
+        _service_start(
+            report_processor, service_manager, qdevice_net.SERVICE_NAME
+        )
 
 
 def qdevice_destroy(lib_env: LibraryEnvironment, model, proceed_if_used=False):
     """
     Stop and disable qdevice on local host and remove its configuration
-    string model qdevice model to destroy
-    bool procced_if_used destroy qdevice even if it is used by clusters
+
+    string model -- qdevice model to destroy
+    bool procced_if_used -- destroy qdevice even if it is used by clusters
     """
     _check_model(model)
+    report_processor = lib_env.report_processor
+    service_manager = lib_env.service_manager
     _check_qdevice_not_used(
-        lib_env.report_processor, lib_env.cmd_runner(), model, proceed_if_used
+        report_processor, lib_env.cmd_runner(), model, proceed_if_used
+    )
+    _service_stop(report_processor, service_manager, qdevice_net.SERVICE_NAME)
+    _service_disable(
+        report_processor, service_manager, qdevice_net.SERVICE_NAME
     )
-    _service_stop(lib_env, qdevice_net.qdevice_stop)
-    _service_disable(lib_env, qdevice_net.qdevice_disable)
     qdevice_net.qdevice_destroy()
-    lib_env.report_processor.report(
+    report_processor.report(
         ReportItem.info(reports.messages.QdeviceDestroySuccess(model))
     )
 
@@ -61,9 +77,10 @@ def qdevice_status_text(
 ):
     """
     Get runtime status of a quorum device in plain text
-    string model qdevice model to query
-    bool verbose get more detailed output
-    string cluster show information only about specified cluster
+
+    string model -- qdevice model to query
+    bool verbose -- get more detailed output
+    string cluster -- show information only about specified cluster
     """
     _check_model(model)
     runner = lib_env.cmd_runner()
@@ -82,7 +99,11 @@ def qdevice_enable(lib_env: LibraryEnvironment, model):
     make qdevice start automatically on boot on local host
     """
     _check_model(model)
-    _service_enable(lib_env, qdevice_net.qdevice_enable)
+    _service_enable(
+        lib_env.report_processor,
+        lib_env.service_manager,
+        qdevice_net.SERVICE_NAME,
+    )
 
 
 def qdevice_disable(lib_env: LibraryEnvironment, model):
@@ -90,7 +111,11 @@ def qdevice_disable(lib_env: LibraryEnvironment, model):
     make qdevice not start automatically on boot on local host
     """
     _check_model(model)
-    _service_disable(lib_env, qdevice_net.qdevice_disable)
+    _service_disable(
+        lib_env.report_processor,
+        lib_env.service_manager,
+        qdevice_net.SERVICE_NAME,
+    )
 
 
 def qdevice_start(lib_env: LibraryEnvironment, model):
@@ -102,20 +127,29 @@ def qdevice_start(lib_env: LibraryEnvironment, model):
         raise LibraryError(
             ReportItem.error(reports.messages.QdeviceNotInitialized(model))
         )
-    _service_start(lib_env, qdevice_net.qdevice_start)
+    _service_start(
+        lib_env.report_processor,
+        lib_env.service_manager,
+        qdevice_net.SERVICE_NAME,
+    )
 
 
 def qdevice_stop(lib_env: LibraryEnvironment, model, proceed_if_used=False):
     """
     stop qdevice now on local host
-    string model qdevice model to destroy
-    bool procced_if_used stop qdevice even if it is used by clusters
+
+    string model -- qdevice model to destroy
+    bool procced_if_used -- stop qdevice even if it is used by clusters
     """
     _check_model(model)
     _check_qdevice_not_used(
         lib_env.report_processor, lib_env.cmd_runner(), model, proceed_if_used
     )
-    _service_stop(lib_env, qdevice_net.qdevice_stop)
+    _service_stop(
+        lib_env.report_processor,
+        lib_env.service_manager,
+        qdevice_net.SERVICE_NAME,
+    )
 
 
 def qdevice_kill(lib_env: LibraryEnvironment, model):
@@ -123,18 +157,32 @@ def qdevice_kill(lib_env: LibraryEnvironment, model):
     kill qdevice now on local host
     """
     _check_model(model)
-    _service_kill(lib_env, qdevice_net.qdevice_kill)
+    _service_kill(lib_env, qdevice_net.SERVICE_NAME)
+
+
+def qdevice_net_get_ca_certificate(lib_env: LibraryEnvironment) -> str:
+    """
+    get base64 encoded qnetd CA certificate
+    """
+    try:
+        return base64.b64encode(
+            FileInstance.for_qnetd_ca_cert().read_raw()
+        ).decode()
+    except RawFileError as e:
+        lib_env.report_processor.report(raw_file_error_report(e))
+        raise LibraryError() from e
 
 
 def qdevice_net_sign_certificate_request(
     lib_env: LibraryEnvironment,
-    certificate_request,
-    cluster_name,
-):
+    certificate_request: str,
+    cluster_name: str,
+) -> str:
     """
-    Sign node certificate request by qnetd CA
-    string certificate_request base64 encoded certificate request
-    string cluster_name name of the cluster to which qdevice is being added
+    Sign node certificate request by qnetd CA and return it base64 encoded
+
+    certificate_request -- base64 encoded certificate request
+    cluster_name -- name of the cluster to which qdevice is being added
     """
     try:
         certificate_request_data = base64.b64decode(certificate_request)
@@ -152,13 +200,14 @@ def qdevice_net_sign_certificate_request(
         qdevice_net.qdevice_sign_certificate_request(
             lib_env.cmd_runner(), certificate_request_data, cluster_name
         )
-    )
+    ).decode()
 
 
-def client_net_setup(lib_env: LibraryEnvironment, ca_certificate):
+def client_net_setup(lib_env: LibraryEnvironment, ca_certificate: str) -> None:
     """
-    Intialize qdevice net client on local host
-    ca_certificate base64 encoded qnetd CA certificate
+    Initialize qdevice net client on local host
+
+    ca_certificate -- base64 encoded qnetd CA certificate
     """
     try:
         ca_certificate_data = base64.b64decode(ca_certificate)
@@ -175,10 +224,13 @@ def client_net_setup(lib_env: LibraryEnvironment, ca_certificate):
     qdevice_net.client_setup(lib_env.cmd_runner(), ca_certificate_data)
 
 
-def client_net_import_certificate(lib_env: LibraryEnvironment, certificate):
+def client_net_import_certificate(
+    lib_env: LibraryEnvironment, certificate: str
+) -> None:
     """
     Import qnetd client certificate to local node certificate storage
-    certificate base64 encoded qnetd client certificate
+
+    certificate -- base64 encoded qnetd client certificate
     """
     try:
         certificate_data = base64.b64decode(certificate)
@@ -197,11 +249,11 @@ def client_net_import_certificate(lib_env: LibraryEnvironment, certificate):
     )
 
 
-def client_net_destroy(lib_env: LibraryEnvironment):
-    # pylint: disable=unused-argument
+def client_net_destroy(lib_env: LibraryEnvironment) -> None:
     """
     delete qdevice client config files on local host
     """
+    del lib_env
     qdevice_net.client_destroy()
 
 
@@ -228,7 +280,7 @@ def _check_qdevice_not_used(
     if connected_clusters:
         reporter.report(
             ReportItem(
-                severity=get_severity(report_codes.FORCE_QDEVICE_USED, force),
+                severity=get_severity(report_codes.FORCE, force),
                 message=reports.messages.QdeviceUsedByClusters(
                     connected_clusters,
                 ),
@@ -238,8 +290,12 @@ def _check_qdevice_not_used(
             raise LibraryError()
 
 
-def _service_start(lib_env: LibraryEnvironment, func):
-    lib_env.report_processor.report(
+def _service_start(
+    report_processor: ReportProcessor,
+    service_manager: ServiceManagerInterface,
+    service: str,
+) -> None:
+    report_processor.report(
         ReportItem.info(
             reports.messages.ServiceActionStarted(
                 reports.const.SERVICE_ACTION_START, "quorum device"
@@ -247,16 +303,10 @@ def _service_start(lib_env: LibraryEnvironment, func):
         )
     )
     try:
-        func(lib_env.cmd_runner())
-    except external.StartServiceError as e:
-        raise LibraryError(
-            ReportItem.error(
-                reports.messages.ServiceActionFailed(
-                    reports.const.SERVICE_ACTION_START, e.service, e.message
-                )
-            )
-        ) from e
-    lib_env.report_processor.report(
+        service_manager.start(service)
+    except ManageServiceError as e:
+        raise LibraryError(service_exception_to_report(e)) from e
+    report_processor.report(
         ReportItem.info(
             reports.messages.ServiceActionSucceeded(
                 reports.const.SERVICE_ACTION_START,
@@ -266,8 +316,12 @@ def _service_start(lib_env: LibraryEnvironment, func):
     )
 
 
-def _service_stop(lib_env: LibraryEnvironment, func):
-    lib_env.report_processor.report(
+def _service_stop(
+    report_processor: ReportProcessor,
+    service_manager: ServiceManagerInterface,
+    service: str,
+) -> None:
+    report_processor.report(
         ReportItem.info(
             reports.messages.ServiceActionStarted(
                 reports.const.SERVICE_ACTION_STOP, "quorum device"
@@ -275,16 +329,10 @@ def _service_stop(lib_env: LibraryEnvironment, func):
         )
     )
     try:
-        func(lib_env.cmd_runner())
-    except external.StopServiceError as e:
-        raise LibraryError(
-            ReportItem.error(
-                reports.messages.ServiceActionFailed(
-                    reports.const.SERVICE_ACTION_STOP, e.service, e.message
-                )
-            )
-        ) from e
-    lib_env.report_processor.report(
+        service_manager.stop(service)
+    except ManageServiceError as e:
+        raise LibraryError(service_exception_to_report(e)) from e
+    report_processor.report(
         ReportItem.info(
             reports.messages.ServiceActionSucceeded(
                 reports.const.SERVICE_ACTION_STOP, "quorum device"
@@ -293,9 +341,9 @@ def _service_stop(lib_env: LibraryEnvironment, func):
     )
 
 
-def _service_kill(lib_env: LibraryEnvironment, func):
+def _service_kill(lib_env: LibraryEnvironment, service: str) -> None:
     try:
-        func(lib_env.cmd_runner())
+        external.kill_services(lib_env.cmd_runner(), [service])
     except external.KillServicesError as e:
         raise LibraryError(
             *[
@@ -316,20 +364,16 @@ def _service_kill(lib_env: LibraryEnvironment, func):
     )
 
 
-def _service_enable(lib_env: LibraryEnvironment, func):
+def _service_enable(
+    report_processor: ReportProcessor,
+    service_manager: ServiceManagerInterface,
+    service: str,
+) -> None:
     try:
-        func(lib_env.cmd_runner())
-    except external.EnableServiceError as e:
-        raise LibraryError(
-            ReportItem.error(
-                reports.messages.ServiceActionFailed(
-                    reports.const.SERVICE_ACTION_ENABLE,
-                    e.service,
-                    e.message,
-                )
-            )
-        ) from e
-    lib_env.report_processor.report(
+        service_manager.enable(service)
+    except ManageServiceError as e:
+        raise LibraryError(service_exception_to_report(e)) from e
+    report_processor.report(
         ReportItem.info(
             reports.messages.ServiceActionSucceeded(
                 reports.const.SERVICE_ACTION_ENABLE, "quorum device"
@@ -338,20 +382,16 @@ def _service_enable(lib_env: LibraryEnvironment, func):
     )
 
 
-def _service_disable(lib_env: LibraryEnvironment, func):
+def _service_disable(
+    report_processor: ReportProcessor,
+    service_manager: ServiceManagerInterface,
+    service: str,
+) -> None:
     try:
-        func(lib_env.cmd_runner())
-    except external.DisableServiceError as e:
-        raise LibraryError(
-            ReportItem.error(
-                reports.messages.ServiceActionFailed(
-                    reports.const.SERVICE_ACTION_DISABLE,
-                    e.service,
-                    e.message,
-                )
-            )
-        ) from e
-    lib_env.report_processor.report(
+        service_manager.disable(service)
+    except ManageServiceError as e:
+        raise LibraryError(service_exception_to_report(e)) from e
+    report_processor.report(
         ReportItem.info(
             reports.messages.ServiceActionSucceeded(
                 reports.const.SERVICE_ACTION_DISABLE, "quorum device"
