@@ -1,4 +1,5 @@
 # pylint: disable=too-many-lines
+import re
 from contextlib import contextmanager
 from functools import partial
 from typing import (
@@ -363,7 +364,8 @@ def create(
     allow_not_suitable_command: bool = False,
     enable_agent_self_validation: bool = False,
 ):
-    # pylint: disable=too-many-arguments, too-many-locals
+    # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-locals
     """
     Create a primitive resource in a cib.
 
@@ -471,7 +473,8 @@ def create_as_clone(
     allow_incompatible_clone_meta_attributes: bool = False,
     enable_agent_self_validation: bool = False,
 ):
-    # pylint: disable=too-many-arguments, too-many-locals
+    # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-locals
     """
     Create a primitive resource in a clone
 
@@ -619,7 +622,8 @@ def create_in_group(
     allow_not_suitable_command: bool = False,
     enable_agent_self_validation: bool = False,
 ):
-    # pylint: disable=too-many-arguments, too-many-locals
+    # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-locals
     """
     Create resource in a cib and put it into defined group
 
@@ -763,7 +767,8 @@ def create_into_bundle(
     allow_not_accessible_resource: bool = False,
     enable_agent_self_validation: bool = False,
 ):
-    # pylint: disable=too-many-arguments, too-many-locals
+    # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-locals
     """
     Create a new resource in a cib and put it into an existing bundle
 
@@ -1223,7 +1228,6 @@ def disable_safe(
     strict -- if False, allow resources to be migrated
     wait -- False: no wait, None: wait default timeout, int: wait timeout
     """
-    # pylint: disable=too-many-locals
     if not env.is_cib_live:
         raise LibraryError(
             ReportItem.error(
@@ -1707,6 +1711,16 @@ def _nodes_exist_reports(
     ]
 
 
+class ResourceMoveAutocleanSimulationFailure(Exception):
+    def __init__(self, other_resources_affected: bool):
+        super().__init__()
+        self._other_resources_affected = other_resources_affected
+
+    @property
+    def other_resources_affected(self) -> bool:
+        return self._other_resources_affected
+
+
 def move_autoclean(
     env: LibraryEnvironment,
     resource_id: str,
@@ -1728,7 +1742,9 @@ def move_autoclean(
     strict -- if True affecting other resources than the specified resource
         will cause failure. If False affecting other resources is allowed.
     """
+    # pylint: disable=too-many-branches
     # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
     wait_timeout = max(wait_timeout, 0)
     if not env.is_cib_live:
         raise LibraryError(
@@ -1765,6 +1781,8 @@ def move_autoclean(
             )
         )
 
+    # add a move constraint to a temporary cib and get a cib diff which adds
+    # the move constraint
     with get_tmp_cib(env.report_processor, cib_xml) as rsc_moved_cib_file:
         stdout, stderr, retval = resource_move(
             env.cmd_runner(dict(CIB_file=rsc_moved_cib_file.name)),
@@ -1777,15 +1795,16 @@ def move_autoclean(
 
     if retval != 0:
         raise LibraryError(
-            ReportItem.error(
-                reports.messages.ResourceMovePcmkError(
-                    resource_id, stdout, stderr
-                )
+            _move_ban_pcmk_error_report(
+                resource_id, stdout, stderr, is_ban=False
             )
         )
     add_constraint_cib_diff = diff_cibs_xml(
         env.cmd_runner(), env.report_processor, cib_xml, rsc_moved_cib_xml
     )
+
+    # clear the move constraint from the temporary cib and get a cib diff which
+    # removes the move constraint
     with get_tmp_cib(
         env.report_processor, rsc_moved_cib_xml
     ) as rsc_moved_constraint_cleared_cib_file:
@@ -1814,16 +1833,19 @@ def move_autoclean(
         constraint_removed_cib,
     )
 
+    # if both the diffs are no-op, nothing needs to be done
     if not (add_constraint_cib_diff and remove_constraint_cib_diff):
         env.report_processor.report(
             reports.ReportItem.info(reports.messages.NoActionNecessary())
         )
         return
 
+    # simulate applying the diff which adds the move constraint
     _, move_transitions, after_move_simulated_cib = simulate_cib(
         env.cmd_runner(), get_cib(rsc_moved_cib_xml)
     )
     if strict:
+        # check if other resources would be affected
         resources_affected_by_move = (
             simulate_tools.get_resources_from_operations(
                 simulate_tools.get_operations_from_transitions(
@@ -1840,16 +1862,37 @@ def move_autoclean(
                     )
                 )
             )
-    _ensure_resource_moved_and_not_moved_back(
-        env.cmd_runner,
-        env.report_processor,
-        etree_to_str(after_move_simulated_cib),
-        remove_constraint_cib_diff,
-        resource_id,
-        strict,
-        resource_state_before,
-        node,
-    )
+    # verify that:
+    # - a cib with added move constraint causes the resource to move by
+    #   comparing the original status of the resource with a status computed
+    #   from the cib with the added constraint
+    # - applying the diff which removes the move constraint won't trigger
+    #   moving the resource (or other resources) around
+    try:
+        _ensure_resource_moved_and_not_moved_back(
+            env.cmd_runner,
+            env.report_processor,
+            etree_to_str(after_move_simulated_cib),
+            remove_constraint_cib_diff,
+            resource_id,
+            strict,
+            resource_state_before,
+            node,
+        )
+    except ResourceMoveAutocleanSimulationFailure as e:
+        raise LibraryError(
+            reports.ReportItem.error(
+                reports.messages.ResourceMoveAutocleanSimulationFailure(
+                    resource_id,
+                    e.other_resources_affected,
+                    node=node,
+                    move_constraint_left_in_cib=False,
+                )
+            )
+        ) from e
+
+    # apply the diff which adds the move constraint to the live cib and wait
+    # for the cluster to settle
     push_cib_diff_xml(env.cmd_runner(), add_constraint_cib_diff)
     env.report_processor.report(
         ReportItem.info(
@@ -1857,16 +1900,36 @@ def move_autoclean(
         )
     )
     env.wait_for_idle(wait_timeout)
-    _ensure_resource_moved_and_not_moved_back(
-        env.cmd_runner,
-        env.report_processor,
-        get_cib_xml(env.cmd_runner()),
-        remove_constraint_cib_diff,
-        resource_id,
-        strict,
-        resource_state_before,
-        node,
-    )
+    # verify that:
+    # - the live cib (now containing the move constraint) causes the resource
+    #   to move by comparing the original status of the resource with a status
+    #   computed from the live cib
+    # - applying the diff which removes the move constraint won't trigger
+    #   moving the resource (or other resources) around
+    try:
+        _ensure_resource_moved_and_not_moved_back(
+            env.cmd_runner,
+            env.report_processor,
+            get_cib_xml(env.cmd_runner()),
+            remove_constraint_cib_diff,
+            resource_id,
+            strict,
+            resource_state_before,
+            node,
+        )
+    except ResourceMoveAutocleanSimulationFailure as e:
+        raise LibraryError(
+            reports.ReportItem.error(
+                reports.messages.ResourceMoveAutocleanSimulationFailure(
+                    resource_id,
+                    e.other_resources_affected,
+                    node=node,
+                    move_constraint_left_in_cib=True,
+                )
+            )
+        ) from e
+    # apply the diff which removes the move constraint to the live cib and wait
+    # for the cluster to settle
     push_cib_diff_xml(env.cmd_runner(), remove_constraint_cib_diff)
     env.report_processor.report(
         ReportItem.info(
@@ -1895,7 +1958,6 @@ def _ensure_resource_moved_and_not_moved_back(
     resource_state_before: Dict[str, List[str]],
     node: Optional[str],
 ) -> None:
-    # pylint: disable=too-many-locals
     with get_tmp_cib(report_processor, cib_xml) as rsc_unmove_cib_file:
         if not _was_resource_moved(
             node,
@@ -1932,13 +1994,7 @@ def _ensure_resource_moved_and_not_moved_back(
     )
     if strict:
         if clean_operations:
-            raise LibraryError(
-                reports.ReportItem.error(
-                    reports.messages.ResourceMoveAutocleanSimulationFailure(
-                        resource_id, others_affected=True
-                    )
-                )
-            )
+            raise ResourceMoveAutocleanSimulationFailure(True)
     else:
         if any(
             rsc == resource_id
@@ -1946,13 +2002,7 @@ def _ensure_resource_moved_and_not_moved_back(
                 clean_operations
             )
         ):
-            raise LibraryError(
-                reports.ReportItem.error(
-                    reports.messages.ResourceMoveAutocleanSimulationFailure(
-                        resource_id, others_affected=False
-                    )
-                )
-            )
+            raise ResourceMoveAutocleanSimulationFailure(False)
 
 
 def ban(env, resource_id, node=None, master=False, lifetime=None, wait=False):
@@ -2024,19 +2074,52 @@ def _move_wait_report(
     )
 
 
+def _move_ban_pcmk_error_report(
+    resource_id: str, stdout: str, stderr: str, is_ban: bool
+) -> reports.ReportItem:
+    active_in_locations = re.search(
+        f"Resource '{resource_id}' not moved: active in (?P<locations>\\d+) locations",
+        stderr,
+    )
+    if active_in_locations:
+        if active_in_locations.group("locations") == "0":
+            message_stopped = (
+                reports.messages.CannotBanResourceStoppedNoNodeSpecified
+                if is_ban
+                else reports.messages.CannotMoveResourceStoppedNoNodeSpecified
+            )
+            return reports.ReportItem.error(message_stopped(resource_id))
+        message_multiple = (
+            reports.messages.CannotBanResourceMultipleInstancesNoNodeSpecified
+            if is_ban
+            else reports.messages.CannotMoveResourceMultipleInstancesNoNodeSpecified
+        )
+        return reports.ReportItem.error(message_multiple(resource_id))
+
+    if not is_ban and "Multiple items match request" in stderr:
+        return reports.ReportItem.error(
+            reports.messages.CannotMoveResourceMultipleInstances(resource_id)
+        )
+
+    message_generic = (
+        reports.messages.ResourceBanPcmkError
+        if is_ban
+        else reports.messages.ResourceMovePcmkError
+    )
+    return reports.ReportItem.error(
+        message_generic(resource_id, stdout, stderr)
+    )
+
+
 class _MoveBanTemplate:
+    _is_ban = False
+
     def _validate(self, resource_el, master):
         raise NotImplementedError()
 
     def _run_action(self, runner, resource_id, node, master, lifetime):
         raise NotImplementedError()
 
-    def _report_action_stopped_resource(self, resource_id):
-        raise NotImplementedError()
-
-    def _report_action_pcmk_error(self, resource_id, stdout, stderr):
-        raise NotImplementedError()
-
     def _report_action_pcmk_success(self, resource_id, stdout, stderr):
         raise NotImplementedError()
 
@@ -2094,18 +2177,13 @@ class _MoveBanTemplate:
             master=master,
             lifetime=lifetime,
         )
-
         if retval != 0:
-            if (
-                f"Resource '{resource_id}' not moved: active in 0 locations"
-                in stderr
-            ):
-                raise LibraryError(
-                    self._report_action_stopped_resource(resource_id)
-                )
             raise LibraryError(
-                self._report_action_pcmk_error(resource_id, stdout, stderr)
+                _move_ban_pcmk_error_report(
+                    resource_id, stdout, stderr, self._is_ban
+                )
             )
+
         if node and not stdout and not stderr:
             env.report_processor.report_list(
                 self._report_resource_may_or_may_not_move(resource_id)
@@ -2140,18 +2218,6 @@ class _Move(_MoveBanTemplate):
             runner, resource_id, node=node, master=master, lifetime=lifetime
         )
 
-    def _report_action_stopped_resource(self, resource_id):
-        return ReportItem.error(
-            reports.messages.CannotMoveResourceStoppedNoNodeSpecified(
-                resource_id
-            )
-        )
-
-    def _report_action_pcmk_error(self, resource_id, stdout, stderr):
-        return ReportItem.error(
-            reports.messages.ResourceMovePcmkError(resource_id, stdout, stderr)
-        )
-
     def _report_action_pcmk_success(self, resource_id, stdout, stderr):
         return ReportItem.info(
             reports.messages.ResourceMovePcmkSuccess(
@@ -2187,6 +2253,8 @@ class _Move(_MoveBanTemplate):
 
 
 class _Ban(_MoveBanTemplate):
+    _is_ban = True
+
     def _validate(self, resource_el, master):
         return resource.validations.validate_ban(resource_el, master)
 
@@ -2195,18 +2263,6 @@ class _Ban(_MoveBanTemplate):
             runner, resource_id, node=node, master=master, lifetime=lifetime
         )
 
-    def _report_action_stopped_resource(self, resource_id):
-        return ReportItem.error(
-            reports.messages.CannotBanResourceStoppedNoNodeSpecified(
-                resource_id,
-            )
-        )
-
-    def _report_action_pcmk_error(self, resource_id, stdout, stderr):
-        return ReportItem.error(
-            reports.messages.ResourceBanPcmkError(resource_id, stdout, stderr)
-        )
-
     def _report_action_pcmk_success(
         self,
         resource_id: str,
