@@ -98,8 +98,8 @@ class StonithWatchdogTimeoutAction(
         )
         if report_item is None:
             self._on_success()
-            return []
-        self._report(report_item)
+        else:
+            self._report(report_item)
         return self._get_next_list()
 
 
@@ -275,7 +275,9 @@ class CheckSbd(AllAtOnceStrategyMixin, RunRemotelyBase):
             if not data["sbd"]["installed"]:
                 report_list.append(
                     ReportItem.error(
-                        reports.messages.SbdNotInstalled(node_label)
+                        reports.messages.ServiceNotInstalled(
+                            node_label, ["sbd"]
+                        )
                     )
                 )
             if "watchdog" in data:
