@@ -41,8 +41,10 @@ _QDEVICE_NET_REQUIRED_OPTIONS = (
 _QDEVICE_NET_OPTIONAL_OPTIONS = (
     "connect_timeout",
     "force_ip_version",
+    "keep_active_partition_tie_breaker",
     "port",
     "tie_breaker",
+    "tls",
 )
 
 
@@ -99,8 +101,8 @@ def create(
     force_unresolvable: bool = False,
     force_cluster_name: bool = False,
 ) -> ReportItemList:
-    # pylint: disable=too-many-locals
     # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
     # pylint: disable=too-many-statements
     """
     Validate creating a new minimalistic corosync.conf
@@ -407,8 +409,8 @@ def add_nodes(
     pcmk_existing_nodes: Iterable[PacemakerNode],
     force_unresolvable: bool = False,
 ) -> ReportItemList:
-    # pylint: disable=too-many-locals
     # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
     # pylint: disable=too-many-statements
     """
     Validate adding nodes to a config with a nonempty nodelist
@@ -792,7 +794,6 @@ def create_link_list_knet(
                         # Links are defined by node addresses. Therefore we
                         # update link options here, we do not create links.
                         ReportItem.error(
-                            # pylint: disable=line-too-long
                             reports.messages.CorosyncLinkDoesNotExistCannotUpdate(
                                 options["linknumber"],
                                 [str(x) for x in range(max_allowed_link_count)],
@@ -860,9 +861,9 @@ def _get_link_options_validators_knet(
     )
 
 
-def _get_link_options_validators_knet_relations() -> list[
-    validate.ValidatorInterface
-]:
+def _get_link_options_validators_knet_relations() -> (
+    list[validate.ValidatorInterface]
+):
     return [
         validate.DependsOnOption(
             ["ping_interval"],
@@ -2112,6 +2113,12 @@ def _get_qdevice_model_net_options_validators(
             ["lowest", "highest"] + sorted(node_ids),
             severity=severity,
         ),
+        validate.ValueIn("tls", ("on", "off", "required"), severity=severity),
+        validate.ValueIn(
+            "keep_active_partition_tie_breaker",
+            ("on", "off"),
+            severity=severity,
+        ),
     ]
 
     if allow_empty_values:
