@@ -1,18 +1,20 @@
 """
 The intention is put there knowledge about cluster state structure.
-Hide information about underlaying xml is desired too.
+Hide information about underlying xml is desired too.
 """
-import os.path
 from collections import defaultdict
-from typing import Dict, Any
+from typing import (
+    Any,
+    Dict,
+)
 
 from lxml import etree
 
-from pcs import settings
-from pcs.common import reports
-from pcs.common.tools import xml_fromstring
+from pcs.common import (
+    const,
+    reports,
+)
 from pcs.common.reports.item import ReportItem
-from pcs.lib.errors import LibraryError
 from pcs.lib.pacemaker.values import (
     is_false,
     is_true,
@@ -24,11 +26,14 @@ class ResourceNotFound(Exception):
     pass
 
 
+_id_xpath_predicate = "(@id=$id or starts-with(@id, concat($id, ':')))"
+
+
 class _Attrs:
     def __init__(self, owner_name, attrib, required_attrs):
         """
         attrib lxml.etree._Attrib - wrapped attribute collection
-        required_attrs dict of required atribute names object_name:xml_attribute
+        required_attrs dict of required attribute names object_name:xml_attribute
         """
         self.owner_name = owner_name
         self.attrib = attrib
@@ -44,15 +49,12 @@ class _Attrs:
                 return self.attrib[attr_specification]
             except KeyError as e:
                 raise AttributeError(
-                    "Missing attribute '{0}' ('{1}' in source) in '{2}'".format(
-                        name, self.required_attrs[name], self.owner_name
-                    )
+                    f"Missing attribute '{name}' ('{self.required_attrs[name]}' "
+                    f"in source) in '{self.owner_name}'"
                 ) from e
 
         raise AttributeError(
-            "'{0}' does not declare attribute '{1}'".format(
-                self.owner_name, name
-            )
+            f"'{self.owner_name}' does not declare attribute '{name}'"
         )
 
 
@@ -68,17 +70,21 @@ class _Children:
             element_name, wrapper = self.children[name]
             return [
                 wrapper(element)
-                for element in self.dom_part.findall(".//" + element_name)
+                for element in self.dom_part.xpath(
+                    ".//*[local-name()=$tag_name]", tag_name=element_name
+                )
             ]
 
         if name in self.sections.keys():
             element_name, wrapper = self.sections[name]
-            return wrapper(self.dom_part.findall(".//" + element_name)[0])
+            return wrapper(
+                self.dom_part.xpath(
+                    ".//*[local-name()=$tag_name]", tag_name=element_name
+                )[0]
+            )
 
         raise AttributeError(
-            "'{0}' does not declare child or section '{1}'".format(
-                self.owner_name, name
-            )
+            f"'{self.owner_name}' does not declare child or section '{name}'"
         )
 
 
@@ -90,7 +96,7 @@ class _Element:
     # Note: not properly typed
     sections: Dict[Any, Any] = {}
 
-    def __init__(self, dom_part):
+    def __init__(self, dom_part: etree._Element):
         self.dom_part = dom_part
         self.attrs = _Attrs(
             self.__class__.__name__, self.dom_part.attrib, self.required_attrs
@@ -149,36 +155,12 @@ class _NodeSection(_Element):
     }
 
 
-def _validate_cluster_state_dom(dom):
-    if os.path.isfile(settings.crm_mon_schema):
-        etree.RelaxNG(file=settings.crm_mon_schema).assertValid(dom)
-
-
-def get_cluster_state_dom(xml):
-    try:
-        dom = xml_fromstring(xml)
-        _validate_cluster_state_dom(dom)
-        return dom
-    except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
-        raise LibraryError(
-            ReportItem.error(reports.messages.BadClusterStateFormat())
-        ) from e
-
-
 class ClusterState(_Element):
     sections = {
         "summary": ("summary", _SummarySection),
         "node_section": ("nodes", _NodeSection),
     }
 
-    def __init__(self, xml):
-        self.dom = get_cluster_state_dom(xml)
-        super().__init__(self.dom)
-
-
-def _id_xpath_predicate(resource_id):
-    return """(@id="{0}" or starts-with(@id, "{0}:"))""".format(resource_id)
-
 
 def _get_primitives_for_state_check(
     cluster_state, resource_id, expected_running
@@ -189,16 +171,16 @@ def _get_primitives_for_state_check(
         |
         .//group[{predicate_id}]/resource[{predicate_position}]
         |
-        .//clone[@id="{id}"]/resource
+        .//clone[@id=$id]/resource
         |
-        .//clone[@id="{id}"]/group/resource[{predicate_position}]
+        .//clone[@id=$id]/group/resource[{predicate_position}]
         |
-        .//bundle[@id="{id}"]/replica/resource
+        .//bundle[@id=$id]/replica/resource
     """.format(
-            id=resource_id,
-            predicate_id=_id_xpath_predicate(resource_id),
+            predicate_id=_id_xpath_predicate,
             predicate_position=("last()" if expected_running else "1"),
-        )
+        ),
+        id=resource_id,
     )
     return [
         element
@@ -211,7 +193,7 @@ def _get_primitive_roles_with_nodes(primitive_el_list):
     # Clone resources are represented by multiple primitive elements.
     roles_with_nodes = defaultdict(set)
     for resource_element in primitive_el_list:
-        if resource_element.attrib["role"] in ["Started", "Master", "Slave"]:
+        if resource_element.attrib["role"] in const.PCMK_ROLES_RUNNING:
             roles_with_nodes[resource_element.attrib["role"]].update(
                 [
                     node.attrib["name"]
@@ -284,8 +266,9 @@ def is_resource_managed(cluster_state, resource_id):
         |
         .//group[{predicate_id}]/resource
         """.format(
-            predicate_id=_id_xpath_predicate(resource_id)
-        )
+            predicate_id=_id_xpath_predicate
+        ),
+        id=resource_id,
     )
     if primitive_list:
         for primitive in primitive_list:
@@ -300,12 +283,11 @@ def is_resource_managed(cluster_state, resource_id):
 
     parent_list = cluster_state.xpath(
         """
-        .//clone[@id="{0}"]
+        .//clone[@id=$resource_id]
         |
-        .//bundle[@id="{0}"]
-        """.format(
-            resource_id
-        )
+        .//bundle[@id=$resource_id]
+        """,
+        resource_id=resource_id,
     )
     for parent in parent_list:
         if is_false(parent.attrib.get("managed", "")):
