@@ -5,6 +5,7 @@ from typing import (
     Union,
 )
 
+from pcs import settings
 from pcs.common import reports
 from pcs.common.reports.item import (
     ReportItem,
@@ -12,6 +13,7 @@ from pcs.common.reports.item import (
 )
 from pcs.common.tools import timeout_to_seconds
 from pcs.lib.errors import LibraryError
+from pcs.lib.external import CommandRunner
 
 _BOOLEAN_TRUE = frozenset(["true", "on", "yes", "y", "1"])
 _BOOLEAN_FALSE = frozenset(["false", "off", "no", "n", "0"])
@@ -61,6 +63,12 @@ def is_score(value: str) -> bool:
     return unsigned_value == SCORE_INFINITY or unsigned_value.isdigit()
 
 
+def is_duration(runner: CommandRunner, value: str) -> bool:
+    cmd = [settings.iso8601_exec, "--duration", value]
+    _, _, retval = runner.run(cmd)
+    return retval == 0
+
+
 def get_valid_timeout_seconds(
     timeout_candidate: Union[str, int, None],
 ) -> Optional[int]:
