@@ -213,11 +213,12 @@ def validate_nodes_devices(
 def create_sbd_config(base_config, node_label, watchdog, device_list=None):
     # TODO: figure out which name/ring has to be in SBD_OPTS
     config = dict(base_config)
-    config["SBD_OPTS"] = '"-n {node_name}"'.format(node_name=node_label)
+    config["SBD_OPTS"] = f'"-n {node_label}"'
     if watchdog:
         config["SBD_WATCHDOG_DEV"] = watchdog
     if device_list:
-        config["SBD_DEVICE"] = '"{0}"'.format(";".join(device_list))
+        device_list_str = ";".join(device_list)
+        config["SBD_DEVICE"] = f'"{device_list_str}"'
     return dict_to_environment_file(config)
 
 
@@ -292,7 +293,7 @@ def initialize_block_devices(
         )
     )
 
-    cmd = [settings.sbd_binary]
+    cmd = [settings.sbd_exec]
     for device in device_list:
         cmd += ["-d", device]
 
@@ -348,7 +349,7 @@ def get_device_messages_info(cmd_runner, device):
     device -- string
     """
     std_out, dummy_std_err, ret_val = cmd_runner.run(
-        [settings.sbd_binary, "-d", device, "list"]
+        [settings.sbd_exec, "-d", device, "list"]
     )
     if ret_val != 0:
         # sbd writes error message into std_out
@@ -368,7 +369,7 @@ def get_device_sbd_header_dump(cmd_runner, device):
     device -- string
     """
     std_out, dummy_std_err, ret_val = cmd_runner.run(
-        [settings.sbd_binary, "-d", device, "dump"]
+        [settings.sbd_exec, "-d", device, "dump"]
     )
     if ret_val != 0:
         # sbd writes error message into std_out
@@ -453,7 +454,7 @@ def set_message(cmd_runner, device, node_name, message):
     message -- string, message type
     """
     dummy_std_out, std_err, ret_val = cmd_runner.run(
-        [settings.sbd_binary, "-d", device, "message", node_name, message]
+        [settings.sbd_exec, "-d", device, "message", node_name, message]
     )
     if ret_val != 0:
         raise LibraryError(
@@ -473,7 +474,7 @@ def get_available_watchdogs(cmd_runner):
         r"(\nCAUTION: (?P<caution>.+)$)?"
     )
     std_out, std_err, ret_val = cmd_runner.run(
-        [settings.sbd_binary, "query-watchdog"]
+        [settings.sbd_exec, "query-watchdog"]
     )
     if ret_val != 0:
         raise LibraryError(
@@ -490,7 +491,7 @@ def get_available_watchdogs(cmd_runner):
 
 
 def test_watchdog(cmd_runner, watchdog=None):
-    cmd = [settings.sbd_binary, "test-watchdog"]
+    cmd = [settings.sbd_exec, "test-watchdog"]
     if watchdog:
         cmd.extend(["-w", watchdog])
     std_out, dummy_std_err, ret_val = cmd_runner.run(cmd)
