@@ -7,6 +7,7 @@ from typing import (
 )
 
 from pcs import utils
+from pcs.cli.reports.output import deprecation_warning
 from pcs.common import (
     const,
     pacemaker,
@@ -326,7 +327,6 @@ def has_node_attr_expr_with_type_integer(rule_tree):
 
 
 class SymbolBase:
-
     END = "{end}"
     LITERAL = "{literal}"
 
@@ -369,7 +369,6 @@ class SymbolLiteral(SymbolBase):
 
 
 class SymbolParenthesisOpen(SymbolBase):
-
     expression_func = None
     advance_func = None
     close_symbol_id = None
@@ -381,7 +380,6 @@ class SymbolParenthesisOpen(SymbolBase):
 
 
 class SymbolOperator(SymbolBase):
-
     expression_func = None
     # Note: not properly typed
     allowed_child_ids: List[Any] = []
@@ -415,7 +413,6 @@ class SymbolPrefix(SymbolOperator):
 
 
 class SymbolType(SymbolPrefix):
-
     value_re = None
 
     def null_denotation(self):
@@ -445,7 +442,6 @@ class SymbolInfix(SymbolOperator):
 
 
 class SymbolTernary(SymbolOperator):
-
     advance_func = None
     symbol_second_id: Optional[str] = None
 
@@ -631,7 +627,6 @@ class SyntaxError(ParserException):
 
 
 class DateCommonValue:
-
     allowed_items = [
         "hours",
         "monthdays",
@@ -689,7 +684,6 @@ class DateCommonValue:
 
 
 class DateSpecValue(DateCommonValue):
-
     KEYWORD = "date-spec"
     part_re = re.compile(r"^(?P<since>\d+)(-(?P<until>\d+))?$")
     part_limits = {
@@ -738,7 +732,6 @@ class DateSpecValue(DateCommonValue):
 
 
 class DateDurationValue(DateCommonValue):
-
     KEYWORD = "duration"
 
     def __init__(self, parts_string):
@@ -755,7 +748,6 @@ class DateDurationValue(DateCommonValue):
 
 
 class SymbolTypeDateCommon(SymbolType):
-
     date_value_class = None
 
     def null_denotation(self):
@@ -766,7 +758,6 @@ class SymbolTypeDateCommon(SymbolType):
 
 
 class SymbolTernaryInRange(SymbolTernary):
-
     allowed_child_ids = [
         [SymbolBase.LITERAL],
         [SymbolBase.LITERAL],
@@ -790,7 +781,6 @@ class SymbolTernaryInRange(SymbolTernary):
 
 
 class RuleParser(Parser):
-
     comparison_list = ["eq", "ne", "lt", "gt", "lte", "gte", "in_range"]
     date_comparison_list = ["gt", "lt", "in_range"]
     prefix_list = ["defined", "not_defined"]
@@ -893,6 +883,17 @@ class RuleParser(Parser):
 class CibBuilder:
     def __init__(self, cib_schema_version):
         self.cib_schema_version = cib_schema_version
+        self.space_deprecation_printed = False
+
+    # deprecated since pcs-0.11.7
+    def date_space_deprecation(self, date):
+        if self.space_deprecation_printed or " " not in date:
+            return
+        self.space_deprecation_printed = True
+        deprecation_warning(
+            "Using spaces in date values is deprecated and will be removed. "
+            "Use 'T' as a delimiter between date and time."
+        )
 
     def build(self, dom_element, syntactic_tree, rule_id=None):
         dom_rule = self.add_element(
@@ -978,6 +979,7 @@ class CibBuilder:
                 "'%s' is not an ISO 8601 date"
                 % syntactic_tree.children[1].value
             )
+        self.date_space_deprecation(syntactic_tree.children[1].value)
         dom_expression.setAttribute("operation", syntactic_tree.symbol_id)
         if syntactic_tree.symbol_id == "gt":
             dom_expression.setAttribute(
@@ -1008,6 +1010,7 @@ class CibBuilder:
                         "'%s' is not an ISO 8601 date"
                         % syntactic_tree.children[2].value
                     )
+                self.date_space_deprecation(syntactic_tree.children[2].value)
                 dom_expression.setAttribute(
                     "end", syntactic_tree.children[2].value
                 )
