@@ -83,10 +83,6 @@ from pcs.lib.services import service_exception_to_report
 
 # pylint: disable=invalid-name
 # pylint: disable=too-many-branches
-# pylint: disable=too-many-locals
-# pylint: disable=too-many-nested-blocks
-# pylint: disable=too-many-return-statements
-# pylint: disable=too-many-statements
 
 # usefile & filename variables are set in pcs module
 usefile = False
@@ -531,6 +527,8 @@ def sendHTTPRequest(
       * --request-timeout - timeout for HTTP requests
       * --debug
     """
+    # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
     port = None
     addr = host
     token = None
@@ -856,9 +854,9 @@ def run(
         "iso8601",
         "stonith_admin",
     ]:
-        args[0] = os.path.join(settings.pacemaker_binaries, command)
+        args[0] = os.path.join(settings.pacemaker_execs, command)
     elif command[0:8] == "corosync":
-        args[0] = os.path.join(settings.corosync_binaries, command)
+        args[0] = os.path.join(settings.corosync_execs, command)
 
     try:
         if "--debug" in pcs_options:
@@ -946,7 +944,7 @@ def run_pcsdcli(command, data=None):
     if settings.pcsd_gem_path is not None:
         env_var["GEM_HOME"] = settings.pcsd_gem_path
     stdout, dummy_stderr, retval = cmd_runner().run(
-        [settings.ruby_executable, "-I" + pcsd_dir_path, pcsdcli_path, command],
+        [settings.ruby_exec, "-I" + pcsd_dir_path, pcsdcli_path, command],
         json.dumps(data),
         env_var,
     )
@@ -1039,6 +1037,7 @@ def call_local_pcsd(argv, options, std_in=None):
     Commandline options:
       * --request-timeout - timeout of call to local pcsd
     """
+    # pylint: disable=too-many-return-statements
     # some commands cannot be run under a non-root account
     # so we pass those commands to locally running pcsd to execute them
     # returns [list_of_errors, exit_code, stdout, stderr]
@@ -1383,6 +1382,7 @@ def validate_constraint_resource(dom, resource_id):
     Commandline options:
       * --force - allow constraint on any resource
     """
+    # pylint: disable=too-many-return-statements
     resource_el = (
         dom_get_clone(dom, resource_id)
         or dom_get_master(dom, resource_id)
@@ -1540,6 +1540,7 @@ def get_resource_for_running_check(cluster_state, resource_id, stopped=False):
     """
     Commandline options: no options
     """
+    # pylint: disable=too-many-nested-blocks
     for clone in cluster_state.getElementsByTagName("clone"):
         if clone.getAttribute("id") == resource_id:
             for child in clone.childNodes:
@@ -1574,6 +1575,7 @@ def resource_running_on(resource, passed_state=None, stopped=False):
     Commandline options:
       * -f - has effect but doesn't make sense to check state of resource
     """
+    # pylint: disable=too-many-locals
     nodes_started = []
     nodes_promoted = []
     nodes_unpromoted = []
@@ -2141,7 +2143,7 @@ def is_iso8601_date(var):
     return retVal == 0
 
 
-def err(errorText, exit_after_error=True):
+def err(errorText: str, exit_after_error: bool = True) -> None:
     retval = reports_output.error(errorText)
     if exit_after_error:
         raise retval
@@ -2710,12 +2712,12 @@ def exit_on_cmdline_input_error(
     if error and error.hint:
         print_to_stderr(f"Hint: {error.hint}")
     if not error or (not error.message or error.show_both_usage_and_message):
-        usage.show(main_name, usage_name)
+        usage.show(main_name, list(usage_name))
     sys.exit(1)
 
 
 def get_report_processor() -> ReportProcessor:
-    return ReportProcessorToConsole(debug=("--debug" in pcs_options))
+    return ReportProcessorToConsole(debug="--debug" in pcs_options)
 
 
 def get_user_and_pass():
