@@ -21,6 +21,21 @@ from pcs_test.tools.misc import dict_to_modifiers
 
 FIXTURE_PROPERTY_METADATA = ClusterPropertyMetadataDto(
     properties_metadata=[
+        ResourceAgentParameterDto(
+            name="property_name",
+            shortdesc="Duplicate property",
+            longdesc=None,
+            type="string",
+            default="duplicate_default",
+            enum_values=None,
+            required=False,
+            advanced=False,
+            deprecated=False,
+            deprecated_by=[],
+            deprecated_desc=None,
+            unique_group=None,
+            reloadable=False,
+        ),
         ResourceAgentParameterDto(
             name="property_name",
             shortdesc=None,
@@ -419,7 +434,12 @@ class TestDefaults(TestCase):
         )
 
     def test_properties_without_defaults(self, mock_print):
-        self._call_cmd(["arg1", "arg2"])
+        with self.assertRaises(CmdLineInputError) as cm:
+            self._call_cmd(["arg1", "arg2"])
+        self.assertEqual(
+            cm.exception.message,
+            "No default value for properties: 'arg1', 'arg2'",
+        )
         self.cluster_property.get_properties_metadata.assert_called_once()
         mock_print.assert_not_called()
 
@@ -495,7 +515,12 @@ class TestDescribe(TestCase):
         mock_print.assert_called_once_with(self.text_output_advanced)
 
     def test_properties_without_metadata(self, mock_print):
-        self._call_cmd(["arg1", "arg2"])
+        with self.assertRaises(CmdLineInputError) as cm:
+            self._call_cmd(["arg1", "arg2"])
+        self.assertEqual(
+            cm.exception.message,
+            "No description for properties: 'arg1', 'arg2'",
+        )
         self.cluster_property.get_properties_metadata.assert_called_once()
         mock_print.assert_not_called()
 
