@@ -1,15 +1,19 @@
 import logging
-from urllib.parse import urlencode
 from unittest import mock
+from urllib.parse import urlencode
 
 from tornado.locks import Lock
 from tornado.util import TimeoutError as TornadoTimeoutError
 
-from pcs_test.tier0.daemon.app import fixtures_app
-from pcs_test.tools.misc import create_setup_patch_mixin
-
-from pcs.daemon import ruby_pcsd, http_server
+from pcs.daemon import (
+    http_server,
+    ruby_pcsd,
+)
 from pcs.daemon.app import sinatra_remote
+from pcs.lib.auth.provider import AuthProvider
+from pcs.lib.auth.types import AuthUser
+
+from pcs_test.tier0.daemon.app import fixtures_app
 
 # Don't write errors to test output.
 logging.getLogger("tornado.access").setLevel(logging.CRITICAL)
@@ -17,67 +21,70 @@ logging.getLogger("tornado.access").setLevel(logging.CRITICAL)
 
 class AppTest(fixtures_app.AppTest):
     def setUp(self):
-        self.wrapper = fixtures_app.RubyPcsdWrapper(ruby_pcsd.SINATRA_REMOTE)
+        self.wrapper = fixtures_app.RubyPcsdWrapper(ruby_pcsd.SINATRA)
         self.https_server_manage = mock.MagicMock(
             spec_set=http_server.HttpsServerManage
         )
         self.lock = Lock()
+        self.auth_provider = AuthProvider(logging.getLogger("test logger"))
         super().setUp()
 
+    def _mock_auth_provider_method(self, method_name, return_value=None):
+        method_patcher = mock.patch.object(AuthProvider, method_name)
+        self.addCleanup(method_patcher.stop)
+        method_mock = method_patcher.start()
+        if return_value:
+            method_mock.return_value = return_value
+        return method_mock
+
     def get_routes(self):
         return sinatra_remote.get_routes(
             self.wrapper,
             self.lock,
             self.https_server_manage,
+            self.auth_provider,
         )
 
 
 class SetCerts(AppTest):
+    def setUp(self):
+        super().setUp()
+        self._mock_auth_provider_method(
+            "auth_by_token", AuthUser(username="user", groups=("group1",))
+        )
+        self.headers = {"Cookie": "token=1234"}
+
     def test_it_asks_for_cert_reload_if_ruby_succeeds(self):
         self.wrapper.status_code = 200
         self.wrapper.body = b"success"
         # body is irelevant
-        self.assert_wrappers_response(self.post("/remote/set_certs", body={}))
+        self.assert_wrappers_response(
+            self.post("/remote/set_certs", body={}, headers=self.headers)
+        )
         self.https_server_manage.reload_certs.assert_called_once()
 
     def test_it_not_asks_for_cert_reload_if_ruby_fail(self):
         self.wrapper.status_code = 400
         self.wrapper.body = b"cannot save ssl certificate without ssl key"
         # body is irelevant
-        self.assert_wrappers_response(self.post("/remote/set_certs", body={}))
+        self.assert_wrappers_response(
+            self.post("/remote/set_certs", body={}, headers=self.headers)
+        )
         self.https_server_manage.reload_certs.assert_not_called()
 
 
-class Auth(
-    AppTest,
-    create_setup_patch_mixin(sinatra_remote),
-    fixtures_app.UserAuthMixin,
-):
-    # pylint: disable=too-many-ancestors
-    def setUp(self):
-        self.setup_patch("authorize_user", self.authorize_user)
-        super().setUp()
-
-    def make_auth_request(self, valid=True):
-        self.user_auth_info = fixtures_app.UserAuthInfo(valid=valid)
-        return self.post(
-            "/remote/auth",
-            body={
-                "username": fixtures_app.USER,
-                "password": fixtures_app.PASSWORD,
-            },
-        )
-
-    def test_refuse_unknown_user(self):
-        self.assertEqual(b"", self.make_auth_request(valid=False).body)
-
-    def test_wraps_ruby_on_valid_user(self):
-        self.assert_wrappers_response(self.make_auth_request())
-
-
 class SinatraRemote(AppTest):
+    def setUp(self):
+        super().setUp()
+        self._mock_auth_provider_method(
+            "auth_by_token", AuthUser(username="user", groups=("group1",))
+        )
+        self.headers = {"Cookie": "token=1234"}
+
     def test_take_result_from_ruby(self):
-        self.assert_wrappers_response(self.get("/remote/"))
+        self.assert_wrappers_response(
+            self.get("/remote/", headers=self.headers)
+        )
 
 
 class SyncConfigMutualExclusive(AppTest):
@@ -92,19 +99,28 @@ class SyncConfigMutualExclusive(AppTest):
     timeout and test detects an expected timeout error.
     """
 
+    def setUp(self):
+        super().setUp()
+        self._mock_auth_provider_method(
+            "auth_by_token", AuthUser(username="user", groups=("group1",))
+        )
+
     def fetch_set_sync_options(self, method):
+        def fetch_sync_options():
+            return self.http_client.fetch(
+                self.get_url("/remote/set_sync_options"), **kwargs
+            )
+
         kwargs = (
             dict(method=method, body=urlencode({}))
             if method == "POST"
             else dict(method=method)
         )
+        kwargs["headers"] = {"Cookie": "token=1234"}
 
         # Without lock the timeout should be enough to finish task. With the
         # lock it should raise because of timeout. The same timeout is used for
         # noticing differences between test with and test without lock.
-        fetch_sync_options = lambda: self.http_client.fetch(
-            self.get_url("/remote/set_sync_options"), **kwargs
-        )
         return self.io_loop.run_sync(fetch_sync_options, timeout=0.5)
 
     def check_call_wrapper_without_lock(self, method):
