@@ -139,7 +139,6 @@ class ValidateMoveResourcesToGroup(TestCase):
         )
 
     def test_adjacent_resource_not_in_the_group(self):
-        # pylint: disable=line-too-long
         assert_report_item_list_equal(
             self._validate("G", ["R1"], "R2"),
             [
@@ -154,7 +153,6 @@ class ValidateMoveResourcesToGroup(TestCase):
         )
 
     def test_adjacent_resource_in_another_group(self):
-        # pylint: disable=line-too-long
         assert_report_item_list_equal(
             self._validate("G", ["R1"], "RGX"),
             [
@@ -312,7 +310,17 @@ class ValidateMoveResourcesToGroup(TestCase):
 
 
 class ValidateMoveBanClearMixin:
-    # pylint: disable=too-many-public-methods,line-too-long
+    # pylint: disable=too-many-public-methods
+    @staticmethod
+    def _fixture_bundle():
+        return etree.fromstring(
+            """
+            <bundle id="R-bundle">
+                <primitive id="R" />
+            </bundle>
+            """
+        )
+
     @staticmethod
     def _fixture_clone(promotable=False):
         return etree.fromstring(
@@ -379,7 +387,7 @@ class ValidateMoveBanClearMixin:
                 fixture.error(
                     self.report_code_bad_master,
                     resource_id="R-clone",
-                    promotable_id=None,
+                    promotable_id="",
                 ),
             ],
         )
@@ -461,7 +469,7 @@ class ValidateMoveBanClearMixin:
                 fixture.error(
                     self.report_code_bad_master,
                     resource_id="R",
-                    promotable_id=None,
+                    promotable_id="",
                 ),
             ],
         )
@@ -480,7 +488,7 @@ class ValidateMoveBanClearMixin:
                 fixture.error(
                     self.report_code_bad_master,
                     resource_id="G",
-                    promotable_id=None,
+                    promotable_id="",
                 ),
             ],
         )
@@ -499,7 +507,7 @@ class ValidateMoveBanClearMixin:
                 fixture.error(
                     self.report_code_bad_master,
                     resource_id="R",
-                    promotable_id=None,
+                    promotable_id="",
                 ),
             ],
         )
@@ -556,16 +564,6 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
         reports.codes.CANNOT_MOVE_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
     )
 
-    @staticmethod
-    def _fixture_bundle():
-        return etree.fromstring(
-            """
-            <bundle id="R-bundle">
-                <primitive id="R" />
-            </bundle>
-            """
-        )
-
     def test_master_false_promotable_clone(self):
         element = self._fixture_clone(True)
         assert_report_item_list_equal(
@@ -586,8 +584,9 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element, True),
             [
                 fixture.error(
-                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE,
+                    reports.codes.CANNOT_MOVE_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE,
                     resource_id="R-clone",
+                    promotable_id="",
                 ),
             ],
         )
@@ -596,12 +595,7 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
         element = self._fixture_clone(False)
         assert_report_item_list_equal(
             self.validate(element, False),
-            [
-                fixture.error(
-                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE,
-                    resource_id="R-clone",
-                ),
-            ],
+            [],
         )
 
     def test_master_false_master(self):
@@ -663,8 +657,9 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element.find("./primitive"), True),
             [
                 fixture.error(
-                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE,
+                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE_INNER,
                     resource_id="R",
+                    clone_id="R-clone",
                 ),
             ],
         )
@@ -675,8 +670,9 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element.find("./primitive"), False),
             [
                 fixture.error(
-                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE,
+                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE_INNER,
                     resource_id="R",
+                    clone_id="R-clone",
                 ),
             ],
         )
@@ -687,8 +683,9 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element.find("./group"), True),
             [
                 fixture.error(
-                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE,
+                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE_INNER,
                     resource_id="G",
+                    clone_id="G-clone",
                 ),
             ],
         )
@@ -699,8 +696,9 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element.find("./group"), False),
             [
                 fixture.error(
-                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE,
+                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE_INNER,
                     resource_id="G",
+                    clone_id="G-clone",
                 ),
             ],
         )
@@ -711,8 +709,9 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element.find("./group/primitive"), True),
             [
                 fixture.error(
-                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE,
+                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE_INNER,
                     resource_id="R",
+                    clone_id="G-clone",
                 ),
             ],
         )
@@ -723,8 +722,9 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
             self.validate(element.find("./group/primitive"), False),
             [
                 fixture.error(
-                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE,
+                    reports.codes.CANNOT_MOVE_RESOURCE_CLONE_INNER,
                     resource_id="R",
+                    clone_id="G-clone",
                 ),
             ],
         )
@@ -733,18 +733,20 @@ class ValidateMove(ValidateMoveBanClearMixin, TestCase):
         element = self._fixture_bundle()
         assert_report_item_list_equal(
             self.validate(element, False),
-            [
-                fixture.error(
-                    reports.codes.CANNOT_MOVE_RESOURCE_BUNDLE,
-                    resource_id="R-bundle",
-                ),
-            ],
+            [],
         )
 
     def test_bundle_resource(self):
         element = self._fixture_bundle()
         assert_report_item_list_equal(
-            self.validate(element.find("./primitive"), False), []
+            self.validate(element.find("./primitive"), False),
+            [
+                fixture.error(
+                    reports.codes.CANNOT_MOVE_RESOURCE_BUNDLE_INNER,
+                    resource_id="R",
+                    bundle_id="R-bundle",
+                ),
+            ],
         )
 
 
@@ -754,6 +756,19 @@ class ValidateBan(ValidateMoveBanClearMixin, TestCase):
         reports.codes.CANNOT_BAN_RESOURCE_MASTER_RESOURCE_NOT_PROMOTABLE
     )
 
+    def test_bundle_resource(self):
+        element = self._fixture_bundle()
+        assert_report_item_list_equal(
+            self.validate(element.find("./primitive"), False),
+            [
+                fixture.error(
+                    reports.codes.CANNOT_BAN_RESOURCE_BUNDLE_INNER,
+                    resource_id="R",
+                    bundle_id="R-bundle",
+                ),
+            ],
+        )
+
 
 class ValidateUnmoveUnban(ValidateMoveBanClearMixin, TestCase):
     validate = staticmethod(validations.validate_unmove_unban)
