@@ -1,11 +1,28 @@
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
 
-from pcs_test.tools.assertions import assert_raise_library_error
+from lxml import etree
 
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 from pcs.lib.cib.constraint import colocation
 
+from pcs_test.tools.assertions import assert_raise_library_error
+
+
+class IsColocationConstraint(TestCase):
+    def test_colocation_constraint_true(self):
+        self.assertTrue(
+            colocation.is_colocation_constraint(etree.Element("rsc_colocation"))
+        )
+
+    def test_colocation_constraint_false(self):
+        self.assertFalse(
+            colocation.is_colocation_constraint(etree.Element("colocation"))
+        )
+
 
 # Patch check_new_id_applicable is always desired when working with
 # prepare_options_with_set. Patched function raises when id not applicable
@@ -59,18 +76,6 @@ class PrepareOptionsWithSetTest(TestCase):
             (severities.ERROR, report_codes.INVALID_SCORE, {"score": "bad"}),
         )
 
-    def test_refuse_more_scores(self, _):
-        assert_raise_library_error(
-            lambda: self.prepare(
-                {
-                    "score": "1",
-                    "score-attribute": "2",
-                    "id": "id",
-                }
-            ),
-            (severities.ERROR, report_codes.MULTIPLE_SCORE_OPTIONS, {}),
-        )
-
     def test_refuse_unknown_attributes(self, _):
         assert_raise_library_error(
             lambda: self.prepare(
@@ -86,12 +91,7 @@ class PrepareOptionsWithSetTest(TestCase):
                 {
                     "option_names": ["unknown"],
                     "option_type": None,
-                    "allowed": [
-                        "id",
-                        "score",
-                        "score-attribute",
-                        "score-attribute-mangle",
-                    ],
+                    "allowed": ["id", "score"],
                     "allowed_patterns": [],
                 },
             ),
