@@ -19,6 +19,16 @@ from pcs_test.tools.assertions import (
 from pcs_test.tools.custom_mock import MockLibraryReportProcessor
 
 
+class IsTicketConstraint(TestCase):
+    def test_ticket_constraint_true(self):
+        self.assertTrue(
+            ticket.is_ticket_constraint(etree.Element("rsc_ticket"))
+        )
+
+    def test_ticket_constraint_false(self):
+        self.assertFalse(ticket.is_ticket_constraint(etree.Element("ticket")))
+
+
 @mock.patch(
     "pcs.lib.cib.constraint.ticket.tools.are_new_role_names_supported",
     lambda _: True,
@@ -183,7 +193,7 @@ class PrepareOptionsPlainTest(TestCase):
         )
 
     def test_refuse_unknown_lost_policy(self, mock_check_new_id_applicable):
-        # pylint: disable=unused-argument
+        del mock_check_new_id_applicable
         assert_raise_library_error(
             lambda: self.prepare(
                 {"loss-policy": "unknown", "id": "id"},
@@ -339,7 +349,6 @@ class PrepareOptionsWithSetTest(TestCase):
 
 
 class Element:
-    # pylint: disable=too-few-public-methods
     def __init__(self, attrib):
         self.attrib = attrib
 
