@@ -1,39 +1,40 @@
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
+
 from lxml import etree
 
-from pcs_test.tools import fixture, fixture_crm_mon
+from pcs import settings
+from pcs.common import reports
+from pcs.common.fencing_topology import (
+    TARGET_TYPE_ATTRIBUTE,
+    TARGET_TYPE_NODE,
+    TARGET_TYPE_REGEXP,
+)
+from pcs.common.reports import ReportItemSeverity as severity
+from pcs.common.reports import codes as report_codes
+from pcs.common.reports.item import ReportItem
+from pcs.lib.cib import fencing_topology as lib
+from pcs.lib.errors import LibraryError
+from pcs.lib.pacemaker.state import ClusterState
+
+from pcs_test.tools import (
+    fixture,
+    fixture_crm_mon,
+)
 from pcs_test.tools.assertions import (
     assert_report_item_list_equal,
     assert_xml_equal,
 )
 from pcs_test.tools.custom_mock import MockLibraryReportProcessor
-from pcs_test.tools.misc import (
-    create_patcher,
-    get_test_resource as rc,
-)
+from pcs_test.tools.misc import create_patcher
+from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.xml import etree_to_str
 
-from pcs import settings
-from pcs.common import reports
-from pcs.common.reports import codes as report_codes
-from pcs.common.fencing_topology import (
-    TARGET_TYPE_NODE,
-    TARGET_TYPE_REGEXP,
-    TARGET_TYPE_ATTRIBUTE,
-)
-from pcs.common.reports import ReportItemSeverity as severity
-from pcs.common.reports.item import ReportItem
-from pcs.lib.errors import LibraryError
-from pcs.lib.pacemaker.state import ClusterState
-
-from pcs.lib.cib import fencing_topology as lib
-
-
 patch_lib = create_patcher("pcs.lib.cib.fencing_topology")
 
-# pylint: disable=too-few-public-methods
 # pylint: disable=protected-access
-# pylint: disable=no-self-use
 
 
 class CibMixin:
@@ -84,6 +85,7 @@ class CibMixin:
 
 class StatusNodesMixin:
     def get_status(self):
+        # pylint: disable=no-self-use
         with open(rc("crm_mon.minimal.xml")) as crm_mon_file:
             crm_mon_xml = crm_mon_file.read()
         return ClusterState(
@@ -667,6 +669,7 @@ class Verify(TestCase, CibMixin, StatusNodesMixin):
         self.tree = self.cib.find("configuration/fencing-topology")
 
     def fixture_resource(self, tree, name):
+        # pylint: disable=no-self-use
         el = etree.SubElement(tree, "primitive", id=name, type="fence_dummy")
         el.set("class", "stonith")
 
@@ -781,6 +784,7 @@ class ValidateLevel(TestCase):
 @patch_lib("_validate_target_typewise")
 class ValidateTarget(TestCase):
     def test_delegate(self, validate_type, validate_value):
+        # pylint: disable=no-self-use
         lib._validate_target("status", "type", "value", "force")
         validate_type.assert_called_once_with("type")
         validate_value.assert_called_once_with(
@@ -790,6 +794,7 @@ class ValidateTarget(TestCase):
 
 class ValidateTargetTypewise(TestCase):
     def test_success(self):
+        # pylint: disable=no-self-use
         report_list = []
         report_list.extend(lib._validate_target_typewise(TARGET_TYPE_NODE))
         report_list.extend(lib._validate_target_typewise(TARGET_TYPE_ATTRIBUTE))
@@ -797,6 +802,7 @@ class ValidateTargetTypewise(TestCase):
         assert_report_item_list_equal(report_list, [])
 
     def test_empty(self):
+        # pylint: disable=no-self-use
         report_list = lib._validate_target_typewise("")
         report = [
             (
@@ -816,6 +822,7 @@ class ValidateTargetTypewise(TestCase):
         assert_report_item_list_equal(report_list, report)
 
     def test_invalid(self):
+        # pylint: disable=no-self-use
         report_list = lib._validate_target_typewise("bad_target")
         report = [
             (
@@ -1010,6 +1017,7 @@ class ValidateDevices(TestCase):
 @patch_lib("_find_level_elements")
 class ValidateLevelTargetDevicesDoesNotExist(TestCase):
     def test_success(self, mock_find):
+        # pylint: disable=no-self-use
         mock_find.return_value = []
 
         report_list = lib._validate_level_target_devices_does_not_exist(
@@ -1022,6 +1030,7 @@ class ValidateLevelTargetDevicesDoesNotExist(TestCase):
         assert_report_item_list_equal(report_list, [])
 
     def test_error(self, mock_find):
+        # pylint: disable=no-self-use
         mock_find.return_value = ["element"]
 
         report_list = lib._validate_level_target_devices_does_not_exist(
@@ -1112,6 +1121,7 @@ class FindLevelElements(TestCase, CibMixin):
         self.tree = self.cib.find("configuration/fencing-topology")
 
     def get_ids(self, elements):
+        # pylint: disable=no-self-use
         return [el.get("id") for el in elements]
 
     def test_no_filter(self):
