@@ -1,22 +1,145 @@
 from functools import partial
-from unittest import mock, TestCase
-from lxml import etree
-
-from pcs_test.tools.assertions import (
-    assert_raise_library_error,
-    assert_report_item_list_equal,
+from unittest import (
+    TestCase,
+    mock,
 )
-from pcs_test.tools import fixture
-from pcs_test.tools.misc import get_test_resource as rc
-from pcs_test.tools.xml import get_xml_manipulation_creator_from_file
+
+from lxml import etree
 
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
 from pcs.common.tools import Version
-
 from pcs.lib.cib import tools as lib
 
-# pylint: disable=no-self-use, line-too-long
+from pcs_test.tools import fixture
+from pcs_test.tools.assertions import (
+    assert_raise_library_error,
+    assert_report_item_list_equal,
+    assert_xml_equal,
+)
+from pcs_test.tools.misc import get_test_resource as rc
+from pcs_test.tools.xml import (
+    etree_to_str,
+    get_xml_manipulation_creator_from_file,
+)
+
+cib_element_lookup = etree.fromstring(
+    """
+            <cib>
+                <configuration>
+                    <resources>
+                        <primitive id="R1" />
+                        <primitive id="R3" />
+                        <primitive id="RX2" />
+                        <primitive id="RX2" />
+                        <primitive id="RX3" />
+                        <primitive id="T" />
+                    </resources>
+                    <tags>
+                        <tag id="T">
+                            <obj_ref id="RX1" />
+                            <obj_ref id="RX3" />
+                        </tag>
+                    </tags>
+                </configuration>
+                <status>
+                    <lrm_resource id="R3" />
+                    <lrm_resource id="R2" />
+                </status>
+            </cib>
+            """
+)
+
+FIXTURE_REFERENCES_IN_CONSTRAINTS = """
+    <constraints>
+        <rsc_location>
+            <resource_set>
+                <resource_ref id="A"/>
+                <resource_ref id="B"/>
+            </resource_set>
+            <resource_ref id="A" invalid="position"/>
+        </rsc_location>
+        <resource_ref id="A" invalid="position"/>
+        <rsc_colocation>
+            <resource_set>
+                <resource_ref id="C"/>
+                <resource_ref id="A"/>
+            </resource_set>
+        </rsc_colocation>
+        <rsc_colocation rsc="A" with-rsc="B"/>
+        <rsc_colocation rsc="B" with-rsc="A"/>
+        <rsc_colocation id="coloc_rsc_set" rsc="A" with-rsc="B">
+            <resource_set/>
+        </rsc_colocation>
+        <rsc_location rsc="A"/>
+        <rsc_location rsc="A" with-rsc="B">
+            <resource_set/>
+        </rsc_location>
+        <rsc_order first="A" then="B"/>
+        <rsc_order first="B" then="A"/>
+        <rsc_order id="order_first_set" first="A" then="B">
+            <resource_set/>
+        </rsc_order>
+        <rsc_ticket id="ticket_rsc" rsc="A"/>
+        <rsc_ticket id="ticket_rsc_set" rsc="A">
+            <resource_set/>
+        </rsc_ticket>
+        <rsc_ticket rsc="C"/>
+    </constraints>
+    <resource_ref id="A" invalid="position"/>
+"""
+
+FIXTURE_REFERENCES_IN_TAGS = """
+    <tags>
+        <tag id="X">
+            <obj_ref id="A"/>
+        </tag>
+        <obj_ref id="A" invalid="position"/>
+        <tag id="Y">
+            <obj_ref id="C"/>
+            <obj_ref id="A"/>
+            <obj_ref id="D"/>
+        </tag>
+        <tag id="Z">
+            <obj_ref id="C"/>
+        </tag>
+    </tags>
+    <obj_ref id="A" invalid="position"/>
+"""
+
+FIXTURE_REFERENCES_IN_ACLS = """
+    <acls>
+        <acl_role id="A">
+            <acl_permission reference="A"/>
+        </acl_role>
+        <acl_role id="B">
+            <acl_permission reference="A"/>
+        </acl_role>
+        <acl_role id="N"/>
+        <acl_permission reference="A" invalid="position"/>
+        <acl_target>
+            <role id="A"/>
+            <role id="B"/>
+            <acl_permission reference="A" invalid="position"/>
+        </acl_target>
+        <role id="A" invalid="position"/>
+        <acl_group>
+            <role id="D"/>
+            <role id="A"/>
+            <role id="C"/>
+            <acl_permission reference="A" invalid="position"/>
+        </acl_group>
+    </acls>
+    <role id="A" invalid="position"/>
+    <acl_permission reference="A" invalid="position"/>
+    """
+FIXTURE_ALL_SECTIONS_WITH_REFERENCES = "".join(
+    [
+        FIXTURE_REFERENCES_IN_CONSTRAINTS,
+        FIXTURE_REFERENCES_IN_TAGS,
+        FIXTURE_REFERENCES_IN_ACLS,
+    ]
+)
 
 
 class CibToolsTest(TestCase):
@@ -410,11 +533,13 @@ class GetTagsTest(CibToolsTest):
 @mock.patch("pcs.lib.cib.tools.does_id_exist")
 class ValidateIdDoesNotExistsTest(TestCase):
     def test_success_when_id_does_not_exists(self, does_id_exists):
+        # pylint: disable=no-self-use
         does_id_exists.return_value = False
         lib.validate_id_does_not_exist("tree", "some-id")
         does_id_exists.assert_called_once_with("tree", "some-id")
 
-    def test_raises_whne_id_exists(self, does_id_exists):
+    def test_raises_when_id_exists(self, does_id_exists):
+        # pylint: disable=no-self-use
         does_id_exists.return_value = True
         assert_raise_library_error(
             lambda: lib.validate_id_does_not_exist("tree", "some-id"),
@@ -429,6 +554,7 @@ class ValidateIdDoesNotExistsTest(TestCase):
 
 class GetPacemakerVersionByWhichCibWasValidatedTest(TestCase):
     def test_missing_attribute(self):
+        # pylint: disable=no-self-use
         assert_raise_library_error(
             lambda: lib.get_pacemaker_version_by_which_cib_was_validated(
                 etree.XML("<cib/>")
@@ -444,6 +570,7 @@ class GetPacemakerVersionByWhichCibWasValidatedTest(TestCase):
         )
 
     def test_invalid_version(self):
+        # pylint: disable=no-self-use
         assert_raise_library_error(
             lambda: lib.get_pacemaker_version_by_which_cib_was_validated(
                 etree.XML('<cib validate-with="something-1.2.3"/>')
@@ -459,6 +586,7 @@ class GetPacemakerVersionByWhichCibWasValidatedTest(TestCase):
         )
 
     def test_invalid_version_at_end(self):
+        # pylint: disable=no-self-use
         assert_raise_library_error(
             lambda: lib.get_pacemaker_version_by_which_cib_was_validated(
                 etree.XML('<cib validate-with="pacemaker-1.2.3x"/>')
@@ -508,6 +636,7 @@ class GetCibCrmFeatureSet(TestCase):
         )
 
     def test_missing_attribute(self):
+        # pylint: disable=no-self-use
         assert_raise_library_error(
             lambda: lib.get_cib_crm_feature_set(etree.XML("<cib />")),
             fixture.error(
@@ -520,6 +649,7 @@ class GetCibCrmFeatureSet(TestCase):
         )
 
     def test_invalid_version(self):
+        # pylint: disable=no-self-use
         assert_raise_library_error(
             lambda: lib.get_cib_crm_feature_set(
                 etree.XML('<cib crm_feature_set="3" />')
@@ -534,6 +664,7 @@ class GetCibCrmFeatureSet(TestCase):
         )
 
     def test_invalid_version_at_end(self):
+        # pylint: disable=no-self-use
         assert_raise_library_error(
             lambda: lib.get_cib_crm_feature_set(
                 etree.XML('<cib crm_feature_set="3.0.9x" />')
@@ -578,6 +709,7 @@ class FindTagWithId(TestCase):
         self.assertEqual("a", element.attrib["id"])
 
     def test_raises_when_is_under_another_tag(self):
+        # pylint: disable=no-self-use
         tree = etree.fromstring(
             '<cib><resources><primitive id="a"/></resources></cib>'
         )
@@ -596,6 +728,7 @@ class FindTagWithId(TestCase):
         )
 
     def test_raises_when_is_under_another_context(self):
+        # pylint: disable=no-self-use
         tree = etree.fromstring(
             """
             <cib>
@@ -623,6 +756,7 @@ class FindTagWithId(TestCase):
         )
 
     def test_raises_when_id_does_not_exists(self):
+        # pylint: disable=no-self-use
         tree = etree.fromstring("<cib><resources/></cib>")
         assert_raise_library_error(
             lambda: find_group(tree.find(".//resources"), "a"),
@@ -843,3 +977,413 @@ class ElementSearcher(TestCase):
                 ),
             ],
         )
+
+
+class GetElementById(TestCase):
+    def test_one_match(self):
+        found_element = lib.get_element_by_id(cib_element_lookup, "R1")
+        self.assertEqual(
+            found_element,
+            cib_element_lookup.find('.//resources/primitive[@id="R1"]'),
+        )
+
+    def test_one_match_ignore_reference(self):
+        found_element = lib.get_element_by_id(cib_element_lookup, "R3")
+        self.assertEqual(
+            found_element,
+            cib_element_lookup.find('.//resources/primitive[@id="R3"]'),
+        )
+
+    def test_duplicate_ids(self):
+        with self.assertRaises(AssertionError):
+            lib.get_element_by_id(cib_element_lookup, "RX2")
+
+    def test_tag_id_same_as_resource_id(self):
+        with self.assertRaises(AssertionError):
+            lib.get_element_by_id(cib_element_lookup, "T")
+
+    def test_id_not_in_cib(self):
+        with self.assertRaises(lib.ElementNotFound):
+            lib.get_element_by_id(cib_element_lookup, "X")
+
+    def test_no_match_in_status(self):
+        with self.assertRaises(lib.ElementNotFound):
+            lib.get_element_by_id(cib_element_lookup, "R2")
+
+    def test_no_match_in_obj_ref(self):
+        with self.assertRaises(lib.ElementNotFound):
+            lib.get_element_by_id(cib_element_lookup, "RX1")
+
+
+class GetElementsById(TestCase):
+    def assert_result(self, found_id_list, unmatched_id_list):
+        found_elements, unmatched_ids = lib.get_elements_by_ids(
+            cib_element_lookup, found_id_list + unmatched_id_list
+        )
+        self.assertListEqual(
+            found_elements,
+            [
+                cib_element_lookup.find(
+                    f'.//resources/primitive[@id="{found_id}"]'
+                )
+                for found_id in found_id_list
+            ],
+        )
+        self.assertListEqual(unmatched_ids, unmatched_id_list)
+
+    def test_one_match(self):
+        self.assert_result(["R1"], [])
+
+    def test_one_match_ignore_reference(self):
+        self.assert_result(["R3"], [])
+
+    def test_duplicate_ids(self):
+        with self.assertRaises(AssertionError):
+            lib.get_elements_by_ids(cib_element_lookup, ["RX2"])
+
+    def test_tag_id_same_as_resource_id(self):
+        with self.assertRaises(AssertionError):
+            lib.get_elements_by_ids(cib_element_lookup, ["T"])
+
+    def test_id_not_in_cib(self):
+        self.assert_result(["R1"], ["X1", "X2"])
+
+    def test_no_match_in_status(self):
+        self.assert_result([], ["R2"])
+
+    def test_no_match_in_obj_ref(self):
+        self.assert_result([], ["RX1"])
+
+
+def _configuration_fixture(configuration_content):
+    return f"""
+    <cib>
+      <configuration>
+      {configuration_content}
+      </configuration>
+      <status>
+      {configuration_content}
+      </status>
+      {configuration_content}
+    </cib>
+    """
+
+
+class FindElementsWithoutIdReferencingId(TestCase):
+    # pylint: disable=protected-access
+    def test_constraint_set_reference(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_REFERENCES_IN_CONSTRAINTS)
+        )
+        self.assertEqual(
+            [
+                cib.find(
+                    "./configuration/constraints/rsc_location/resource_set/resource_ref[@id='A']"
+                ),
+                cib.find(
+                    "./configuration/constraints/rsc_colocation/resource_set/resource_ref[@id='A']"
+                ),
+            ],
+            list(lib._find_elements_without_id_referencing_id(cib, "A")),
+        )
+
+    def test_tag_reference(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_REFERENCES_IN_TAGS)
+        )
+        self.assertEqual(
+            [
+                cib.find("./configuration/tags/tag[@id='X']/obj_ref[@id='A']"),
+                cib.find("./configuration/tags/tag[@id='Y']/obj_ref[@id='A']"),
+            ],
+            list(lib._find_elements_without_id_referencing_id(cib, "A")),
+        )
+
+    def test_acl_reference(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_REFERENCES_IN_ACLS)
+        )
+        self.assertEqual(
+            [
+                cib.find("./configuration/acls/acl_target/role[@id='A']"),
+                cib.find("./configuration/acls/acl_group/role[@id='A']"),
+            ],
+            list(lib._find_elements_without_id_referencing_id(cib, "A")),
+        )
+
+    def test_all_references_types(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_ALL_SECTIONS_WITH_REFERENCES)
+        )
+        self.assertEqual(
+            [
+                cib.find(
+                    "./configuration/constraints/rsc_location/resource_set/"
+                    "resource_ref[@id='A']"
+                ),
+                cib.find(
+                    "./configuration/constraints/rsc_colocation/resource_set/"
+                    "resource_ref[@id='A']"
+                ),
+                cib.find("./configuration/tags/tag[@id='X']/obj_ref[@id='A']"),
+                cib.find("./configuration/tags/tag[@id='Y']/obj_ref[@id='A']"),
+                cib.find("./configuration/acls/acl_target/role[@id='A']"),
+                cib.find("./configuration/acls/acl_group/role[@id='A']"),
+            ],
+            list(lib._find_elements_without_id_referencing_id(cib, "A")),
+        )
+
+    def test_no_reference_to_id(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_ALL_SECTIONS_WITH_REFERENCES)
+        )
+        self.assertEqual(
+            [], list(lib._find_elements_without_id_referencing_id(cib, "N"))
+        )
+
+
+class FindElementsReferencingId(TestCase):
+    def test_constraint_reference(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_REFERENCES_IN_CONSTRAINTS)
+        )
+        self.assertEqual(
+            [
+                cib.find(
+                    "./configuration/constraints/rsc_location/resource_set/"
+                    "resource_ref[@id='A']"
+                ),
+                cib.find(
+                    "./configuration/constraints/rsc_colocation/resource_set/"
+                    "resource_ref[@id='A']"
+                ),
+                cib.find(
+                    "./configuration/constraints/rsc_colocation[@rsc='A']"
+                ),
+                cib.find(
+                    "./configuration/constraints/rsc_colocation[@with-rsc='A']"
+                ),
+                cib.find("./configuration/constraints/rsc_location[@rsc='A']"),
+                cib.find("./configuration/constraints/rsc_order[@first='A']"),
+                cib.find("./configuration/constraints/rsc_order[@then='A']"),
+                cib.find(
+                    "./configuration/constraints/rsc_ticket[@id='ticket_rsc']"
+                ),
+            ],
+            list(lib.find_elements_referencing_id(cib, "A")),
+        )
+
+    def test_tag_reference(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_REFERENCES_IN_TAGS)
+        )
+        self.assertEqual(
+            [
+                cib.find("./configuration/tags/tag[@id='Y']/obj_ref[@id='C']"),
+                cib.find("./configuration/tags/tag[@id='Z']/obj_ref[@id='C']"),
+            ],
+            list(lib.find_elements_referencing_id(cib, "C")),
+        )
+
+    def test_acl_reference(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_REFERENCES_IN_ACLS)
+        )
+        self.assertEqual(
+            [
+                cib.find(
+                    "./configuration/acls/acl_role[@id='A']/acl_permission"
+                    "[@reference='A']"
+                ),
+                cib.find(
+                    "./configuration/acls/acl_role[@id='B']/acl_permission"
+                    "[@reference='A']"
+                ),
+                cib.find("./configuration/acls/acl_target/role[@id='A']"),
+                cib.find("./configuration/acls/acl_group/role[@id='A']"),
+            ],
+            list(lib.find_elements_referencing_id(cib, "A")),
+        )
+
+    def test_all_references_types(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_ALL_SECTIONS_WITH_REFERENCES)
+        )
+        self.assertEqual(
+            [
+                cib.find(
+                    "./configuration/constraints/rsc_colocation/resource_set/"
+                    "resource_ref[@id='C']"
+                ),
+                cib.find("./configuration/constraints/rsc_ticket[@rsc='C']"),
+                cib.find("./configuration/tags/tag[@id='Y']/obj_ref[@id='C']"),
+                cib.find("./configuration/tags/tag[@id='Z']/obj_ref[@id='C']"),
+                cib.find("./configuration/acls/acl_group/role[@id='C']"),
+            ],
+            list(lib.find_elements_referencing_id(cib, "C")),
+        )
+
+    def test_no_reference_to_id(self):
+        cib = etree.fromstring(
+            _configuration_fixture(FIXTURE_ALL_SECTIONS_WITH_REFERENCES)
+        )
+        self.assertEqual([], list(lib.find_elements_referencing_id(cib, "N")))
+
+
+class RemoveElementById(TestCase):
+    # pylint: disable=no-self-use
+    def test_element_not_found(self):
+        expected_cib = """<cib><configuration/></cib>"""
+        cib = etree.fromstring(expected_cib)
+        lib.remove_element_by_id(cib, "id-not-found")
+        assert_xml_equal(expected_cib, etree_to_str(cib))
+
+    def test_remove_element_without_references(self):
+        cib = etree.fromstring(
+            """
+            <cib>
+                <configuration>
+                    <resources>
+                        <primitive id="id-without-references"/>
+                    </resources>
+                </configuration>
+            </cib>
+            """
+        )
+        expected_cib = """
+            <cib>
+                <configuration>
+                    <resources/>
+                </configuration>
+            </cib>
+        """
+        lib.remove_element_by_id(cib, "id-without-references")
+        assert_xml_equal(expected_cib, etree_to_str(cib))
+
+    def test_remove_element_with_references(self):
+        cib = etree.fromstring(
+            """
+            <cib>
+                <configuration>
+                    <resources>
+                        <primitive id="id-with-references"/>
+                    </resources>
+                    <constraints>
+                        <any>
+                            <resource_set>
+                                <resource_ref id="id-with-references"/>
+                            </resource_set>
+                        </any>
+                        <resource_set>
+                            <resource_ref id="id-with-references"/>
+                        </resource_set>
+                    </constraints>
+                    <acls>
+                        <role id="id-with-references"/>
+                        <acl_target>
+                            <role id="id-with-references"/>
+                        </acl_target>
+                        <acl_group>
+                            <role id="id-with-references"/>
+                        </acl_group>
+                    </acls>
+                    <tags>
+                        <tag id="T1">
+                            <obj_ref id="id-with-references"/>
+                            <obj_ref id="B"/>
+                        </tag>
+                        <tag id="T2">
+                            <obj_ref id="id-with-references"/>
+                        </tag>
+                    </tags>
+                </configuration>
+                <status>
+                    <element id="id-with-references"/>
+                </status>
+                <element id="id-with-references"/>
+            </cib>
+            """
+        )
+        expected_cib = """
+            <cib>
+                <configuration>
+                    <resources/>
+                    <constraints>
+                        <any>
+                            <resource_set/>
+                        </any>
+                        <resource_set>
+                            <resource_ref id="id-with-references"/>
+                        </resource_set>
+                    </constraints>
+                    <acls>
+                        <role id="id-with-references"/>
+                        <acl_target>
+                        </acl_target>
+                        <acl_group>
+                        </acl_group>
+                    </acls>
+                    <tags>
+                        <tag id="T1">
+                            <obj_ref id="B"/>
+                        </tag>
+                        <tag id="T2">
+                        </tag>
+                    </tags>
+                </configuration>
+                <status>
+                    <element id="id-with-references"/>
+                </status>
+                <element id="id-with-references"/>
+            </cib>
+        """
+        lib.remove_element_by_id(cib, "id-with-references")
+        assert_xml_equal(expected_cib, etree_to_str(cib))
+
+    def test_assert_raised_for_duplicate_ids(self):
+        expected_cib = """
+            <cib>
+                <configuration>
+                    <element id="duplicate-id"/>
+                    <element id="duplicate-id"/>
+                </configuration>
+            </cib>
+        """
+        cib = etree.fromstring(expected_cib)
+        with self.assertRaises(AssertionError) as cm:
+            lib.remove_element_by_id(cib, "duplicate-id")
+        self.assertEqual(
+            str(cm.exception),
+            "Found more than one match for id 'duplicate-id' in the CIB",
+        )
+        assert_xml_equal(expected_cib, etree_to_str(cib))
+
+    def test_assert_not_raised_for_duplicate_ids(self):
+        expected_cib = """
+            <cib>
+                <configuration/>
+                <status>
+                    <element id="duplicate-id"/>
+                    <element id="duplicate-id"/>
+                </status>
+                <element id="duplicate-id"/>
+                <element id="duplicate-id"/>
+            </cib>
+        """
+        cib = etree.fromstring(expected_cib)
+        lib.remove_element_by_id(cib, "duplicate-id")
+        assert_xml_equal(expected_cib, etree_to_str(cib))
+
+    def test_missing_configuration_section(self):
+        expected_cib = """
+            <cib><element id="missing-configuration-section"/></cib>
+        """
+        cib = etree.fromstring(expected_cib)
+        assert_raise_library_error(
+            lambda: lib.remove_element_by_id(cib, "missing-config-section"),
+            fixture.error(
+                report_codes.CIB_CANNOT_FIND_MANDATORY_SECTION,
+                section="configuration",
+            ),
+        )
+        assert_xml_equal(expected_cib, etree_to_str(cib))
