@@ -1,19 +1,25 @@
-# pylint: disable=too-many-lines,no-member
+# pylint: disable=too-many-lines
+# pylint: disable=no-member
 import json
 import re
-
 from functools import partial
 from textwrap import dedent
-from unittest import TestCase
-
-from pcs_test.tools import fixture
-from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.misc import outdent
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from pcs import settings
 from pcs.common.reports import codes as report_codes
 from pcs.lib.commands import cluster
 
+from pcs_test.tools import fixture
+from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.command_env.config_http_corosync import (
+    corosync_running_check_response,
+)
+from pcs_test.tools.misc import outdent
+
 QDEVICE_HOST = "qdevice.host"
 CLUSTER_NAME = "myCluster"
 
@@ -422,46 +428,59 @@ class SuccessAtbRequired(TestCase):
             node_fixture(node, i)
             for i, node in enumerate(self.existing_nodes, 1)
         ]
+        sbd_config_data = dedent(
+            """
+            # This file has been generated by pcs.
+            SBD_DELAY_START=no
+            SBD_DEVICE=""
+            SBD_OPTS="-n rh85-node1"
+            SBD_PACEMAKER=yes
+            SBD_STARTMODE=always
+            SBD_WATCHDOG_DEV=/dev/watchdog
+            SBD_WATCHDOG_TIMEOUT=5
+        """
+        )
         self.config.env.set_known_nodes(self.existing_nodes)
-        (
-            self.config.corosync_conf.load_content(
-                corosync_conf_fixture(
-                    existing_corosync_nodes,
-                    _get_two_node(len(self.existing_nodes)),
-                )
+        self.config.corosync_conf.load_content(
+            corosync_conf_fixture(
+                existing_corosync_nodes,
+                _get_two_node(len(self.existing_nodes)),
             )
-            .http.host.check_auth(node_labels=self.existing_nodes)
-            .services.is_installed("sbd", return_value=True)
-            .services.is_enabled("sbd", return_value=True)
-            .http.corosync.check_corosync_offline(
-                node_labels=self.nodes_to_stay,
-            )
-            .local.destroy_cluster(self.nodes_to_remove)
-            .http.corosync.set_corosync_conf(
-                corosync_conf_fixture(
-                    existing_corosync_nodes[:-removing_num],
-                    [("auto_tie_breaker", "1")],
-                ),
-                node_labels=self.nodes_to_stay,
-            )
-            # corosync is not running
-            .http.corosync.reload_corosync_conf(
-                communication_list=[
-                    [
-                        dict(
-                            label=node,
-                            output=json.dumps(
-                                dict(code="not_running", message="")
-                            ),
-                        )
-                    ]
-                    for node in self.nodes_to_stay
+        )
+        self.config.http.host.check_auth(node_labels=self.existing_nodes)
+        self.config.services.is_installed("sbd", return_value=True)
+        self.config.services.is_enabled("sbd", return_value=True)
+        self.config.fs.exists(settings.sbd_config, return_value=True)
+        self.config.fs.open(
+            settings.sbd_config,
+            mock.mock_open(read_data=sbd_config_data)(),
+        )
+        self.config.http.corosync.check_corosync_offline(
+            node_labels=self.nodes_to_stay,
+        )
+        self.config.local.destroy_cluster(self.nodes_to_remove)
+        self.config.http.corosync.set_corosync_conf(
+            corosync_conf_fixture(
+                existing_corosync_nodes[:-removing_num],
+                [("auto_tie_breaker", "1")],
+            ),
+            node_labels=self.nodes_to_stay,
+        )
+        # corosync is not running
+        self.config.http.corosync.reload_corosync_conf(
+            communication_list=[
+                [
+                    dict(
+                        label=node,
+                        output=json.dumps(dict(code="not_running", message="")),
+                    )
                 ]
-            )
-            .http.pcmk.remove_nodes_from_cib(
-                self.nodes_to_remove,
-                node_labels=self.nodes_to_stay,
-            )
+                for node in self.nodes_to_stay
+            ]
+        )
+        self.config.http.pcmk.remove_nodes_from_cib(
+            self.nodes_to_remove,
+            node_labels=self.nodes_to_stay,
         )
         self.expected_reports.extend(
             [
@@ -472,7 +491,7 @@ class SuccessAtbRequired(TestCase):
             ]
             + [
                 fixture.info(
-                    report_codes.COROSYNC_NOT_RUNNING_ON_NODE,
+                    report_codes.COROSYNC_NOT_RUNNING_CHECK_NODE_STOPPED,
                     node=node,
                 )
                 for node in self.nodes_to_stay
@@ -542,6 +561,18 @@ class FailureAtbRequired(TestCase):
         self.config.local.set_expected_reports_list(self.expected_reports)
         staying_num = 4
         removing_num = 2
+        sbd_config_data = dedent(
+            """
+            # This file has been generated by pcs.
+            SBD_DELAY_START=no
+            SBD_DEVICE=""
+            SBD_OPTS="-n rh85-node1"
+            SBD_PACEMAKER=yes
+            SBD_STARTMODE=always
+            SBD_WATCHDOG_DEV=/dev/watchdog
+            SBD_WATCHDOG_TIMEOUT=5
+        """
+        )
         self.existing_nodes = [
             f"node{i}" for i in range(staying_num + removing_num)
         ]
@@ -552,26 +583,105 @@ class FailureAtbRequired(TestCase):
             for i, node in enumerate(self.existing_nodes, 1)
         ]
         self.config.env.set_known_nodes(self.existing_nodes)
-        (
-            self.config.corosync_conf.load_content(
-                corosync_conf_fixture(
-                    existing_corosync_nodes,
-                    _get_two_node(len(self.existing_nodes)),
-                )
+        self.config.corosync_conf.load_content(
+            corosync_conf_fixture(
+                existing_corosync_nodes,
+                _get_two_node(len(self.existing_nodes)),
             )
-            .http.host.check_auth(node_labels=self.existing_nodes)
-            .services.is_installed("sbd", return_value=True)
-            .services.is_enabled("sbd", return_value=True)
+        )
+        self.config.http.host.check_auth(node_labels=self.existing_nodes)
+        self.config.services.is_installed("sbd", return_value=True)
+        self.config.services.is_enabled("sbd", return_value=True)
+        self.config.fs.exists(settings.sbd_config, return_value=True)
+        self.config.fs.open(
+            settings.sbd_config,
+            mock.mock_open(read_data=sbd_config_data)(),
         )
         self.expected_reports.extend(
             [
-                fixture.warn(
-                    report_codes.COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD
-                ),
                 fixture.info(report_codes.COROSYNC_NOT_RUNNING_CHECK_STARTED),
             ]
         )
 
+    def test_cluster_is_running_somewhere(self):
+        self.config.http.corosync.check_corosync_offline(
+            communication_list=[
+                {"label": self.nodes_to_stay[0]},
+                {
+                    "label": self.nodes_to_stay[1],
+                    "output": corosync_running_check_response(True),
+                },
+                {"label": self.nodes_to_stay[2]},
+                {"label": self.nodes_to_stay[3]},
+            ]
+        )
+
+        self.env_assist.assert_raise_library_error(
+            lambda: cluster.remove_nodes(
+                self.env_assist.get_env(),
+                self.nodes_to_remove,
+            )
+        )
+
+        self.env_assist.assert_reports(
+            self.expected_reports
+            + [
+                fixture.info(
+                    report_codes.COROSYNC_NOT_RUNNING_CHECK_NODE_STOPPED,
+                    node=self.nodes_to_stay[0],
+                ),
+                fixture.error(
+                    report_codes.COROSYNC_NOT_RUNNING_CHECK_NODE_RUNNING,
+                    node=self.nodes_to_stay[1],
+                ),
+                fixture.info(
+                    report_codes.COROSYNC_NOT_RUNNING_CHECK_NODE_STOPPED,
+                    node=self.nodes_to_stay[2],
+                ),
+                fixture.info(
+                    report_codes.COROSYNC_NOT_RUNNING_CHECK_NODE_STOPPED,
+                    node=self.nodes_to_stay[3],
+                ),
+                fixture.error(
+                    report_codes.COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD_CLUSTER_IS_RUNNING
+                ),
+            ]
+        )
+
+    def test_cluster_is_running_everywhere(self):
+        self.config.http.corosync.check_corosync_offline(
+            communication_list=[
+                {
+                    "label": node,
+                    "output": corosync_running_check_response(True),
+                }
+                for node in self.nodes_to_stay
+            ]
+        )
+
+        self.env_assist.assert_raise_library_error(
+            lambda: cluster.remove_nodes(
+                self.env_assist.get_env(),
+                self.nodes_to_remove,
+            )
+        )
+
+        self.env_assist.assert_reports(
+            self.expected_reports
+            + [
+                fixture.error(
+                    report_codes.COROSYNC_NOT_RUNNING_CHECK_NODE_RUNNING,
+                    node=node,
+                )
+                for node in self.nodes_to_stay
+            ]
+            + [
+                fixture.error(
+                    report_codes.COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD_CLUSTER_IS_RUNNING
+                ),
+            ]
+        )
+
     def test_failed_on_some(self):
         err_output = "an error"
         self.config.http.corosync.check_corosync_offline(
@@ -602,7 +712,7 @@ class FailureAtbRequired(TestCase):
             self.expected_reports
             + [
                 fixture.info(
-                    report_codes.COROSYNC_NOT_RUNNING_ON_NODE,
+                    report_codes.COROSYNC_NOT_RUNNING_CHECK_NODE_STOPPED,
                     node=node,
                 )
                 for node in [self.nodes_to_stay[0], self.nodes_to_stay[2]]
@@ -624,6 +734,9 @@ class FailureAtbRequired(TestCase):
                     node=self.nodes_to_stay[3],
                     force_code=None,
                 ),
+                fixture.warn(
+                    report_codes.COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD
+                ),
             ]
         )
 
@@ -666,6 +779,11 @@ class FailureAtbRequired(TestCase):
                 )
                 for node in self.nodes_to_stay
             ]
+            + [
+                fixture.warn(
+                    report_codes.COROSYNC_QUORUM_ATB_WILL_BE_ENABLED_DUE_TO_SBD
+                ),
+            ]
         )
 
 
@@ -2575,7 +2693,7 @@ class OfflineNodes(TestCase):
     def test_all_removed_unknown(self):
         (
             self.config.env.set_known_nodes(self.nodes_to_stay)
-            .http.host.check_auth(node_labels=(self.nodes_to_stay))
+            .http.host.check_auth(node_labels=self.nodes_to_stay)
             # SBD not installed
             .services.is_installed(
                 "sbd",
@@ -2610,7 +2728,7 @@ class OfflineNodes(TestCase):
     def test_all_removed_unknown_forced(self):
         (
             self.config.env.set_known_nodes(self.nodes_to_stay)
-            .http.host.check_auth(node_labels=(self.nodes_to_stay))
+            .http.host.check_auth(node_labels=self.nodes_to_stay)
             # SBD not installed
             .services.is_installed(
                 "sbd",
