@@ -1,16 +1,18 @@
-from unittest import mock, TestCase
-
-from pcs_test.tools import fixture
-from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.misc import get_test_resource as rc
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from pcs import settings
 from pcs.common.reports import codes as report_codes
 from pcs.lib.commands.cluster import verify
 
+from pcs_test.tools import fixture
+from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.misc import get_test_resource as rc
 
 CRM_VERIFY_ERROR_REPORT_LINES = [
-    "someting wrong\nsomething else wrong\n",
+    "something wrong\nsomething else wrong\n",
     "  Use -V -V for more detail\n",
 ]
 
@@ -57,7 +59,9 @@ class AssertInvalidCibMixin:
         )
 
 
-@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
 class CibAsWholeValid(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
@@ -91,14 +95,18 @@ class CibAsWholeInvalid(TestCase, AssertInvalidCibMixin):
         self.assert_raises_invalid_cib_content(CRM_VERIFY_ERROR_REPORT_LINES[0])
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_continue_on_loadable_cib(self):
         (self.config.runner.cib.load().runner.pcmk.load_state())
         self.assert_raises_invalid_cib_content(CRM_VERIFY_ERROR_REPORT_LINES[0])
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_add_following_errors(self):
         # More fencing topology tests are provided by tests of
@@ -114,18 +122,23 @@ class CibAsWholeInvalid(TestCase, AssertInvalidCibMixin):
         )
 
 
-@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
 class CibIsMocked(TestCase, AssertInvalidCibMixin):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
         self.cib_tempfile = "/fake/tmp/file"
+        self.cmd_env = dict(CIB_file=self.cib_tempfile)
         self.config.env.set_cib_data("<cib/>", cib_tempfile=self.cib_tempfile)
 
     def test_success_on_valid_cib(self):
         (
-            self.config.runner.pcmk.verify(cib_tempfile=self.cib_tempfile)
-            .runner.cib.load()
-            .runner.pcmk.load_state()
+            self.config.runner.pcmk.verify(
+                cib_tempfile=self.cib_tempfile, env=self.cmd_env
+            )
+            .runner.cib.load(env=self.cmd_env)
+            .runner.pcmk.load_state(env=self.cmd_env)
         )
         verify(self.env_assist.get_env())
 
@@ -134,14 +147,17 @@ class CibIsMocked(TestCase, AssertInvalidCibMixin):
             self.config.runner.pcmk.verify(
                 stderr="".join(CRM_VERIFY_ERROR_REPORT_LINES),
                 cib_tempfile=self.cib_tempfile,
+                env=self.cmd_env,
             )
-            .runner.cib.load()
-            .runner.pcmk.load_state()
+            .runner.cib.load(env=self.cmd_env)
+            .runner.pcmk.load_state(env=self.cmd_env)
         )
         self.assert_raises_invalid_cib_content(CRM_VERIFY_ERROR_REPORT_LINES[0])
 
 
-@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
 class VerboseMode(TestCase, AssertInvalidCibMixin):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
