@@ -13,19 +13,17 @@ from pcs.common.file import RawFileError
 from pcs.common.host import Destination
 from pcs.lib.commands.remote_node import node_add_remote as node_add_remote_orig
 
-from pcs_test.tier0.lib.commands.remote_node.fixtures_add import (
-    EXTRA_REPORTS as FIXTURE_EXTRA_REPORTS,
-)
 from pcs_test.tier0.lib.commands.remote_node.fixtures_add import (
     FAIL_HTTP_KWARGS,
-)
-from pcs_test.tier0.lib.commands.remote_node.fixtures_add import (
-    REPORTS as FIXTURE_REPORTS,
-)
-from pcs_test.tier0.lib.commands.remote_node.fixtures_add import (
     EnvConfigMixin,
+    base_reports_for_host,
     fixture_reports_new_node_unreachable,
     fixture_reports_not_live_cib,
+    report_authkey_distribution_failed,
+    report_manage_services_connection_failed,
+    report_pcmk_remote_enable_failed,
+    report_pcmk_remote_start_failed,
+    report_put_file_connection_failed,
 )
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
@@ -81,28 +79,7 @@ class LocalConfig(EnvConfigMixin):
 
 get_env_tools = partial(get_env_tools, local_extensions={"local": LocalConfig})
 
-REPORTS = (
-    FIXTURE_REPORTS.adapt("authkey_distribution_started", node_list=[NODE_NAME])
-    .adapt("authkey_distribution_success", node=NODE_NAME)
-    .adapt("pcmk_remote_start_enable_started", node_list=[NODE_NAME])
-    .adapt("pcmk_remote_enable_success", node=NODE_NAME)
-    .adapt("pcmk_remote_start_success", node=NODE_NAME)
-)
-EXTRA_REPORTS = FIXTURE_EXTRA_REPORTS.adapt_multi(
-    [
-        "manage_services_connection_failed",
-        "manage_services_connection_failed_warn",
-        "put_file_connection_failed",
-        "put_file_connection_failed_warn",
-        "pcmk_remote_enable_failed",
-        "pcmk_remote_enable_failed_warn",
-        "pcmk_remote_start_failed",
-        "pcmk_remote_start_failed_warn",
-        "authkey_distribution_failed",
-        "authkey_distribution_failed_warn",
-    ],
-    node=NODE_NAME,
-)
+REPORTS = base_reports_for_host(NODE_NAME)
 
 
 FIXTURE_RESOURCES_TEMPLATE = """
@@ -152,20 +129,20 @@ class AddRemote(TestCase):
     def _config_success_base(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .http.host.check_auth(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-            )
-            .local.get_host_info(NODE_NAME, NODE_DEST_LIST)
-            .local.push_existing_authkey_to_remote(NODE_NAME, NODE_DEST_LIST)
-            .local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
-            .env.push_cib(resources=FIXTURE_RESOURCES)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+        )
+        self.config.local.get_host_info(NODE_NAME, NODE_DEST_LIST)
+        self.config.local.push_existing_authkey_to_remote(
+            NODE_NAME, NODE_DEST_LIST
+        )
+        self.config.local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
+        self.config.env.push_cib(resources=FIXTURE_RESOURCES)
 
     def test_success_base(self):
         self._config_success_base()
@@ -229,25 +206,23 @@ class AddRemote(TestCase):
             ],
         )
         self.env_assist.assert_reports(
-            REPORTS.info(
-                "cib_upgrade_successful", reports.codes.CIB_UPGRADE_SUCCESSFUL
+            fixture.ReportSequenceBuilder(REPORTS.copy()).info(
+                reports.codes.CIB_UPGRADE_SUCCESSFUL
             )
         )
 
     def test_node_name_conflict_report_is_unique(self):
-        (
-            self.config.runner.cib.load(
-                resources="""
-                    <resources>
-                        <primitive class="ocf" id="node-name"
-                            provider="pacemaker" type="Dummy"
-                        />
-                    </resources>
-                """
-            )
-            .corosync_conf.load(node_name_list=[NODE_1, NODE_2])
-            .runner.pcmk.load_agent(agent_name="ocf:pacemaker:remote")
+        self.config.runner.cib.load(
+            resources="""
+                <resources>
+                    <primitive class="ocf" id="node-name"
+                        provider="pacemaker" type="Dummy"
+                    />
+                </resources>
+            """
         )
+        self.config.corosync_conf.load(node_name_list=[NODE_1, NODE_2])
+        self.config.runner.pcmk.load_agent(agent_name="ocf:pacemaker:remote")
 
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env()), []
@@ -266,63 +241,60 @@ class AddRemote(TestCase):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
         generate_binary_key.return_value = b"password"
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .http.host.check_auth(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-            )
-            .local.get_host_info(NODE_NAME, NODE_DEST_LIST)
-            .local.authkey_exists(return_value=False)
-            .local.distribute_authkey(
-                communication_list=[
-                    dict(label=NODE_1, dest_list=NODE_1_DEST_LIST),
-                    dict(label=NODE_2, dest_list=NODE_2_DEST_LIST),
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST),
-                ],
-                pcmk_authkey_content=generate_binary_key.return_value,
-            )
-            .local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
-            .env.push_cib(resources=FIXTURE_RESOURCES)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+        )
+        self.config.local.get_host_info(NODE_NAME, NODE_DEST_LIST)
+        self.config.local.authkey_exists(return_value=False)
+        self.config.local.distribute_authkey(
+            communication_list=[
+                dict(label=NODE_1, dest_list=NODE_1_DEST_LIST),
+                dict(label=NODE_2, dest_list=NODE_2_DEST_LIST),
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST),
+            ],
+            pcmk_authkey_content=generate_binary_key.return_value,
+        )
+        self.config.local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
+        self.config.env.push_cib(resources=FIXTURE_RESOURCES)
+
         node_add_remote(self.env_assist.get_env())
         generate_binary_key.assert_called_once_with(random_bytes_count=256)
-        self.env_assist.assert_reports(
-            REPORTS.adapt(
-                "authkey_distribution_started",
+        my_reports = REPORTS.copy()
+        my_reports.replace(
+            "authkey_distribution_started",
+            REPORTS["authkey_distribution_started"].adapt(
                 node_list=[NODE_1, NODE_2, NODE_NAME],
-            )
-            .copy(
-                "authkey_distribution_success",
-                "authkey_distribution_success_node1",
-                node=NODE_1,
-            )
-            .copy(
-                "authkey_distribution_success",
-                "authkey_distribution_success_node2",
-                node=NODE_2,
-            )
+            ),
         )
+        my_reports.append(
+            REPORTS["authkey_distribution_success"].adapt(node=NODE_1),
+        )
+        my_reports.append(
+            REPORTS["authkey_distribution_success"].adapt(node=NODE_2),
+        )
+        self.env_assist.assert_reports(my_reports)
 
     def test_new_offline(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            ).http.host.check_auth(
-                communication_list=[
-                    dict(
-                        label=NODE_NAME,
-                        dest_list=NODE_DEST_LIST,
-                        **FAIL_HTTP_KWARGS,
-                    )
-                ],
-            )
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(
+                    label=NODE_NAME,
+                    dest_list=NODE_DEST_LIST,
+                    **FAIL_HTTP_KWARGS,
+                )
+            ],
+        )
+
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env()), []
         )
@@ -342,23 +314,22 @@ class AddRemote(TestCase):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
         pcmk_authkey_content = b"password"
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .http.host.check_auth(
-                communication_list=[
-                    dict(
-                        label=NODE_NAME,
-                        dest_list=NODE_DEST_LIST,
-                        **FAIL_HTTP_KWARGS,
-                    )
-                ],
-            )
-            .local.authkey_exists(return_value=True)
-            .local.open_authkey(pcmk_authkey_content)
-            .env.push_cib(resources=FIXTURE_RESOURCES)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(
+                    label=NODE_NAME,
+                    dest_list=NODE_DEST_LIST,
+                    **FAIL_HTTP_KWARGS,
+                )
+            ],
+        )
+        self.config.local.authkey_exists(return_value=True)
+        self.config.local.open_authkey(pcmk_authkey_content)
+        self.config.env.push_cib(resources=FIXTURE_RESOURCES)
+
         node_add_remote(self.env_assist.get_env(), skip_offline_nodes=True)
         self.env_assist.assert_reports(
             fixture_reports_new_node_unreachable(NODE_NAME, omitting=True)
@@ -369,30 +340,29 @@ class AddRemote(TestCase):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
         generate_binary_key.return_value = b"password"
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .http.host.check_auth(
-                communication_list=[
-                    dict(
-                        label=NODE_NAME,
-                        dest_list=NODE_DEST_LIST,
-                        **FAIL_HTTP_KWARGS,
-                    )
-                ],
-            )
-            .local.authkey_exists(return_value=False)
-            .local.distribute_authkey(
-                communication_list=[
-                    dict(label=NODE_1, dest_list=NODE_1_DEST_LIST),
-                    dict(label=NODE_2, dest_list=NODE_2_DEST_LIST),
-                ],
-                pcmk_authkey_content=generate_binary_key.return_value,
-                **FAIL_HTTP_KWARGS,
-            )
-            .env.push_cib(resources=FIXTURE_RESOURCES)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(
+                    label=NODE_NAME,
+                    dest_list=NODE_DEST_LIST,
+                    **FAIL_HTTP_KWARGS,
+                )
+            ],
+        )
+        self.config.local.authkey_exists(return_value=False)
+        self.config.local.distribute_authkey(
+            communication_list=[
+                dict(label=NODE_1, dest_list=NODE_1_DEST_LIST),
+                dict(label=NODE_2, dest_list=NODE_2_DEST_LIST),
+            ],
+            pcmk_authkey_content=generate_binary_key.return_value,
+            **FAIL_HTTP_KWARGS,
+        )
+        self.config.env.push_cib(resources=FIXTURE_RESOURCES)
+
         node_add_remote(self.env_assist.get_env(), skip_offline_nodes=True)
         self.env_assist.assert_reports(
             fixture_reports_new_node_unreachable(NODE_NAME, omitting=True)
@@ -420,34 +390,29 @@ class AddRemote(TestCase):
     def test_fails_when_remote_node_is_not_prepared(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .http.host.check_auth(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-            )
-            .local.get_host_info(
-                NODE_NAME,
-                NODE_DEST_LIST,
-                output=dict(
-                    services=dict(
-                        pacemaker_remote=dict(
-                            installed=False, enabled=False, running=False
-                        ),
-                        pacemaker=dict(
-                            installed=True, enabled=False, running=True
-                        ),
-                        corosync=dict(
-                            installed=True, enabled=False, running=True
-                        ),
-                    ),
-                    cluster_configuration_exists=True,
-                ),
-            )
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+        )
+        self.config.local.get_host_info(
+            NODE_NAME,
+            NODE_DEST_LIST,
+            output=dict(
+                services=dict(
+                    pacemaker_remote=dict(
+                        installed=False, enabled=False, running=False
+                    ),
+                    pacemaker=dict(installed=True, enabled=False, running=True),
+                    corosync=dict(installed=True, enabled=False, running=True),
+                ),
+                cluster_configuration_exists=True,
+            ),
+        )
+
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env()), []
         )
@@ -473,19 +438,18 @@ class AddRemote(TestCase):
     def test_fails_when_remote_node_returns_invalid_output(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .http.host.check_auth(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-            )
-            .local.get_host_info(
-                NODE_NAME, NODE_DEST_LIST, output="INVALID_OUTPUT"
-            )
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+        )
+        self.config.local.get_host_info(
+            NODE_NAME, NODE_DEST_LIST, output="INVALID_OUTPUT"
+        )
+
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env()), []
         )
@@ -501,19 +465,17 @@ class AddRemote(TestCase):
     def test_open_failed(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .http.host.check_auth(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-            )
-            .local.get_host_info(NODE_NAME, NODE_DEST_LIST)
-            .local.authkey_exists(return_value=True)
-            .local.open_authkey(fail=True)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+        )
+        self.config.local.get_host_info(NODE_NAME, NODE_DEST_LIST)
+        self.config.local.authkey_exists(return_value=True)
+        self.config.local.open_authkey(fail=True)
 
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(
@@ -585,14 +547,13 @@ class AddRemote(TestCase):
                 NODE_2: NODE_2_DEST_LIST,
             }
         )
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .local.authkey_exists(return_value=True)
-            .local.open_authkey(pcmk_authkey_content)
-            .env.push_cib(resources=FIXTURE_RESOURCES)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.local.authkey_exists(return_value=True)
+        self.config.local.open_authkey(pcmk_authkey_content)
+        self.config.env.push_cib(resources=FIXTURE_RESOURCES)
+
         node_add_remote(self.env_assist.get_env(), skip_offline_nodes=True)
         self.env_assist.assert_reports(
             fixture_reports_new_node_unreachable(NODE_NAME)
@@ -611,20 +572,19 @@ class AddRemote(TestCase):
                 NODE_2: NODE_2_DEST_LIST,
             }
         )
-        (
-            self.config.local.load_cluster_configs(
-                cluster_node_list=[NODE_1, NODE_2]
-            )
-            .local.authkey_exists(return_value=False)
-            .local.distribute_authkey(
-                communication_list=[
-                    dict(label=NODE_1, dest_list=NODE_1_DEST_LIST),
-                    dict(label=NODE_2, dest_list=NODE_2_DEST_LIST),
-                ],
-                pcmk_authkey_content=generate_binary_key.return_value,
-            )
-            .env.push_cib(resources=FIXTURE_RESOURCES)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.local.authkey_exists(return_value=False)
+        self.config.local.distribute_authkey(
+            communication_list=[
+                dict(label=NODE_1, dest_list=NODE_1_DEST_LIST),
+                dict(label=NODE_2, dest_list=NODE_2_DEST_LIST),
+            ],
+            pcmk_authkey_content=generate_binary_key.return_value,
+        )
+        self.config.env.push_cib(resources=FIXTURE_RESOURCES)
+
         node_add_remote(self.env_assist.get_env(), skip_offline_nodes=True)
         generate_binary_key.assert_called_once_with(random_bytes_count=256)
         self.env_assist.assert_reports(
@@ -650,23 +610,21 @@ class AddRemote(TestCase):
 
     def test_some_node_names_missing(self):
         self._config_success_base()
-        (
-            self.config.env.set_known_hosts_dests(
-                {
-                    "rh7-1": [Destination("rh7-1", 2224)],
-                    "rh7-2": [Destination("rh7-2", 2224)],
-                    NODE_NAME: NODE_DEST_LIST,
-                }
-            ).corosync_conf.load(
-                filename="corosync-some-node-names.conf",
-                instead="corosync_conf.load",
-            )
+        self.config.env.set_known_hosts_dests(
+            {
+                "rh7-1": [Destination("rh7-1", 2224)],
+                "rh7-2": [Destination("rh7-2", 2224)],
+                NODE_NAME: NODE_DEST_LIST,
+            }
+        )
+        self.config.corosync_conf.load(
+            filename="corosync-some-node-names.conf",
+            instead="corosync_conf.load",
         )
 
         node_add_remote(self.env_assist.get_env())
         self.env_assist.assert_reports(
-            REPORTS.warn(
-                "missing_node_names_in_corosync",
+            fixture.ReportSequenceBuilder(REPORTS.copy()).warn(
                 reports.codes.COROSYNC_CONFIG_MISSING_NAMES_OF_NODES,
                 fatal=False,
             )
@@ -679,8 +637,7 @@ class AddRemote(TestCase):
         )
         node_add_remote(self.env_assist.get_env())
         self.env_assist.assert_reports(
-            REPORTS.warn(
-                "missing_node_names_in_corosync",
+            fixture.ReportSequenceBuilder(REPORTS.copy()).warn(
                 reports.codes.COROSYNC_CONFIG_MISSING_NAMES_OF_NODES,
                 fatal=False,
             )
@@ -791,21 +748,25 @@ class NotLive(TestCase):
 )
 class WithWait(TestCase):
     def setUp(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         self.wait = 1
         self.env_assist, self.config = get_env_tools(self)
-        (
-            self.config.env.set_known_hosts_dests(KNOWN_HOSTS_DESTS)
-            .local.load_cluster_configs(cluster_node_list=[NODE_1, NODE_2])
-            .http.host.check_auth(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-            )
-            .local.get_host_info(NODE_NAME, NODE_DEST_LIST)
-            .local.push_existing_authkey_to_remote(NODE_NAME, NODE_DEST_LIST)
-            .local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
-            .env.push_cib(resources=FIXTURE_RESOURCES, wait=self.wait)
+        self.config.env.set_known_hosts_dests(KNOWN_HOSTS_DESTS)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+        )
+        self.config.local.get_host_info(NODE_NAME, NODE_DEST_LIST)
+        self.config.local.push_existing_authkey_to_remote(
+            NODE_NAME, NODE_DEST_LIST
+        )
+        self.config.local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
+        self.config.env.push_cib(resources=FIXTURE_RESOURCES, wait=self.wait)
 
     def test_success_when_resource_started(self):
         self.config.runner.pcmk.load_state(
@@ -822,8 +783,7 @@ class WithWait(TestCase):
         )
         node_add_remote(self.env_assist.get_env(), wait=self.wait)
         self.env_assist.assert_reports(
-            REPORTS.info(
-                "resource_running",
+            fixture.ReportSequenceBuilder(REPORTS.copy()).info(
                 reports.codes.RESOURCE_RUNNING_ON_NODES,
                 roles_with_nodes={"Started": [NODE_1]},
                 resource_id=NODE_NAME,
@@ -848,29 +808,30 @@ class WithWait(TestCase):
             lambda: node_add_remote(self.env_assist.get_env(), wait=self.wait)
         )
         self.env_assist.assert_reports(
-            REPORTS.reports
-            + [
-                fixture.error(
-                    reports.codes.RESOURCE_DOES_NOT_RUN,
-                    resource_id=NODE_NAME,
-                )
-            ]
+            fixture.ReportSequenceBuilder(REPORTS.copy()).error(
+                reports.codes.RESOURCE_DOES_NOT_RUN,
+                resource_id=NODE_NAME,
+            )
         )
 
 
 class AddRemotePcmkRemoteService(TestCase):
     def setUp(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         self.env_assist, self.config = get_env_tools(self)
-        (
-            self.config.env.set_known_hosts_dests(KNOWN_HOSTS_DESTS)
-            .local.load_cluster_configs(cluster_node_list=[NODE_1, NODE_2])
-            .http.host.check_auth(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-            )
-            .local.get_host_info(NODE_NAME, NODE_DEST_LIST)
-            .local.push_existing_authkey_to_remote(NODE_NAME, NODE_DEST_LIST)
+        self.config.env.set_known_hosts_dests(KNOWN_HOSTS_DESTS)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
+        )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+        )
+        self.config.local.get_host_info(NODE_NAME, NODE_DEST_LIST)
+        self.config.local.push_existing_authkey_to_remote(
+            NODE_NAME, NODE_DEST_LIST
         )
 
     def test_fails_when_offline(self):
@@ -883,10 +844,9 @@ class AddRemotePcmkRemoteService(TestCase):
             lambda: node_add_remote(self.env_assist.get_env())
         )
 
-        self.env_assist.assert_reports(
-            REPORTS[:"pcmk_remote_enable_success"]
-            + EXTRA_REPORTS.select("manage_services_connection_failed")
-        )
+        my_reports = REPORTS[:"pcmk_remote_enable_success"]
+        my_reports.append(report_manage_services_connection_failed(NODE_NAME))
+        self.env_assist.assert_reports(my_reports)
 
     def test_fail_when_remotely_fail(self):
         # Instance of 'Config' has no 'local' member
@@ -902,13 +862,10 @@ class AddRemotePcmkRemoteService(TestCase):
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env())
         )
-        self.env_assist.assert_reports(
-            REPORTS[:"pcmk_remote_enable_success"]
-            + EXTRA_REPORTS.select(
-                "pcmk_remote_enable_failed",
-                "pcmk_remote_start_failed",
-            )
-        )
+        my_reports = REPORTS[:"pcmk_remote_enable_success"]
+        my_reports.append(report_pcmk_remote_enable_failed(NODE_NAME))
+        my_reports.append(report_pcmk_remote_start_failed(NODE_NAME))
+        self.env_assist.assert_reports(my_reports)
 
     def test_forceable_when_remotely_fail(self):
         # Instance of 'Config' has no 'local' member
@@ -925,54 +882,48 @@ class AddRemotePcmkRemoteService(TestCase):
             self.env_assist.get_env(), allow_pacemaker_remote_service_fail=True
         )
 
-        self.env_assist.assert_reports(
-            REPORTS[:"pcmk_remote_enable_success"]
-            + EXTRA_REPORTS.select(
-                "pcmk_remote_enable_failed_warn",
-                "pcmk_remote_start_failed_warn",
-            )
-        )
+        my_reports = REPORTS[:"pcmk_remote_enable_success"]
+        my_reports.append(report_pcmk_remote_enable_failed(NODE_NAME).to_warn())
+        my_reports.append(report_pcmk_remote_start_failed(NODE_NAME).to_warn())
+        self.env_assist.assert_reports(my_reports)
 
 
 class AddRemoteAuthkeyDistribution(TestCase):
     def setUp(self):
+        # Instance of 'Config' has no 'local' member
+        # pylint: disable=no-member
         self.env_assist, self.config = get_env_tools(self)
-        (
-            self.config.env.set_known_hosts_dests(KNOWN_HOSTS_DESTS)
-            .local.load_cluster_configs(cluster_node_list=[NODE_1, NODE_2])
-            .http.host.check_auth(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-            )
-            .local.get_host_info(NODE_NAME, NODE_DEST_LIST)
+        self.config.env.set_known_hosts_dests(KNOWN_HOSTS_DESTS)
+        self.config.local.load_cluster_configs(
+            cluster_node_list=[NODE_1, NODE_2]
         )
+        self.config.http.host.check_auth(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+        )
+        self.config.local.get_host_info(NODE_NAME, NODE_DEST_LIST)
 
     def test_fails_when_offline(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
         pcmk_authkey_content = b"password"
-        (
-            self.config.local.authkey_exists(return_value=True)
-            .local.open_authkey(pcmk_authkey_content)
-            .local.distribute_authkey(
-                communication_list=[
-                    dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
-                ],
-                pcmk_authkey_content=pcmk_authkey_content,
-                **FAIL_HTTP_KWARGS,
-            )
+        self.config.local.authkey_exists(return_value=True)
+        self.config.local.open_authkey(pcmk_authkey_content)
+        self.config.local.distribute_authkey(
+            communication_list=[
+                dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
+            ],
+            pcmk_authkey_content=pcmk_authkey_content,
+            **FAIL_HTTP_KWARGS,
         )
+
         self.env_assist.assert_raise_library_error(
             lambda: node_add_remote(self.env_assist.get_env())
         )
-        self.env_assist.assert_reports(
-            REPORTS[:"authkey_distribution_success"]
-            + EXTRA_REPORTS.only(
-                "manage_services_connection_failed",
-                command="remote/put_file",
-            )
-        )
+        my_reports = REPORTS[:"authkey_distribution_success"]
+        my_reports.append(report_put_file_connection_failed(NODE_NAME))
+        self.env_assist.assert_reports(my_reports)
 
     def test_fail_when_remotely_fail(self):
         # Instance of 'Config' has no 'local' member
@@ -990,33 +941,32 @@ class AddRemoteAuthkeyDistribution(TestCase):
             lambda: node_add_remote(self.env_assist.get_env())
         )
 
-        self.env_assist.assert_reports(
-            REPORTS[:"authkey_distribution_success"]
-            + EXTRA_REPORTS.select("authkey_distribution_failed")
-        )
+        my_reports = REPORTS[:"authkey_distribution_success"]
+        my_reports.append(report_authkey_distribution_failed(NODE_NAME))
+        self.env_assist.assert_reports(my_reports)
 
     def test_forceable_when_remotely_fail(self):
         # Instance of 'Config' has no 'local' member
         # pylint: disable=no-member
-        (
-            self.config.local.push_existing_authkey_to_remote(
-                NODE_NAME,
-                NODE_DEST_LIST,
-                distribution_result={
-                    "code": "conflict",
-                    "message": "",
-                },
-            )
-            .local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
-            .env.push_cib(resources=FIXTURE_RESOURCES)
+        self.config.local.push_existing_authkey_to_remote(
+            NODE_NAME,
+            NODE_DEST_LIST,
+            distribution_result={
+                "code": "conflict",
+                "message": "",
+            },
         )
+        self.config.local.run_pacemaker_remote(NODE_NAME, NODE_DEST_LIST)
+        self.config.env.push_cib(resources=FIXTURE_RESOURCES)
 
         node_add_remote(
             self.env_assist.get_env(),
             allow_incomplete_distribution=True,
         )
 
-        self.env_assist.assert_reports(
-            REPORTS.remove("authkey_distribution_success")
-            + EXTRA_REPORTS.select("authkey_distribution_failed_warn")
+        my_reports = REPORTS.copy()
+        my_reports.replace(
+            "authkey_distribution_success",
+            report_authkey_distribution_failed(NODE_NAME).to_warn(),
         )
+        self.env_assist.assert_reports(my_reports)
