@@ -1,10 +1,6 @@
 from textwrap import dedent
 from unittest import mock
 
-from pcs_test.tools import fixture
-from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.misc import get_test_resource as rc
-
 from pcs import settings
 from pcs.common import reports
 from pcs.common.reports import ReportItemSeverity as severities
@@ -17,6 +13,10 @@ from pcs.lib.cib.resource.bundle import (
 )
 from pcs.lib.errors import LibraryError
 
+from pcs_test.tools import fixture
+from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.misc import get_test_resource as rc
+
 TIMEOUT = 10
 
 
@@ -45,7 +45,6 @@ class SetUpMixin:
     initial_cib_filename = "cib-empty.xml"
 
     def setUp(self):
-        # pylint: disable=invalid-name
         self.env_assist, self.config = get_env_tools(test_case=self)
         self.config.runner.cib.load(
             filename=self.initial_cib_filename,
@@ -140,7 +139,7 @@ class ParametrizedContainerMixin(SetUpMixin):
         self.env_assist.assert_reports(
             [
                 (
-                    severities.WARNING,
+                    severities.DEPRECATION,
                     report_codes.DEPRECATED_OPTION,
                     {
                         "option_name": "masters",
@@ -167,7 +166,7 @@ class ParametrizedContainerMixin(SetUpMixin):
         self.env_assist.assert_reports(
             [
                 (
-                    severities.WARNING,
+                    severities.DEPRECATION,
                     report_codes.DEPRECATED_OPTION,
                     {
                         "option_name": "masters",
@@ -532,6 +531,7 @@ class PortMapMixin(SetUpMixin):
                     {
                         "option_type": "port-map",
                         "option_names": ["port", "range"],
+                        "deprecated_names": [],
                     },
                     None,
                 ),
@@ -553,6 +553,7 @@ class PortMapMixin(SetUpMixin):
                     {
                         "option_type": "port-map",
                         "option_names": ["port", "range"],
+                        "deprecated_names": [],
                     },
                     None,
                 ),
@@ -574,6 +575,7 @@ class PortMapMixin(SetUpMixin):
                     {
                         "option_type": "port-map",
                         "option_names": ["port", "range"],
+                        "deprecated_names": [],
                     },
                     None,
                 ),
@@ -591,10 +593,7 @@ class PortMapMixin(SetUpMixin):
                     severities.ERROR,
                     report_codes.MUTUALLY_EXCLUSIVE_OPTIONS,
                     {
-                        "option_names": [
-                            "port",
-                            "range",
-                        ],
+                        "option_names": ["port", "range"],
                         "option_type": "port-map",
                     },
                     None,
@@ -627,9 +626,7 @@ class PortMapMixin(SetUpMixin):
                     severities.ERROR,
                     report_codes.INVALID_OPTIONS,
                     {
-                        "option_names": [
-                            "extra",
-                        ],
+                        "option_names": ["extra"],
                         "option_type": "port-map",
                         "allowed": sorted(list(PORT_MAP_OPTIONS)),
                         "allowed_patterns": [],
@@ -686,9 +683,7 @@ class PortMapMixin(SetUpMixin):
                     severities.WARNING,
                     report_codes.INVALID_OPTIONS,
                     {
-                        "option_names": [
-                            "extra",
-                        ],
+                        "option_names": ["extra"],
                         "option_type": "port-map",
                         "allowed": sorted(list(PORT_MAP_OPTIONS)),
                         "allowed_patterns": [],
@@ -806,6 +801,7 @@ class StorageMapMixin(SetUpMixin):
                     {
                         "option_type": "storage-map",
                         "option_names": ["source-dir", "source-dir-root"],
+                        "deprecated_names": [],
                     },
                     None,
                 ),
@@ -814,9 +810,7 @@ class StorageMapMixin(SetUpMixin):
                     report_codes.REQUIRED_OPTIONS_ARE_MISSING,
                     {
                         "option_type": "storage-map",
-                        "option_names": [
-                            "target-dir",
-                        ],
+                        "option_names": ["target-dir"],
                     },
                     None,
                 ),
