@@ -1,4 +1,3 @@
-import os.path
 from unittest import TestCase
 
 from pcs import settings
@@ -35,7 +34,6 @@ class DefaultsCreateMixin:
     tag = ""
 
     def setUp(self):
-        # pylint: disable=invalid-name
         self.env_assist, self.config = get_env_tools(self)
         self.config.runner.cib.load()
 
@@ -501,7 +499,6 @@ class DefaultsConfigMixin:
     tag = ""
 
     def setUp(self):
-        # pylint: disable=invalid-name
         self.env_assist, self.config = get_env_tools(self)
 
     @staticmethod
@@ -541,10 +538,7 @@ class DefaultsConfigMixin:
         self.config.runner.cib.load(
             filename="cib-empty-3.4.xml", optional_in_conf=defaults_xml
         )
-        self.config.fs.isfile(
-            (os.path.join(settings.pacemaker_binaries, "crm_rule")),
-            return_value=True,
-        )
+        self.config.fs.isfile(settings.crm_rule_exec, return_value=True)
         self.assertEqual(
             CibDefaultsDto(instance_attributes=[], meta_attributes=[]),
             self.command(self.env_assist.get_env(), True),
@@ -624,10 +618,7 @@ class DefaultsConfigMixin:
         self.config.runner.cib.load(
             filename="cib-empty-3.4.xml", optional_in_conf=defaults_xml
         )
-        self.config.fs.isfile(
-            (os.path.join(settings.pacemaker_binaries, "crm_rule")),
-            return_value=False,
-        )
+        self.config.fs.isfile(settings.crm_rule_exec, return_value=False)
         self.assertEqual(
             CibDefaultsDto(
                 instance_attributes=[
@@ -842,8 +833,7 @@ class DefaultsConfigMixin:
         )
         if crm_rule_check:
             self.config.fs.isfile(
-                (os.path.join(settings.pacemaker_binaries, "crm_rule")),
-                return_value=crm_rule_present,
+                settings.crm_rule_exec, return_value=crm_rule_present
             )
 
     def test_crm_rule_missing(self):
@@ -962,7 +952,6 @@ class DefaultsRemoveMixin:
     tag = ""
 
     def setUp(self):
-        # pylint: disable=invalid-name
         self.env_assist, self.config = get_env_tools(self)
 
     def test_nothing_to_delete(self):
@@ -1068,12 +1057,10 @@ class DefaultsUpdateLegacyMixin:
     command_for_report = None
 
     def setUp(self):
-        # pylint: disable=invalid-name
         self.env_assist, self.config = get_env_tools(self)
         self.reports = [fixture.warn(reports.codes.DEFAULTS_CAN_BE_OVERRIDDEN)]
 
     def tearDown(self):
-        # pylint: disable=invalid-name
         self.env_assist.assert_reports(self.reports)
 
     def fixture_initial_defaults(self):
@@ -1204,7 +1191,6 @@ class DefaultsUpdateMixin:
     tag = ""
 
     def setUp(self):
-        # pylint: disable=invalid-name
         self.env_assist, self.config = get_env_tools(self)
 
     def fixture_initial_defaults(self):
