@@ -1,24 +1,23 @@
-from functools import partial
 import logging
-from unittest import mock, TestCase
+from functools import partial
+from unittest import (
+    TestCase,
+    mock,
+)
 
-from pcs_test.tools import fixture
-from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.misc import create_patcher
-from pcs_test.tools.custom_mock import MockLibraryReportProcessor
-
-from pcs.common.reports import codes as report_codes
 from pcs.common.fencing_topology import (
     TARGET_TYPE_ATTRIBUTE,
     TARGET_TYPE_NODE,
     TARGET_TYPE_REGEXP,
 )
-from pcs.common.tools import Version
+from pcs.common.reports import codes as report_codes
+from pcs.lib.commands import fencing_topology as lib
 from pcs.lib.env import LibraryEnvironment
 
-from pcs.lib.commands import fencing_topology as lib
-
-# pylint: disable=no-self-use
+from pcs_test.tools import fixture
+from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.custom_mock import MockLibraryReportProcessor
+from pcs_test.tools.misc import create_patcher
 
 create_lib_env = partial(
     LibraryEnvironment,
@@ -34,20 +33,20 @@ patch_command = create_patcher("pcs.lib.commands.fencing_topology")
 @patch_command("get_fencing_topology")
 @patch_env("push_cib")
 @patch_command("ClusterState")
-@patch_command("get_cluster_status_xml")
+@patch_env("get_cluster_state")
 @patch_env("get_cib")
-@patch_env("cmd_runner", lambda self: "mocked cmd_runner")
 class AddLevel(TestCase):
     def prepare_mocks(
         self,
         mock_get_cib,
-        mock_status_xml,
+        mock_status_dom,
         mock_status,
         mock_get_topology,
         mock_get_resources,
     ):
+        # pylint: disable=no-self-use
         mock_get_cib.return_value = "mocked cib"
-        mock_status_xml.return_value = "mock get_cluster_status_xml"
+        mock_status_dom.return_value = "mock get_cluster_status_dom"
         mock_status.return_value = mock.MagicMock(
             node_section=mock.MagicMock(nodes="nodes")
         )
@@ -56,14 +55,15 @@ class AddLevel(TestCase):
 
     def assert_mocks(
         self,
-        mock_status_xml,
+        mock_status_dom,
         mock_status,
         mock_get_topology,
         mock_get_resources,
         mock_push_cib,
     ):
-        mock_status_xml.assert_called_once_with("mocked cmd_runner")
-        mock_status.assert_called_once_with("mock get_cluster_status_xml")
+        # pylint: disable=no-self-use
+        mock_status_dom.assert_called_once_with()
+        mock_status.assert_called_once_with("mock get_cluster_status_dom")
         mock_get_topology.assert_called_once_with("mocked cib")
         mock_get_resources.assert_called_once_with("mocked cib")
         mock_push_cib.assert_called_once_with()
@@ -71,7 +71,7 @@ class AddLevel(TestCase):
     def test_success(
         self,
         mock_get_cib,
-        mock_status_xml,
+        mock_status_dom,
         mock_status,
         mock_push_cib,
         mock_get_topology,
@@ -80,7 +80,7 @@ class AddLevel(TestCase):
     ):
         self.prepare_mocks(
             mock_get_cib,
-            mock_status_xml,
+            mock_status_dom,
             mock_status,
             mock_get_topology,
             mock_get_resources,
@@ -109,9 +109,9 @@ class AddLevel(TestCase):
             "force device",
             "force node",
         )
-        mock_get_cib.assert_called_once_with(None)
+        mock_get_cib.assert_called_once_with()
         self.assert_mocks(
-            mock_status_xml,
+            mock_status_dom,
             mock_status,
             mock_get_topology,
             mock_get_resources,
@@ -121,7 +121,7 @@ class AddLevel(TestCase):
     def test_target_attribute_updates_cib(
         self,
         mock_get_cib,
-        mock_status_xml,
+        mock_status_dom,
         mock_status,
         mock_push_cib,
         mock_get_topology,
@@ -130,7 +130,7 @@ class AddLevel(TestCase):
     ):
         self.prepare_mocks(
             mock_get_cib,
-            mock_status_xml,
+            mock_status_dom,
             mock_status,
             mock_get_topology,
             mock_get_resources,
@@ -159,9 +159,9 @@ class AddLevel(TestCase):
             "force device",
             "force node",
         )
-        mock_get_cib.assert_called_once_with(Version(2, 4, 0))
+        mock_get_cib.assert_called_once_with()
         self.assert_mocks(
-            mock_status_xml,
+            mock_status_dom,
             mock_status,
             mock_get_topology,
             mock_get_resources,
@@ -171,7 +171,7 @@ class AddLevel(TestCase):
     def test_target_regexp_updates_cib(
         self,
         mock_get_cib,
-        mock_status_xml,
+        mock_status_dom,
         mock_status,
         mock_push_cib,
         mock_get_topology,
@@ -180,7 +180,7 @@ class AddLevel(TestCase):
     ):
         self.prepare_mocks(
             mock_get_cib,
-            mock_status_xml,
+            mock_status_dom,
             mock_status,
             mock_get_topology,
             mock_get_resources,
@@ -209,9 +209,9 @@ class AddLevel(TestCase):
             "force device",
             "force node",
         )
-        mock_get_cib.assert_called_once_with(Version(2, 3, 0))
+        mock_get_cib.assert_called_once_with()
         self.assert_mocks(
-            mock_status_xml,
+            mock_status_dom,
             mock_status,
             mock_get_topology,
             mock_get_resources,
@@ -242,6 +242,7 @@ class GetConfig(TestCase):
 @patch_env("get_cib", lambda self: "mocked cib")
 class RemoveAllLevels(TestCase):
     def test_success(self, mock_push_cib, mock_get_topology, mock_remove):
+        # pylint: disable=no-self-use
         mock_get_topology.return_value = "topology el"
         lib_env = create_lib_env()
 
@@ -457,20 +458,20 @@ class RemoveLevelsByParams(TestCase):
 @patch_command("get_fencing_topology")
 @patch_env("push_cib")
 @patch_command("ClusterState")
-@patch_command("get_cluster_status_xml")
+@patch_env("get_cluster_state")
 @patch_env("get_cib", lambda self: "mocked cib")
-@patch_env("cmd_runner", lambda self: "mocked cmd_runner")
 class Verify(TestCase):
     def test_success(
         self,
-        mock_status_xml,
+        mock_status_dom,
         mock_status,
         mock_push_cib,
         mock_get_topology,
         mock_get_resources,
         mock_verify,
     ):
-        mock_status_xml.return_value = "mock get_cluster_status_xml"
+        # pylint: disable=no-self-use
+        mock_status_dom.return_value = "mock get_cluster_status_dom"
         mock_status.return_value = mock.MagicMock(
             node_section=mock.MagicMock(nodes="nodes")
         )
@@ -483,8 +484,8 @@ class Verify(TestCase):
         mock_verify.assert_called_once_with(
             "topology el", "resources_el", "nodes"
         )
-        mock_status_xml.assert_called_once_with("mocked cmd_runner")
-        mock_status.assert_called_once_with("mock get_cluster_status_xml")
+        mock_status_dom.assert_called_once_with()
+        mock_status.assert_called_once_with("mock get_cluster_status_dom")
         mock_get_topology.assert_called_once_with("mocked cib")
         mock_get_resources.assert_called_once_with("mocked cib")
         mock_push_cib.assert_not_called()
