@@ -1,33 +1,48 @@
 import base64
 import logging
-from unittest import mock, TestCase
-
-from pcs_test.tools.assertions import (
-    assert_raise_library_error,
-    assert_report_item_list_equal,
+import os.path
+from unittest import (
+    TestCase,
+    mock,
 )
-from pcs_test.tools.custom_mock import MockLibraryReportProcessor
 
-from pcs.common import reports
+import pcs.lib.commands.qdevice as lib
+from pcs import settings
+from pcs.common import (
+    file_type_codes,
+    reports,
+)
+from pcs.common.file import RawFileError
 from pcs.common.reports import ReportItemSeverity as severity
 from pcs.common.reports import codes as report_codes
-from pcs.lib.env import LibraryEnvironment
-from pcs.lib.errors import LibraryError
-from pcs.lib.external import (
+from pcs.common.services.errors import (
     DisableServiceError,
     EnableServiceError,
     StartServiceError,
     StopServiceError,
-    KillServicesError,
 )
+from pcs.common.services.interfaces import ServiceManagerInterface
+from pcs.lib.env import LibraryEnvironment
+from pcs.lib.errors import LibraryError
+from pcs.lib.external import KillServicesError
 
-import pcs.lib.commands.qdevice as lib
+from pcs_test.tools import fixture
+from pcs_test.tools.assertions import (
+    assert_raise_library_error,
+    assert_report_item_list_equal,
+)
+from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.custom_mock import MockLibraryReportProcessor
 
 
 class QdeviceTestCase(TestCase):
     def setUp(self):
         self.mock_logger = mock.MagicMock(logging.Logger)
         self.mock_reporter = MockLibraryReportProcessor()
+        mock.patch(
+            "pcs.lib.env.get_service_manager", spec=ServiceManagerInterface
+        ).start()
+        self.addCleanup(mock.patch.stopall)
         self.lib_env = LibraryEnvironment(self.mock_logger, self.mock_reporter)
 
 
@@ -78,17 +93,15 @@ class QdeviceBadModelTest(QdeviceTestCase):
         self.base_test(lambda: lib.qdevice_kill(self.lib_env, "bad model"))
 
 
-@mock.patch("pcs.lib.external.start_service")
-@mock.patch("pcs.lib.external.enable_service")
 @mock.patch("pcs.lib.commands.qdevice.qdevice_net.qdevice_setup")
 @mock.patch.object(LibraryEnvironment, "cmd_runner", lambda self: "mock_runner")
 class QdeviceNetSetupTest(QdeviceTestCase):
-    def test_success(self, mock_net_setup, mock_net_enable, mock_net_start):
+    # pylint: disable=no-member
+    def test_success(self, mock_net_setup):
         lib.qdevice_setup(self.lib_env, "net", False, False)
 
         mock_net_setup.assert_called_once_with("mock_runner")
-        mock_net_enable.assert_not_called()
-        mock_net_start.assert_not_called()
+        self.assertEqual(self.lib_env.service_manager.method_calls, [])
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
             [
@@ -102,14 +115,17 @@ class QdeviceNetSetupTest(QdeviceTestCase):
             ],
         )
 
-    def test_start_enable_success(
-        self, mock_net_setup, mock_net_enable, mock_net_start
-    ):
+    def test_start_enable_success(self, mock_net_setup):
         lib.qdevice_setup(self.lib_env, "net", True, True)
 
         mock_net_setup.assert_called_once_with("mock_runner")
-        mock_net_enable.assert_called_once_with("mock_runner", "corosync-qnetd")
-        mock_net_start.assert_called_once_with("mock_runner", "corosync-qnetd")
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [
+                mock.call.enable("corosync-qnetd"),
+                mock.call.start("corosync-qnetd"),
+            ],
+        )
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
             [
@@ -152,21 +168,18 @@ class QdeviceNetSetupTest(QdeviceTestCase):
             ],
         )
 
-    def test_init_failed(self, mock_net_setup, mock_net_enable, mock_net_start):
+    def test_init_failed(self, mock_net_setup):
         mock_net_setup.side_effect = LibraryError("mock_report_item")
         self.assertRaises(
             LibraryError,
             lambda: lib.qdevice_setup(self.lib_env, "net", False, False),
         )
         mock_net_setup.assert_called_once_with("mock_runner")
-        mock_net_enable.assert_not_called()
-        mock_net_start.assert_not_called()
+        self.assertEqual(self.lib_env.service_manager.method_calls, [])
         assert_report_item_list_equal(self.mock_reporter.report_item_list, [])
 
-    def test_enable_failed(
-        self, mock_net_setup, mock_net_enable, mock_net_start
-    ):
-        mock_net_enable.side_effect = EnableServiceError(
+    def test_enable_failed(self, mock_net_setup):
+        self.lib_env.service_manager.enable.side_effect = EnableServiceError(
             "test service", "test error"
         )
 
@@ -186,8 +199,10 @@ class QdeviceNetSetupTest(QdeviceTestCase):
         )
 
         mock_net_setup.assert_called_once_with("mock_runner")
-        mock_net_enable.assert_called_once_with("mock_runner", "corosync-qnetd")
-        mock_net_start.assert_not_called()
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.enable("corosync-qnetd")],
+        )
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
             [
@@ -201,10 +216,8 @@ class QdeviceNetSetupTest(QdeviceTestCase):
             ],
         )
 
-    def test_start_failed(
-        self, mock_net_setup, mock_net_enable, mock_net_start
-    ):
-        mock_net_start.side_effect = StartServiceError(
+    def test_start_failed(self, mock_net_setup):
+        self.lib_env.service_manager.start.side_effect = StartServiceError(
             "test service", "test error"
         )
 
@@ -224,8 +237,13 @@ class QdeviceNetSetupTest(QdeviceTestCase):
         )
 
         mock_net_setup.assert_called_once_with("mock_runner")
-        mock_net_enable.assert_called_once_with("mock_runner", "corosync-qnetd")
-        mock_net_start.assert_called_once_with("mock_runner", "corosync-qnetd")
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [
+                mock.call.enable("corosync-qnetd"),
+                mock.call.start("corosync-qnetd"),
+            ],
+        )
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
             [
@@ -260,21 +278,21 @@ class QdeviceNetSetupTest(QdeviceTestCase):
 
 
 @mock.patch("pcs.lib.corosync.qdevice_net.qdevice_status_cluster_text")
-@mock.patch("pcs.lib.external.stop_service")
-@mock.patch("pcs.lib.external.disable_service")
 @mock.patch("pcs.lib.commands.qdevice.qdevice_net.qdevice_destroy")
 @mock.patch.object(LibraryEnvironment, "cmd_runner", lambda self: "mock_runner")
 class QdeviceNetDestroyTest(QdeviceTestCase):
-    def test_success_not_used(
-        self, mock_net_destroy, mock_net_disable, mock_net_stop, mock_status
-    ):
+    # pylint: disable=no-member
+    def test_success_not_used(self, mock_net_destroy, mock_status):
         mock_status.return_value = ""
 
         lib.qdevice_destroy(self.lib_env, "net")
 
-        mock_net_stop.assert_called_once_with("mock_runner", "corosync-qnetd")
-        mock_net_disable.assert_called_once_with(
-            "mock_runner", "corosync-qnetd"
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [
+                mock.call.stop("corosync-qnetd"),
+                mock.call.disable("corosync-qnetd"),
+            ],
         )
         mock_net_destroy.assert_called_once_with()
         assert_report_item_list_equal(
@@ -319,16 +337,17 @@ class QdeviceNetDestroyTest(QdeviceTestCase):
             ],
         )
 
-    def test_success_used_forced(
-        self, mock_net_destroy, mock_net_disable, mock_net_stop, mock_status
-    ):
+    def test_success_used_forced(self, mock_net_destroy, mock_status):
         mock_status.return_value = 'Cluster "a_cluster":\n'
 
         lib.qdevice_destroy(self.lib_env, "net", proceed_if_used=True)
 
-        mock_net_stop.assert_called_once_with("mock_runner", "corosync-qnetd")
-        mock_net_disable.assert_called_once_with(
-            "mock_runner", "corosync-qnetd"
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [
+                mock.call.stop("corosync-qnetd"),
+                mock.call.disable("corosync-qnetd"),
+            ],
         )
         mock_net_destroy.assert_called_once_with()
         assert_report_item_list_equal(
@@ -380,9 +399,7 @@ class QdeviceNetDestroyTest(QdeviceTestCase):
             ],
         )
 
-    def test_used_not_forced(
-        self, mock_net_destroy, mock_net_disable, mock_net_stop, mock_status
-    ):
+    def test_used_not_forced(self, mock_net_destroy, mock_status):
         mock_status.return_value = 'Cluster "a_cluster":\n'
 
         assert_raise_library_error(
@@ -397,20 +414,20 @@ class QdeviceNetDestroyTest(QdeviceTestCase):
                     {
                         "clusters": ["a_cluster"],
                     },
-                    report_codes.FORCE_QDEVICE_USED,
+                    report_codes.FORCE,
                 ),
             ],
         )
 
-        mock_net_stop.assert_not_called()
-        mock_net_disable.assert_not_called()
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [],
+        )
         mock_net_destroy.assert_not_called()
 
-    def test_stop_failed(
-        self, mock_net_destroy, mock_net_disable, mock_net_stop, mock_status
-    ):
+    def test_stop_failed(self, mock_net_destroy, mock_status):
         mock_status.return_value = ""
-        mock_net_stop.side_effect = StopServiceError(
+        self.lib_env.service_manager.stop.side_effect = StopServiceError(
             "test service", "test error"
         )
 
@@ -429,8 +446,10 @@ class QdeviceNetDestroyTest(QdeviceTestCase):
             ),
         )
 
-        mock_net_stop.assert_called_once_with("mock_runner", "corosync-qnetd")
-        mock_net_disable.assert_not_called()
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.stop("corosync-qnetd")],
+        )
         mock_net_destroy.assert_not_called()
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
@@ -447,11 +466,9 @@ class QdeviceNetDestroyTest(QdeviceTestCase):
             ],
         )
 
-    def test_disable_failed(
-        self, mock_net_destroy, mock_net_disable, mock_net_stop, mock_status
-    ):
+    def test_disable_failed(self, mock_net_destroy, mock_status):
         mock_status.return_value = ""
-        mock_net_disable.side_effect = DisableServiceError(
+        self.lib_env.service_manager.disable.side_effect = DisableServiceError(
             "test service", "test error"
         )
 
@@ -470,9 +487,12 @@ class QdeviceNetDestroyTest(QdeviceTestCase):
             ),
         )
 
-        mock_net_stop.assert_called_once_with("mock_runner", "corosync-qnetd")
-        mock_net_disable.assert_called_once_with(
-            "mock_runner", "corosync-qnetd"
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [
+                mock.call.stop("corosync-qnetd"),
+                mock.call.disable("corosync-qnetd"),
+            ],
         )
         mock_net_destroy.assert_not_called()
         assert_report_item_list_equal(
@@ -500,9 +520,7 @@ class QdeviceNetDestroyTest(QdeviceTestCase):
             ],
         )
 
-    def test_destroy_failed(
-        self, mock_net_destroy, mock_net_disable, mock_net_stop, mock_status
-    ):
+    def test_destroy_failed(self, mock_net_destroy, mock_status):
         mock_status.return_value = ""
         mock_net_destroy.side_effect = LibraryError("mock_report_item")
 
@@ -510,9 +528,12 @@ class QdeviceNetDestroyTest(QdeviceTestCase):
             LibraryError, lambda: lib.qdevice_destroy(self.lib_env, "net")
         )
 
-        mock_net_stop.assert_called_once_with("mock_runner", "corosync-qnetd")
-        mock_net_disable.assert_called_once_with(
-            "mock_runner", "corosync-qnetd"
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [
+                mock.call.stop("corosync-qnetd"),
+                mock.call.disable("corosync-qnetd"),
+            ],
         )
         mock_net_destroy.assert_called_once_with()
         assert_report_item_list_equal(
@@ -620,12 +641,14 @@ class TestQdeviceNetStatusTextTest(QdeviceTestCase):
         mock_status_cluster.assert_called_once_with("mock_runner", None, False)
 
 
-@mock.patch("pcs.lib.external.enable_service")
-@mock.patch.object(LibraryEnvironment, "cmd_runner", lambda self: "mock_runner")
 class QdeviceNetEnableTest(QdeviceTestCase):
-    def test_success(self, mock_net_enable):
+    # pylint: disable=no-member
+    def test_success(self):
         lib.qdevice_enable(self.lib_env, "net")
-        mock_net_enable.assert_called_once_with("mock_runner", "corosync-qnetd")
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.enable("corosync-qnetd")],
+        )
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
             [
@@ -642,8 +665,8 @@ class QdeviceNetEnableTest(QdeviceTestCase):
             ],
         )
 
-    def test_failed(self, mock_net_enable):
-        mock_net_enable.side_effect = EnableServiceError(
+    def test_failed(self):
+        self.lib_env.service_manager.enable.side_effect = EnableServiceError(
             "test service", "test error"
         )
 
@@ -661,16 +684,19 @@ class QdeviceNetEnableTest(QdeviceTestCase):
                 },
             ),
         )
-        mock_net_enable.assert_called_once_with("mock_runner", "corosync-qnetd")
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.enable("corosync-qnetd")],
+        )
 
 
-@mock.patch("pcs.lib.external.disable_service")
-@mock.patch.object(LibraryEnvironment, "cmd_runner", lambda self: "mock_runner")
 class QdeviceNetDisableTest(QdeviceTestCase):
-    def test_success(self, mock_net_disable):
+    # pylint: disable=no-member
+    def test_success(self):
         lib.qdevice_disable(self.lib_env, "net")
-        mock_net_disable.assert_called_once_with(
-            "mock_runner", "corosync-qnetd"
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.disable("corosync-qnetd")],
         )
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
@@ -688,8 +714,8 @@ class QdeviceNetDisableTest(QdeviceTestCase):
             ],
         )
 
-    def test_failed(self, mock_net_disable):
-        mock_net_disable.side_effect = DisableServiceError(
+    def test_failed(self):
+        self.lib_env.service_manager.disable.side_effect = DisableServiceError(
             "test service", "test error"
         )
 
@@ -707,19 +733,22 @@ class QdeviceNetDisableTest(QdeviceTestCase):
                 },
             ),
         )
-        mock_net_disable.assert_called_once_with(
-            "mock_runner", "corosync-qnetd"
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.disable("corosync-qnetd")],
         )
 
 
 @mock.patch("pcs.lib.corosync.qdevice_net.qdevice_initialized")
-@mock.patch("pcs.lib.external.start_service")
-@mock.patch.object(LibraryEnvironment, "cmd_runner", lambda self: "mock_runner")
 class QdeviceNetStartTest(QdeviceTestCase):
-    def test_success(self, mock_net_start, mock_qdevice_initialized):
+    # pylint: disable=no-member
+    def test_success(self, mock_qdevice_initialized):
         mock_qdevice_initialized.return_value = True
         lib.qdevice_start(self.lib_env, "net")
-        mock_net_start.assert_called_once_with("mock_runner", "corosync-qnetd")
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.start("corosync-qnetd")],
+        )
         mock_qdevice_initialized.assert_called_once_with()
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
@@ -746,8 +775,8 @@ class QdeviceNetStartTest(QdeviceTestCase):
             ],
         )
 
-    def test_failed(self, mock_net_start, mock_qdevice_initialized):
-        mock_net_start.side_effect = StartServiceError(
+    def test_failed(self, mock_qdevice_initialized):
+        self.lib_env.service_manager.start.side_effect = StartServiceError(
             "test service", "test error"
         )
         mock_qdevice_initialized.return_value = True
@@ -766,7 +795,10 @@ class QdeviceNetStartTest(QdeviceTestCase):
                 },
             ),
         )
-        mock_net_start.assert_called_once_with("mock_runner", "corosync-qnetd")
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.start("corosync-qnetd")],
+        )
         mock_qdevice_initialized.assert_called_once_with()
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
@@ -783,9 +815,7 @@ class QdeviceNetStartTest(QdeviceTestCase):
             ],
         )
 
-    def test_qdevice_not_initialized(
-        self, mock_net_start, mock_qdevice_initialized
-    ):
+    def test_qdevice_not_initialized(self, mock_qdevice_initialized):
         mock_qdevice_initialized.return_value = False
 
         assert_raise_library_error(
@@ -798,20 +828,25 @@ class QdeviceNetStartTest(QdeviceTestCase):
                 },
             ),
         )
-        mock_net_start.assert_not_called()
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [],
+        )
         mock_qdevice_initialized.assert_called_once_with()
 
 
 @mock.patch("pcs.lib.corosync.qdevice_net.qdevice_status_cluster_text")
-@mock.patch("pcs.lib.external.stop_service")
-@mock.patch.object(LibraryEnvironment, "cmd_runner", lambda self: "mock_runner")
 class QdeviceNetStopTest(QdeviceTestCase):
-    def test_success_not_used(self, mock_net_stop, mock_status):
+    # pylint: disable=no-member
+    def test_success_not_used(self, mock_status):
         mock_status.return_value = ""
 
         lib.qdevice_stop(self.lib_env, "net", proceed_if_used=False)
 
-        mock_net_stop.assert_called_once_with("mock_runner", "corosync-qnetd")
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.stop("corosync-qnetd")],
+        )
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
             [
@@ -837,12 +872,15 @@ class QdeviceNetStopTest(QdeviceTestCase):
             ],
         )
 
-    def test_success_used_forced(self, mock_net_stop, mock_status):
+    def test_success_used_forced(self, mock_status):
         mock_status.return_value = 'Cluster "a_cluster":\n'
 
         lib.qdevice_stop(self.lib_env, "net", proceed_if_used=True)
 
-        mock_net_stop.assert_called_once_with("mock_runner", "corosync-qnetd")
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.stop("corosync-qnetd")],
+        )
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
             [
@@ -875,7 +913,7 @@ class QdeviceNetStopTest(QdeviceTestCase):
             ],
         )
 
-    def test_used_not_forced(self, mock_net_stop, mock_status):
+    def test_used_not_forced(self, mock_status):
         mock_status.return_value = 'Cluster "a_cluster":\n'
 
         assert_raise_library_error(
@@ -890,15 +928,18 @@ class QdeviceNetStopTest(QdeviceTestCase):
                     {
                         "clusters": ["a_cluster"],
                     },
-                    report_codes.FORCE_QDEVICE_USED,
+                    report_codes.FORCE,
                 ),
             ],
         )
-        mock_net_stop.assert_not_called()
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [],
+        )
 
-    def test_failed(self, mock_net_stop, mock_status):
+    def test_failed(self, mock_status):
         mock_status.return_value = ""
-        mock_net_stop.side_effect = StopServiceError(
+        self.lib_env.service_manager.stop.side_effect = StopServiceError(
             "test service", "test error"
         )
 
@@ -916,7 +957,10 @@ class QdeviceNetStopTest(QdeviceTestCase):
                 },
             ),
         )
-        mock_net_stop.assert_called_once_with("mock_runner", "corosync-qnetd")
+        self.assertEqual(
+            self.lib_env.service_manager.method_calls,
+            [mock.call.stop("corosync-qnetd")],
+        )
         assert_report_item_list_equal(
             self.mock_reporter.report_item_list,
             [
@@ -977,19 +1021,59 @@ class QdeviceNetKillTest(QdeviceTestCase):
         mock_net_kill.assert_called_once_with("mock_runner", ["corosync-qnetd"])
 
 
+class QdeviceNetGetCaCertificate(TestCase):
+    def setUp(self):
+        self.env_assist, self.config = get_env_tools(test_case=self)
+        self.path = os.path.join(
+            settings.corosync_qdevice_net_server_certs_dir,
+            settings.corosync_qdevice_net_server_ca_file_name,
+        )
+
+    def test_success(self):
+        ca_cert_data = b"ca cert data"
+        self.config.raw_file.read(
+            file_type_codes.COROSYNC_QNETD_CA_CERT, self.path, ca_cert_data
+        )
+        result = lib.qdevice_net_get_ca_certificate(self.env_assist.get_env())
+        self.assertEqual(result, base64.b64encode(ca_cert_data).decode())
+
+    def test_read_error(self):
+        self.config.raw_file.read(
+            file_type_codes.COROSYNC_QNETD_CA_CERT,
+            self.path,
+            exception_msg="an error",
+        )
+        self.env_assist.assert_raise_library_error(
+            lambda: lib.qdevice_net_get_ca_certificate(
+                self.env_assist.get_env()
+            )
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    reports.codes.FILE_IO_ERROR,
+                    file_type_code=file_type_codes.COROSYNC_QNETD_CA_CERT,
+                    operation=RawFileError.ACTION_READ,
+                    reason="an error",
+                    file_path=self.path,
+                )
+            ]
+        )
+
+
 @mock.patch(
     "pcs.lib.commands.qdevice.qdevice_net.qdevice_sign_certificate_request"
 )
 @mock.patch.object(LibraryEnvironment, "cmd_runner", lambda self: "mock_runner")
 class QdeviceNetSignCertificateRequestTest(QdeviceTestCase):
     def test_success(self, mock_qdevice_func):
-        qdevice_func_input = "certificate request".encode("utf-8")
-        qdevice_func_output = "signed certificate".encode("utf-8")
+        qdevice_func_input = "certificate request".encode()
+        qdevice_func_output = "signed certificate".encode()
         mock_qdevice_func.return_value = qdevice_func_output
         cluster_name = "clusterName"
 
         self.assertEqual(
-            base64.b64encode(qdevice_func_output),
+            base64.b64encode(qdevice_func_output).decode(),
             lib.qdevice_net_sign_certificate_request(
                 self.lib_env, base64.b64encode(qdevice_func_input), cluster_name
             ),
