@@ -1,15 +1,17 @@
 from functools import partial
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
+
+from pcs import settings
+from pcs.common import reports
+from pcs.lib.commands import stonith
 
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
 from pcs_test.tools.misc import get_test_resource as rc
 
-from pcs import settings
-from pcs.common.reports import codes as report_codes
-from pcs.lib.commands import stonith
-from pcs.lib.resource_agent import StonithAgent
-
 expected_cib_simple = """
     <primitive class="stonith" id="stonith-test" type="test_simple">
         <instance_attributes id="stonith-test-instance_attributes">
@@ -89,27 +91,23 @@ expected_cib_unknown = """
 
 class CreateMixin:
     def setUp(self):
-        # pylint does not know this method is defined in TestCase
-        # pylint: disable=invalid-name
         self.env_assist, self.config = get_env_tools(test_case=self)
 
-    def tearDown(self):
-        # pylint does not know this method is defined in TestCase
-        # pylint: disable=invalid-name
-        # pylint: disable=no-self-use
-        StonithAgent.clear_fenced_metadata_cache()
-
     def test_minimal_success(self):
         agent_name = "test_simple"
+        instance_attributes = {
+            "must-set": "value",
+            "must-set-new": "B",
+        }
 
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml",
-            )
-            .runner.cib.load()
-            .runner.pcmk.load_fenced_metadata()
-            .env.push_cib(resources=self._expected_cib(expected_cib_simple))
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.env.push_cib(
+            resources=self._expected_cib(expected_cib_simple)
         )
 
         self._create(
@@ -118,23 +116,156 @@ class CreateMixin:
             agent_name,
             operations=[],
             meta_attributes={},
-            instance_attributes={
-                "must-set": "value",
-                "must-set-new": "B",
-            },
+            instance_attributes=instance_attributes,
+        )
+
+    def test_agent_self_validation_failure(self):
+        agent_name = "test_simple"
+        instance_attributes = {
+            "must-set": "value",
+            "must-set-new": "B",
+        }
+
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes,
+            agent_name,
+            output="""
+            <output source="stderr">not ignored</output>
+            <output source="stdout">this is ignored</output>
+            <output source="stderr">
+            first issue
+            another one
+            </output>
+            """,
+            returncode=1,
+        )
+        self.env_assist.assert_raise_library_error(
+            lambda: self._create(
+                self.env_assist.get_env(),
+                "stonith-test",
+                agent_name,
+                operations=[],
+                meta_attributes={},
+                instance_attributes=instance_attributes,
+                enable_agent_self_validation=True,
+            ),
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    reports.codes.AGENT_SELF_VALIDATION_RESULT,
+                    result="not ignored\nfirst issue\nanother one",
+                    force_code=reports.codes.FORCE,
+                )
+            ]
+        )
+
+    def test_agent_self_validation_failure_forced(self):
+        agent_name = "test_simple"
+        instance_attributes = {
+            "must-set": "value",
+            "must-set-new": "B",
+        }
+
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes,
+            agent_name,
+            output="""
+            <output source="stderr">not ignored</output>
+            <output source="stdout">this is ignored</output>
+            <output source="stderr">
+            first issue
+            another one
+            </output>
+            """,
+            returncode=1,
+        )
+        self.config.env.push_cib(
+            resources=self._expected_cib(expected_cib_simple)
+        )
+
+        self._create(
+            self.env_assist.get_env(),
+            "stonith-test",
+            agent_name,
+            operations=[],
+            meta_attributes={},
+            instance_attributes=instance_attributes,
+            allow_invalid_instance_attributes=True,
+            enable_agent_self_validation=True,
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    reports.codes.AGENT_SELF_VALIDATION_RESULT,
+                    result="not ignored\nfirst issue\nanother one",
+                )
+            ]
+        )
+
+    def test_agent_self_validation_invalid_output(self):
+        agent_name = "test_simple"
+        instance_attributes = {
+            "must-set": "value",
+            "must-set-new": "B",
+        }
+
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.runner.pcmk.stonith_agent_self_validation(
+            instance_attributes,
+            agent_name,
+            output="""<not valid> xml""",
+            returncode=0,
+        )
+        self.env_assist.assert_raise_library_error(
+            lambda: self._create(
+                self.env_assist.get_env(),
+                "stonith-test",
+                agent_name,
+                operations=[],
+                meta_attributes={},
+                instance_attributes=instance_attributes,
+                enable_agent_self_validation=True,
+            ),
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    reports.codes.AGENT_SELF_VALIDATION_INVALID_DATA,
+                    reason="Specification mandates value for attribute valid, line 5, column 29 (<string>, line 5)",
+                    force_code=reports.codes.FORCE,
+                )
+            ]
         )
 
     def test_unfencing(self):
         agent_name = "test_unfencing"
 
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_unfencing.xml",
-            )
-            .runner.cib.load()
-            .runner.pcmk.load_fenced_metadata()
-            .env.push_cib(resources=self._expected_cib(expected_cib_unfencing))
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_unfencing.xml",
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.env.push_cib(
+            resources=self._expected_cib(expected_cib_unfencing)
         )
 
         self._create(
@@ -148,6 +279,10 @@ class CreateMixin:
 
     def test_disabled(self):
         agent_name = "test_simple"
+        instance_attributes = {
+            "must-set": "value",
+            "must-set-new": "B",
+        }
         expected_cib = expected_cib_simple.replace(
             '<instance_attributes id="stonith-test-instance_attributes">',
             """
@@ -160,15 +295,13 @@ class CreateMixin:
             """,
         )
 
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml",
-            )
-            .runner.cib.load()
-            .runner.pcmk.load_fenced_metadata()
-            .env.push_cib(resources=self._expected_cib(expected_cib))
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
         )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.env.push_cib(resources=self._expected_cib(expected_cib))
 
         self._create(
             self.env_assist.get_env(),
@@ -176,10 +309,7 @@ class CreateMixin:
             agent_name,
             operations=[],
             meta_attributes={},
-            instance_attributes={
-                "must-set": "value",
-                "must-set-new": "B",
-            },
+            instance_attributes=instance_attributes,
             ensure_disabled=True,
         )
 
@@ -190,14 +320,14 @@ class CreateMixin:
         # updated to test new behaviour.
         agent_name = "test_custom_actions"
 
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_custom_actions.xml",
-            )
-            .runner.cib.load()
-            .runner.pcmk.load_fenced_metadata()
-            .env.push_cib(resources=self._expected_cib(expected_cib_operations))
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_custom_actions.xml",
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.env.push_cib(
+            resources=self._expected_cib(expected_cib_operations)
         )
 
         self._create(
@@ -219,11 +349,13 @@ class CreateMixin:
     def test_id_already_exists(self):
         agent_name = "test_simple"
 
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml",
-            ).runner.cib.load(resources=self._expected_cib(expected_cib_simple))
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load(
+            resources=self._expected_cib(expected_cib_simple)
         )
 
         self.env_assist.assert_raise_library_error(
@@ -238,36 +370,31 @@ class CreateMixin:
                     "must-set-new": "B",
                 },
             ),
-            [fixture.error(report_codes.ID_ALREADY_EXISTS, id="stonith-test")],
+            [fixture.error(reports.codes.ID_ALREADY_EXISTS, id="stonith-test")],
             expected_in_processor=False,
         )
 
     def test_instance_meta_and_operations(self):
         agent_name = "test_simple"
+        instance_attributes = {"undefined": "attribute"}
 
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml",
-            )
-            .runner.cib.load()
-            .runner.pcmk.load_fenced_metadata()
-            .env.push_cib(
-                resources=self._expected_cib(expected_cib_simple_forced)
-            )
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.env.push_cib(
+            resources=self._expected_cib(expected_cib_simple_forced)
         )
 
         self._create(
             self.env_assist.get_env(),
             "stonith-test",
             agent_name,
-            operations=[
-                {"name": "bad-action"},
-            ],
-            meta_attributes={
-                "metaname": "metavalue",
-            },
-            instance_attributes={"undefined": "attribute"},
+            operations=[{"name": "bad-action"}],
+            meta_attributes={"metaname": "metavalue"},
+            instance_attributes=instance_attributes,
             allow_invalid_operation=True,
             allow_invalid_instance_attributes=True,
         )
@@ -275,7 +402,7 @@ class CreateMixin:
         self.env_assist.assert_reports(
             [
                 fixture.warn(
-                    report_codes.INVALID_OPTION_VALUE,
+                    reports.codes.INVALID_OPTION_VALUE,
                     option_value="bad-action",
                     option_name="operation name",
                     allowed_values=[
@@ -293,7 +420,7 @@ class CreateMixin:
                     forbidden_characters=None,
                 ),
                 fixture.warn(
-                    report_codes.INVALID_OPTIONS,
+                    reports.codes.INVALID_OPTIONS,
                     option_names=["undefined"],
                     option_type="stonith",
                     allowed=[
@@ -326,28 +453,86 @@ class CreateMixin:
                         "pcmk_status_action",
                         "pcmk_status_retries",
                         "pcmk_status_timeout",
-                        "priority",
                     ],
                     allowed_patterns=[],
                 ),
                 fixture.warn(
-                    report_codes.REQUIRED_OPTIONS_ARE_MISSING,
-                    option_names=["must-set", "must-set-new"],
+                    reports.codes.REQUIRED_OPTIONS_ARE_MISSING,
+                    option_names=["must-set"],
+                    option_type="stonith",
+                ),
+                fixture.warn(
+                    reports.codes.REQUIRED_OPTION_OF_ALTERNATIVES_IS_MISSING,
+                    option_names=["must-set-new", "must-set-old"],
+                    deprecated_names=["must-set-old"],
                     option_type="stonith",
                 ),
             ]
         )
 
-    def test_unknown_agent_forced(self):
-        agent_name = "test_unknown"
-
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_is_missing=True,
+    def test_invalid_agent_name(self):
+        self.env_assist.assert_raise_library_error(
+            lambda: self._create(
+                self.env_assist.get_env(),
+                "stonith-test",
+                "stonith:fence_xvm",
+                operations=[],
+                meta_attributes={},
+                instance_attributes={},
+                allow_absent_agent=True,
             )
-            .runner.cib.load()
-            .env.push_cib(resources=self._expected_cib(expected_cib_unknown))
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    reports.codes.INVALID_STONITH_AGENT_NAME,
+                    name="stonith:fence_xvm",
+                ),
+            ]
+        )
+
+    def test_agent_load_failure(self):
+        agent_name = "test_unknown"
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}", agent_is_missing=True
+        )
+
+        self.env_assist.assert_raise_library_error(
+            lambda: self._create(
+                self.env_assist.get_env(),
+                "stonith-test",
+                agent_name,
+                operations=[],
+                meta_attributes={},
+                instance_attributes={},
+            )
+        )
+
+        self.env_assist.assert_reports(
+            [
+                fixture.error(
+                    reports.codes.UNABLE_TO_GET_AGENT_METADATA,
+                    force_code=reports.codes.FORCE,
+                    agent="stonith:test_unknown",
+                    reason=(
+                        "Agent stonith:test_unknown not found or does not "
+                        "support meta-data: Invalid argument (22)\n"
+                        "Metadata query for stonith:test_unknown failed: "
+                        "Input/output error"
+                    ),
+                ),
+            ]
+        )
+
+    def test_agent_load_failure_forced(self):
+        agent_name = "test_unknown"
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}", agent_is_missing=True
+        )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.env.push_cib(
+            resources=self._expected_cib(expected_cib_unknown)
         )
 
         self._create(
@@ -363,8 +548,8 @@ class CreateMixin:
         self.env_assist.assert_reports(
             [
                 fixture.warn(
-                    report_codes.UNABLE_TO_GET_AGENT_METADATA,
-                    agent="test_unknown",
+                    reports.codes.UNABLE_TO_GET_AGENT_METADATA,
+                    agent="stonith:test_unknown",
                     reason=(
                         "Agent stonith:test_unknown not found or does not "
                         "support meta-data: Invalid argument (22)\n"
@@ -376,12 +561,18 @@ class CreateMixin:
         )
 
     @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+        settings,
+        "pacemaker_api_result_schema",
+        rc("pcmk_api_rng/api-result.rng"),
     )
     def test_minimal_wait_ok_run_ok(self):
         agent_name = "test_simple"
         instance_name = "stonith-test"
-        timeout = "10"
+        instance_attributes = {
+            "must-set": "value",
+            "must-set-new": "B",
+        }
+        timeout = 10
         expected_status = """
             <resources>
                 <resource
@@ -399,18 +590,16 @@ class CreateMixin:
             id=instance_name, agent=agent_name
         )
 
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml",
-            )
-            .runner.cib.load()
-            .runner.pcmk.load_fenced_metadata()
-            .env.push_cib(
-                resources=self._expected_cib(expected_cib_simple), wait=timeout
-            )
-            .runner.pcmk.load_state(resources=expected_status)
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
         )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
+        self.config.env.push_cib(
+            resources=self._expected_cib(expected_cib_simple), wait=timeout
+        )
+        self.config.runner.pcmk.load_state(resources=expected_status)
 
         self._create(
             self.env_assist.get_env(),
@@ -418,16 +607,13 @@ class CreateMixin:
             agent_name,
             operations=[],
             meta_attributes={},
-            instance_attributes={
-                "must-set": "value",
-                "must-set-new": "B",
-            },
-            wait=timeout,
+            instance_attributes=instance_attributes,
+            wait=str(timeout),
         )
         self.env_assist.assert_reports(
             [
                 fixture.info(
-                    report_codes.RESOURCE_RUNNING_ON_NODES,
+                    reports.codes.RESOURCE_RUNNING_ON_NODES,
                     roles_with_nodes={"Started": ["node1"]},
                     resource_id=instance_name,
                 ),
@@ -462,14 +648,12 @@ class CreateInGroup(CreateMixin, TestCase):
     def test_group_not_valid(self):
         agent_name = "test_simple"
 
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml",
-            )
-            .runner.cib.load()
-            .runner.pcmk.load_fenced_metadata()
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
         )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load()
 
         self.env_assist.assert_raise_library_error(
             lambda: stonith.create_in_group(
@@ -484,20 +668,27 @@ class CreateInGroup(CreateMixin, TestCase):
                     "must-set-new": "B",
                 },
             ),
+            expected_in_processor=False,
+        )
+
+        self.env_assist.assert_reports(
             [
                 fixture.error(
-                    report_codes.INVALID_ID_BAD_CHAR,
+                    reports.codes.INVALID_ID_BAD_CHAR,
                     id="0-group",
                     id_description="group name",
                     is_first_char=True,
                     invalid_character="0",
                 )
-            ],
-            expected_in_processor=False,
+            ]
         )
 
     def _assert_adjacent(self, adjacent, after):
         agent_name = "test_simple"
+        instance_attributes = {
+            "must-set": "value",
+            "must-set-new": "B",
+        }
         original_cib = (
             "<resources><group id='my-group'>"
             + self._dummy("dummy1")
@@ -512,15 +703,13 @@ class CreateInGroup(CreateMixin, TestCase):
             + "</group></resources>"
         )
 
-        (
-            self.config.runner.pcmk.load_agent(
-                agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml",
-            )
-            .runner.cib.load(resources=original_cib)
-            .runner.pcmk.load_fenced_metadata()
-            .env.push_cib(resources=expected_cib)
+        self.config.runner.pcmk.load_agent(
+            agent_name=f"stonith:{agent_name}",
+            agent_filename="stonith_agent_fence_simple.xml",
         )
+        self.config.runner.pcmk.load_fake_agent_metadata()
+        self.config.runner.cib.load(resources=original_cib)
+        self.config.env.push_cib(resources=expected_cib)
 
         stonith.create_in_group(
             self.env_assist.get_env(),
@@ -529,10 +718,7 @@ class CreateInGroup(CreateMixin, TestCase):
             "my-group",
             operations=[],
             meta_attributes={},
-            instance_attributes={
-                "must-set": "value",
-                "must-set-new": "B",
-            },
+            instance_attributes=instance_attributes,
             adjacent_resource_id=adjacent,
             put_after_adjacent=after,
         )
