@@ -1,5 +1,4 @@
 # pylint: disable=too-many-lines
-import os.path
 from unittest import (
     TestCase,
     mock,
@@ -32,6 +31,7 @@ from pcs_test.tools.custom_mock import (
     TmpFileCall,
     TmpFileMock,
 )
+from pcs_test.tools.custom_mock import get_runner_mock as get_runner
 from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.xml import (
     XmlManipulation,
@@ -41,17 +41,6 @@ from pcs_test.tools.xml import (
 _EXITCODE_NOT_CONNECTED = 102
 
 
-def get_runner(stdout="", stderr="", returncode=0, env_vars=None):
-    runner = mock.MagicMock(spec_set=CommandRunner)
-    runner.run.return_value = (stdout, stderr, returncode)
-    runner.env_vars = env_vars if env_vars else {}
-    return runner
-
-
-def path(name):
-    return os.path.join(settings.pacemaker_binaries, name)
-
-
 class GetStatusFromApiResult(TestCase):
     # pylint: disable=protected-access
     def test_errors(self):
@@ -79,8 +68,6 @@ class GetStatusFromApiResult(TestCase):
 
 class GetClusterStatusMixin(TestCase):
     def setUp(self):
-        # 'setUp' not defined in TestCase class
-        # pylint: disable=invalid-name
         self.env_assist, self.config = get_env_tools(test_case=self)
         self._xml_summary = etree_to_str(
             etree.parse(rc("crm_mon.minimal.xml")).find("/summary")
@@ -230,7 +217,7 @@ class GetClusterStatusText(TestCase):
         )
 
         mock_runner.run.assert_called_once_with(
-            [settings.crm_mon, "--one-shot", "--inactive"]
+            [settings.crm_mon_exec, "--one-shot", "--inactive"]
         )
         self.assertEqual(self.expected_stdout, real_status)
         self.assertEqual(warnings, [])
@@ -243,7 +230,7 @@ class GetClusterStatusText(TestCase):
 
         mock_runner.run.assert_called_once_with(
             [
-                settings.crm_mon,
+                settings.crm_mon_exec,
                 "--one-shot",
                 "--inactive",
                 "--show-detail",
@@ -270,7 +257,7 @@ class GetClusterStatusText(TestCase):
 
         mock_runner.run.assert_called_once_with(
             [
-                settings.crm_mon,
+                settings.crm_mon_exec,
                 "--one-shot",
                 "--inactive",
                 "--show-detail",
@@ -288,7 +275,7 @@ class GetClusterStatusText(TestCase):
         )
 
         mock_runner.run.assert_called_once_with(
-            [settings.crm_mon, "--one-shot"]
+            [settings.crm_mon_exec, "--one-shot"]
         )
         self.assertEqual(self.expected_stdout, real_status)
         self.assertEqual(warnings, [])
@@ -301,7 +288,7 @@ class GetClusterStatusText(TestCase):
 
         mock_runner.run.assert_called_once_with(
             [
-                settings.crm_mon,
+                settings.crm_mon_exec,
                 "--one-shot",
                 "--show-detail",
                 "--show-node-attributes",
@@ -323,7 +310,7 @@ class GetClusterStatusText(TestCase):
             ),
         )
         mock_runner.run.assert_called_once_with(
-            [settings.crm_mon, "--one-shot", "--inactive"]
+            [settings.crm_mon_exec, "--one-shot", "--inactive"]
         )
 
     def test_warnings(self):
@@ -335,7 +322,7 @@ class GetClusterStatusText(TestCase):
         )
 
         mock_runner.run.assert_called_once_with(
-            [settings.crm_mon, "--one-shot", "--inactive"]
+            [settings.crm_mon_exec, "--one-shot", "--inactive"]
         )
         self.assertEqual(self.expected_stdout, real_status)
         self.assertEqual(warnings, ["msgA", "msgC"])
@@ -350,7 +337,7 @@ class GetClusterStatusText(TestCase):
 
         mock_runner.run.assert_called_once_with(
             [
-                settings.crm_mon,
+                settings.crm_mon_exec,
                 "--one-shot",
                 "--inactive",
                 "--show-detail",
@@ -366,7 +353,6 @@ class GetClusterStatusText(TestCase):
 
 
 class GetCibXmlTest(TestCase):
-    # pylint: disable=no-self-use
     def test_success(self):
         expected_stdout = "<xml />"
         expected_stderr = ""
@@ -378,11 +364,12 @@ class GetCibXmlTest(TestCase):
         real_xml = lib.get_cib_xml(mock_runner)
 
         mock_runner.run.assert_called_once_with(
-            [path("cibadmin"), "--local", "--query"]
+            [settings.cibadmin_exec, "--local", "--query"]
         )
         self.assertEqual(expected_stdout, real_xml)
 
     def test_error(self):
+        # pylint: disable=no-self-use
         expected_stdout = "some info"
         expected_stderr = "some error"
         expected_retval = 1
@@ -402,7 +389,7 @@ class GetCibXmlTest(TestCase):
         )
 
         mock_runner.run.assert_called_once_with(
-            [path("cibadmin"), "--local", "--query"]
+            [settings.cibadmin_exec, "--local", "--query"]
         )
 
     def test_success_scope(self):
@@ -418,7 +405,7 @@ class GetCibXmlTest(TestCase):
 
         mock_runner.run.assert_called_once_with(
             [
-                path("cibadmin"),
+                settings.cibadmin_exec,
                 "--local",
                 "--query",
                 "--scope={0}".format(scope),
@@ -427,6 +414,7 @@ class GetCibXmlTest(TestCase):
         self.assertEqual(expected_stdout, real_xml)
 
     def test_scope_error(self):
+        # pylint: disable=no-self-use
         expected_stdout = "some info"
         # yes, the numbers do not match, tested and verified with
         # pacemaker-2.0.0-1.fc29.1.x86_64
@@ -453,7 +441,7 @@ class GetCibXmlTest(TestCase):
 
         mock_runner.run.assert_called_once_with(
             [
-                path("cibadmin"),
+                settings.cibadmin_exec,
                 "--local",
                 "--query",
                 "--scope={0}".format(scope),
@@ -487,7 +475,7 @@ class Verify(TestCase):
         runner = get_runner()
         self.assertEqual(lib.verify(runner), ("", "", 0, False))
         runner.run.assert_called_once_with(
-            [path("crm_verify"), "--live-check"],
+            [settings.crm_verify_exec, "--live-check"],
         )
 
     def test_run_on_mocked_cib(self):
@@ -496,14 +484,14 @@ class Verify(TestCase):
 
         self.assertEqual(lib.verify(runner), ("", "", 0, False))
         runner.run.assert_called_once_with(
-            [path("crm_verify"), "--xml-file", fake_tmp_file],
+            [settings.crm_verify_exec, "--xml-file", fake_tmp_file],
         )
 
     def test_run_verbose(self):
         runner = get_runner()
         self.assertEqual(lib.verify(runner, verbose=True), ("", "", 0, False))
         runner.run.assert_called_once_with(
-            [path("crm_verify"), "-V", "-V", "--live-check"],
+            [settings.crm_verify_exec, "-V", "-V", "--live-check"],
         )
 
     def test_run_verbose_on_mocked_cib(self):
@@ -512,7 +500,7 @@ class Verify(TestCase):
 
         self.assertEqual(lib.verify(runner, verbose=True), ("", "", 0, False))
         runner.run.assert_called_once_with(
-            [path("crm_verify"), "-V", "-V", "--xml-file", fake_tmp_file],
+            [settings.crm_verify_exec, "-V", "-V", "--xml-file", fake_tmp_file],
         )
 
     @staticmethod
@@ -575,7 +563,7 @@ class Verify(TestCase):
                     lib.verify(runner, verbose=verbose),
                     ("", "".join(out_stderr), 78, can_be_more_verbose),
                 )
-                args = [path("crm_verify")]
+                args = [settings.crm_verify_exec]
                 if verbose:
                     args.extend(["-V", "-V"])
                 args.extend(["--xml-file", fake_tmp_file])
@@ -621,7 +609,7 @@ class ReplaceCibConfigurationTest(TestCase):
 
         mock_runner.run.assert_called_once_with(
             [
-                path("cibadmin"),
+                settings.cibadmin_exec,
                 "--replace",
                 "--verbose",
                 "--xml-pipe",
@@ -656,7 +644,7 @@ class ReplaceCibConfigurationTest(TestCase):
 
         mock_runner.run.assert_called_once_with(
             [
-                path("cibadmin"),
+                settings.cibadmin_exec,
                 "--replace",
                 "--verbose",
                 "--xml-pipe",
@@ -674,7 +662,7 @@ class UpgradeCibTest(TestCase):
         mock_runner = get_runner("", "", 0)
         lib._upgrade_cib(mock_runner)
         mock_runner.run.assert_called_once_with(
-            [settings.cibadmin, "--upgrade", "--force"]
+            [settings.cibadmin_exec, "--upgrade", "--force"]
         )
 
     def test_error(self):
@@ -695,7 +683,7 @@ class UpgradeCibTest(TestCase):
             ),
         )
         mock_runner.run.assert_called_once_with(
-            [settings.cibadmin, "--upgrade", "--force"]
+            [settings.cibadmin_exec, "--upgrade", "--force"]
         )
 
 
@@ -804,7 +792,6 @@ class SimulateCibXml(TestCase):
             self.tmp_file_mock_obj.get_mock_side_effect()
         )
 
-    # pylint: disable=no-self-use
     def test_success(self):
         orig_cib_data = "orig cib"
         cib_file_name = "new_cib_file.tmp"
@@ -834,7 +821,7 @@ class SimulateCibXml(TestCase):
 
         mock_runner.run.assert_called_once_with(
             [
-                path("crm_simulate"),
+                settings.crm_simulate_exec,
                 "--simulate",
                 "--save-output",
                 cib_file_name,
@@ -1168,7 +1155,7 @@ class RemoveNode(TestCase):
         mock_runner = get_runner("", "", 0)
         lib.remove_node(mock_runner, "NODE_NAME")
         mock_runner.run.assert_called_once_with(
-            [path("crm_node"), "--force", "--remove", "NODE_NAME"]
+            [settings.crm_node_exec, "--force", "--remove", "NODE_NAME"]
         )
 
     def test_error(self):
@@ -1428,7 +1415,7 @@ class ResourcesWaitingTest(TestCase):
         self.assertEqual(None, lib.wait_for_idle(mock_runner, 0))
 
         mock_runner.run.assert_called_once_with(
-            [path("crm_resource"), "--wait"]
+            [settings.crm_resource_exec, "--wait"]
         )
 
     def test_wait_timeout_success(self):
@@ -1443,7 +1430,11 @@ class ResourcesWaitingTest(TestCase):
         self.assertEqual(None, lib.wait_for_idle(mock_runner, timeout))
 
         mock_runner.run.assert_called_once_with(
-            [path("crm_resource"), "--wait", "--timeout={0}".format(timeout)]
+            [
+                settings.crm_resource_exec,
+                "--wait",
+                "--timeout={0}".format(timeout),
+            ]
         )
 
     def test_wait_error(self):
@@ -1466,7 +1457,7 @@ class ResourcesWaitingTest(TestCase):
         )
 
         mock_runner.run.assert_called_once_with(
-            [path("crm_resource"), "--wait"]
+            [settings.crm_resource_exec, "--wait"]
         )
 
     def test_wait_error_timeout(self):
@@ -1489,7 +1480,7 @@ class ResourcesWaitingTest(TestCase):
         )
 
         mock_runner.run.assert_called_once_with(
-            [path("crm_resource"), "--wait"]
+            [settings.crm_resource_exec, "--wait"]
         )
 
 
@@ -1548,7 +1539,7 @@ class GetResourceDigests(TestCase):
         "nonreloadable": "0" * 31 + "3",
     }
     CALL_ARGS = [
-        path("crm_resource"),
+        settings.crm_resource_exec,
         "--digests",
         "--resource",
         "resource-id",
@@ -1880,6 +1871,7 @@ class ValidateResourceInstanceAttributesViaPcmkTest(TestCase):
             "pcs.lib.pacemaker.live._handle_instance_attributes_validation_via_pcmk"
         )
         self.mock_handler = patcher.start()
+        self.addCleanup(patcher.stop)
         self.ret_val = "ret val"
         self.mock_handler.return_value = self.ret_val
 
@@ -1896,7 +1888,7 @@ class ValidateResourceInstanceAttributesViaPcmkTest(TestCase):
         self.mock_handler.assert_called_once_with(
             self.runner,
             [
-                settings.crm_resource_binary,
+                settings.crm_resource_exec,
                 "--validate",
                 "--output-as",
                 "xml",
@@ -1924,7 +1916,7 @@ class ValidateResourceInstanceAttributesViaPcmkTest(TestCase):
         self.mock_handler.assert_called_once_with(
             self.runner,
             [
-                settings.crm_resource_binary,
+                settings.crm_resource_exec,
                 "--validate",
                 "--output-as",
                 "xml",
@@ -1948,6 +1940,7 @@ class ValidateStonithInstanceAttributesViaPcmkTest(TestCase):
             "pcs.lib.pacemaker.live._handle_instance_attributes_validation_via_pcmk"
         )
         self.mock_handler = patcher.start()
+        self.addCleanup(patcher.stop)
         self.ret_val = "ret val"
         self.mock_handler.return_value = self.ret_val
 
@@ -1964,7 +1957,7 @@ class ValidateStonithInstanceAttributesViaPcmkTest(TestCase):
         self.mock_handler.assert_called_once_with(
             self.runner,
             [
-                settings.stonith_admin,
+                settings.stonith_admin_exec,
                 "--validate",
                 "--output-as",
                 "xml",
