@@ -1,14 +1,10 @@
-from unittest import mock, TestCase
+from unittest import (
+    TestCase,
+    mock,
+)
 
 from lxml import etree
 
-from pcs_test.tools.assertions import (
-    assert_raise_library_error,
-    assert_report_item_equal,
-)
-from pcs_test.tools.misc import get_test_resource as rc
-from pcs_test.tools.xml import get_xml_manipulation_creator_from_file
-
 from pcs import settings
 from pcs.common.reports import ReportItemSeverity as severities
 from pcs.common.reports import codes as report_codes
@@ -19,7 +15,9 @@ from pcs.lib.pacemaker.state import (
     _Children,
 )
 
-# pylint: disable=no-self-use, protected-access
+from pcs_test.tools.assertions import assert_report_item_equal
+from pcs_test.tools.fixture_crm_mon import complete_state
+from pcs_test.tools.misc import get_test_resource as rc
 
 
 class AttrsTest(TestCase):
@@ -51,6 +49,7 @@ class ChildrenTest(TestCase):
         )
 
     def wrap(self, element):
+        # pylint: disable=no-self-use
         return "{0}.{1}".format(element.tag, element.attrib["name"])
 
     def test_get_declared_section(self):
@@ -68,101 +67,73 @@ class ChildrenTest(TestCase):
         self.assertRaises(AttributeError, lambda: children.some_section)
 
 
-class TestBase(TestCase):
-    def setUp(self):
-        self.create_covered_status = get_xml_manipulation_creator_from_file(
-            rc("crm_mon.minimal.xml")
-        )
-        self.covered_status = self.create_covered_status()
-
-
-class ClusterStatusTest(TestBase):
-    @mock.patch.object(
-        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
-    )
-    def test_minimal_crm_mon_is_valid(self):
-        ClusterState(str(self.covered_status))
-
-    def test_refuse_invalid_xml(self):
-        assert_raise_library_error(
-            lambda: ClusterState("invalid xml"),
-            (severities.ERROR, report_codes.BAD_CLUSTER_STATE_FORMAT, {}),
-        )
-
-    @mock.patch("pcs.lib.pacemaker.state._validate_cluster_state_dom")
-    def test_refuse_invalid_document(self, mock_validate):
-        mock_validate.side_effect = etree.DocumentInvalid("some error")
-        self.covered_status.append_to_first_tag_name(
-            "nodes", '<node without="required attributes" />'
-        )
-
-        assert_raise_library_error(
-            lambda: ClusterState(str(self.covered_status)),
-            (severities.ERROR, report_codes.BAD_CLUSTER_STATE_FORMAT, {}),
-        )
-
-
-@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
-class WorkWithClusterStatusNodesTest(TestBase):
-    def fixture_node_string(self, **kwargs):
-        attrs = dict(name="name", id="id", type="member")
-        attrs.update(kwargs)
-        return """<node
-            name="{name}"
-            id="{id}"
-            online="true"
-            standby="true"
-            standby_onfail="false"
-            maintenance="false"
-            pending="false"
-            unclean="false"
-            shutdown="false"
-            expected_up="false"
-            is_dc="false"
-            resources_running="0"
-            type="{type}"
-        />""".format(
-            **attrs
-        )
-
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
+class WorkWithClusterStatusNodesTest(TestCase):
     def test_can_get_node_names(self):
-        self.covered_status.append_to_first_tag_name(
-            "nodes",
-            self.fixture_node_string(name="node1", id="1"),
-            self.fixture_node_string(name="node2", id="2"),
+        with open(rc("crm_mon.minimal.xml")) as crm_mon_file:
+            crm_mon_xml = crm_mon_file.read()
+        state_dom = complete_state(
+            crm_mon_xml,
+            nodes_xml="""
+                <nodes>
+                    <node name="node1" id="1" />
+                    <node name="node2" id="2" />
+                </nodes>
+            """,
         )
-        xml = str(self.covered_status)
         self.assertEqual(
             ["node1", "node2"],
-            [node.attrs.name for node in ClusterState(xml).node_section.nodes],
+            [
+                node.attrs.name
+                for node in ClusterState(state_dom).node_section.nodes
+            ],
         )
 
     def test_can_filter_out_remote_nodes(self):
-        self.covered_status.append_to_first_tag_name(
-            "nodes",
-            self.fixture_node_string(name="node1", id="1"),
-            self.fixture_node_string(name="node2", type="remote", id="2"),
+        with open(rc("crm_mon.minimal.xml")) as crm_mon_file:
+            crm_mon_xml = crm_mon_file.read()
+        state_dom = complete_state(
+            crm_mon_xml,
+            nodes_xml="""
+                <nodes>
+                    <node name="node1" id="1" />
+                    <node name="node2" id="2" type="remote" />
+                </nodes>
+            """,
         )
-        xml = str(self.covered_status)
         self.assertEqual(
             ["node1"],
             [
                 node.attrs.name
-                for node in ClusterState(xml).node_section.nodes
+                for node in ClusterState(state_dom).node_section.nodes
                 if node.attrs.type != "remote"
             ],
         )
 
 
-@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
-class WorkWithClusterStatusSummaryTest(TestBase):
+@mock.patch.object(
+    settings, "pacemaker_api_result_schema", rc("pcmk_api_rng/api-result.rng")
+)
+class WorkWithClusterStatusSummaryTest(TestCase):
     def test_nodes_count(self):
-        xml = str(self.covered_status)
-        self.assertEqual(0, ClusterState(xml).summary.nodes.attrs.count)
+        with open(rc("crm_mon.minimal.xml")) as crm_mon_file:
+            crm_mon_xml = crm_mon_file.read()
+        self.assertEqual(
+            0,
+            ClusterState(complete_state(crm_mon_xml)).summary.nodes.attrs.count,
+        )
 
     def test_resources_count(self):
-        xml = str(self.covered_status)
-        self.assertEqual(0, ClusterState(xml).summary.resources.attrs.count)
+        with open(rc("crm_mon.minimal.xml")) as crm_mon_file:
+            crm_mon_xml = crm_mon_file.read()
+        self.assertEqual(
+            0,
+            ClusterState(
+                complete_state(crm_mon_xml)
+            ).summary.resources.attrs.count,
+        )
 
 
 class GetPrimitiveRolesWithNodes(TestCase):
@@ -201,6 +172,7 @@ class GetPrimitiveRolesWithNodes(TestCase):
         primitives = [etree.fromstring(xml) for xml in primitives_xml]
 
         self.assertEqual(
+            # pylint: disable=protected-access
             state._get_primitive_roles_with_nodes(primitives),
             {
                 "Started": ["node1", "node5"],
@@ -210,6 +182,7 @@ class GetPrimitiveRolesWithNodes(TestCase):
         )
 
     def test_empty(self):
+        # pylint: disable=protected-access
         self.assertEqual(state._get_primitive_roles_with_nodes([]), {})
 
 
@@ -358,6 +331,7 @@ class GetPrimitivesForStateCheck(TestCase):
         self.assertEqual(
             [
                 elem.attrib["id"]
+                # pylint: disable=protected-access
                 for elem in state._get_primitives_for_state_check(
                     self.status, resource_id, expected_running
                 )
@@ -517,6 +491,7 @@ class CommonResourceState(TestCase):
         self.get_primitive_roles_with_nodes = patcher_roles.start()
 
     def fixture_running_state_info(self):
+        # pylint: disable=no-self-use
         return {
             "Started": ["node1"],
             "Master": ["node2"],
