@@ -127,7 +127,6 @@ class TestGroupMixin:
     empty_cib = rc("cib-empty.xml")
 
     def setUp(self):
-        # pylint: disable=invalid-name
         self.temp_cib = get_tmp_file("tier1_cib_resource_group_ungroup")
         self.pcs_runner = PcsRunner(self.temp_cib.name)
         xml_manip = XmlManipulation.from_file(self.empty_cib)
@@ -150,16 +149,12 @@ class TestGroupMixin:
         write_data_to_tmpfile(str(xml_manip), self.temp_cib)
 
     def tearDown(self):
-        # pylint: disable=invalid-name
         self.temp_cib.close()
 
 
 class GroupDeleteRemoveUngroupBase(
     get_assert_pcs_effect_mixin(
-        lambda cib: etree.tostring(
-            # pylint:disable=undefined-variable
-            etree.parse(cib).findall(".//resources")[0]
-        )
+        lambda cib: etree.tostring(etree.parse(cib).findall(".//resources")[0])
     ),
     TestGroupMixin,
 ):
