@@ -182,8 +182,10 @@ class ManageUnmanage(
                 </primitive>
             </resources>
             """,
-            "Warning: Resource 'A' has no enabled monitor operations."
-            " Re-run with '--monitor' to enable them.\n",
+            stderr_full=(
+                "Warning: Resource 'A' has no enabled monitor operations."
+                " Re-run with '--monitor' to enable them.\n"
+            ),
         )
 
     def test_unmanage_more(self):
