@@ -24,7 +24,6 @@ from pcs_test.tools.misc import (
 from pcs_test.tools.pcs_runner import PcsRunner
 
 # pylint: disable=invalid-name
-# pylint: disable=line-too-long
 
 empty_cib = rc("cib-empty-3.2.xml")
 empty_cib_new_roles_supported = rc("cib-empty-3.7.xml")
@@ -453,10 +452,18 @@ class ParserTest(TestCase):
             "(gt (literal date) (literal 2014-06-26))",
             str(self.parser.parse(["date", "gt", "2014-06-26"])),
         )
+        self.assertEqual(
+            "(gt (literal date) (literal 2014-06-26 12:00:00))",
+            str(self.parser.parse(["date", "gt", "2014-06-26 12:00:00"])),
+        )
         self.assertEqual(
             "(lt (literal date) (literal 2014-06-26))",
             str(self.parser.parse(["date", "lt", "2014-06-26"])),
         )
+        self.assertEqual(
+            "(lt (literal date) (literal 2014-06-26 12:00:00))",
+            str(self.parser.parse(["date", "lt", "2014-06-26 12:00:00"])),
+        )
         self.assertEqual(
             "(in_range "
             "(literal date) (literal 2014-06-26) (literal 2014-07-26)"
@@ -467,6 +474,22 @@ class ParserTest(TestCase):
                 )
             ),
         )
+        self.assertEqual(
+            "(in_range "
+            "(literal date) (literal 2014-06-26 12:00) (literal 2014-07-26 13:00)"
+            ")",
+            str(
+                self.parser.parse(
+                    [
+                        "date",
+                        "in_range",
+                        "2014-06-26 12:00",
+                        "to",
+                        "2014-07-26 13:00",
+                    ]
+                )
+            ),
+        )
         self.assertEqual(
             "(in_range "
             "(literal date) "
