@@ -1,7 +1,6 @@
 # pylint: disable=too-many-lines
 import sys
 import xml.dom.minidom
-import xml.etree.ElementTree as ET
 from io import StringIO
 from time import sleep
 from unittest import (
@@ -15,9 +14,6 @@ from pcs.common import const
 from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.xml import dom_get_child_elements
 
-# pylint: disable=line-too-long
-# pylint: disable=invalid-name
-
 cib_with_nodes = rc("cib-empty-withnodes.xml")
 empty_cib = rc("cib-empty.xml")
 
@@ -91,7 +87,7 @@ class UtilsTest(TestCase):
         resources.parentNode.replaceChild(new_resources, resources)
         return cib_dom
 
-    def testDomGetResources(self):
+    def test_dom_get_resources(self):
         # pylint: disable=too-many-statements
         def test_dom_get(method, dom, ok_ids, bad_ids):
             for element_id in ok_ids:
@@ -342,7 +338,7 @@ class UtilsTest(TestCase):
             )
         )
 
-    def testDomGetResourceRemoteNodeName(self):
+    def test_dom_get_resource_remote_node_name(self):
         dom = self.get_cib_empty()
         new_resources = xml.dom.minidom.parseString(
             """
@@ -463,7 +459,7 @@ class UtilsTest(TestCase):
             ),
         )
 
-    def testGetElementWithId(self):
+    def test_get_element_with_id(self):
         dom = xml.dom.minidom.parseString(
             """
             <aa>
@@ -536,7 +532,7 @@ class UtilsTest(TestCase):
         self.assertEqual(None, utils.dom_get_parent_by_tag_names(cc1, ["dd"]))
         self.assertEqual(None, utils.dom_get_parent_by_tag_names(cc1, ["ee"]))
 
-    def testValidateConstraintResource(self):
+    def test_validate_constraint_resource(self):
         dom = self.get_cib_resources()
         self.assertEqual(
             (True, "", "myClone"),
@@ -673,7 +669,7 @@ class UtilsTest(TestCase):
             utils.validate_constraint_resource(dom, "myBundledResource"),
         )
 
-    def testValidateXmlId(self):
+    def test_validate_xml_id(self):
         self.assertEqual((True, ""), utils.validate_xml_id("dummy"))
         self.assertEqual((True, ""), utils.validate_xml_id("DUMMY"))
         self.assertEqual((True, ""), utils.validate_xml_id("dUmMy"))
@@ -742,7 +738,7 @@ class UtilsTest(TestCase):
             utils.validate_xml_id("dummy?", "test id"),
         )
 
-    def testIsIso8601Date(self):
+    def test_is_iso8601_date(self):
         self.assertTrue(utils.is_iso8601_date("2014-07-03"))
         self.assertTrue(utils.is_iso8601_date("2014-07-03T11:35:14"))
         self.assertTrue(utils.is_iso8601_date("20140703"))
@@ -1510,7 +1506,7 @@ class UtilsTest(TestCase):
         )
 
         self.assertEqual(len(dom_get_child_elements(el)), 1)
-        u = dom_get_child_elements(el)[0]
+        u = dom_get_child_elements(el)[0]  # pylint: disable=invalid-name
         self.assertEqual(u.tagName, "utilization")
         self.assertEqual(u.getAttribute("id"), "test_id-utilization")
         self.assertEqual(len(dom_get_child_elements(u)), 2)
@@ -1555,7 +1551,7 @@ class UtilsTest(TestCase):
             },
         )
 
-        u = dom_get_child_elements(el)[0]
+        u = dom_get_child_elements(el)[0]  # pylint: disable=invalid-name
         self.assertEqual(len(dom_get_child_elements(u)), 1)
         self.assertEqual(
             dom_get_child_elements(u)[0].getAttribute("id"),
@@ -1579,7 +1575,7 @@ class UtilsTest(TestCase):
         )
 
         self.assertEqual(len(dom_get_child_elements(el)), 1)
-        u = dom_get_child_elements(el)[0]
+        u = dom_get_child_elements(el)[0]  # pylint: disable=invalid-name
         self.assertEqual(u.tagName, "meta_attributes")
         self.assertEqual(u.getAttribute("id"), "test_id-meta_attributes")
         self.assertEqual(len(dom_get_child_elements(u)), 2)
@@ -1618,7 +1614,7 @@ class UtilsTest(TestCase):
         ).documentElement
         utils.dom_update_meta_attr(el, [("key", "another_val"), ("key2", "")])
 
-        u = dom_get_child_elements(el)[0]
+        u = dom_get_child_elements(el)[0]  # pylint: disable=invalid-name
         self.assertEqual(len(dom_get_child_elements(u)), 1)
         self.assertEqual(
             dom_get_child_elements(u)[0].getAttribute("id"),
@@ -1657,192 +1653,6 @@ class UtilsTest(TestCase):
         ).documentElement
         self.assertEqual("key=-1 keys=90", utils.get_utilization_str(el))
 
-    def test_get_cluster_property_from_xml_enum(self):
-        el = ET.fromstring(
-            """
-        <parameter name="no-quorum-policy" unique="0">
-            <shortdesc lang="en">What to do when the cluster does not have quorum</shortdesc>
-            <content type="enum" default="stop"/>
-            <longdesc lang="en">What to do when the cluster does not have quorum  Allowed values: stop, freeze, ignore, suicide</longdesc>
-        </parameter>
-        """
-        )
-        expected = {
-            "name": "no-quorum-policy",
-            "shortdesc": "What to do when the cluster does not have quorum",
-            "longdesc": "",
-            "type": "enum",
-            "default": "stop",
-            "enum": ["stop", "freeze", "ignore", "suicide"],
-        }
-        self.assertEqual(expected, utils.get_cluster_property_from_xml(el))
-
-    def test_get_cluster_property_from_xml(self):
-        el = ET.fromstring(
-            """
-        <parameter name="an-integer-property" unique="0">
-            <shortdesc lang="en"></shortdesc>
-            <content type="integer" default="0"/>
-            <longdesc lang="en"></longdesc>
-        </parameter>
-        """
-        )
-        expected = {
-            "name": "an-integer-property",
-            "shortdesc": "",
-            "longdesc": "",
-            "type": "integer",
-            "default": "0",
-        }
-        self.assertEqual(expected, utils.get_cluster_property_from_xml(el))
-
-    def test_is_valid_cib_value_unknown_type(self):
-        # should be always true
-        self.assertTrue(utils.is_valid_cib_value("unknown", "test"))
-        self.assertTrue(utils.is_valid_cib_value("string", "string value"))
-
-    def test_is_valid_cib_value_integer(self):
-        self.assertTrue(utils.is_valid_cib_value("integer", "0"))
-        self.assertTrue(utils.is_valid_cib_value("integer", "42"))
-        self.assertTrue(utils.is_valid_cib_value("integer", "-90"))
-        self.assertTrue(utils.is_valid_cib_value("integer", "+90"))
-        self.assertTrue(utils.is_valid_cib_value("integer", "INFINITY"))
-        self.assertTrue(utils.is_valid_cib_value("integer", "-INFINITY"))
-        self.assertTrue(utils.is_valid_cib_value("integer", "+INFINITY"))
-        self.assertFalse(utils.is_valid_cib_value("integer", "0.0"))
-        self.assertFalse(utils.is_valid_cib_value("integer", "-10.9"))
-        self.assertFalse(utils.is_valid_cib_value("integer", "string"))
-
-    def test_is_valid_cib_value_enum(self):
-        self.assertTrue(
-            utils.is_valid_cib_value("enum", "this", ["another", "this", "1"])
-        )
-        self.assertFalse(
-            utils.is_valid_cib_value("enum", "this", ["another", "this_not"])
-        )
-        self.assertFalse(utils.is_valid_cib_value("enum", "this", []))
-        self.assertFalse(utils.is_valid_cib_value("enum", "this"))
-
-    def test_is_valid_cib_value_boolean(self):
-        self.assertTrue(utils.is_valid_cib_value("boolean", "true"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "TrUe"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "TRUE"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "yes"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "on"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "y"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "Y"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "1"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "false"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "FaLse"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "FALSE"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "off"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "no"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "N"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "n"))
-        self.assertTrue(utils.is_valid_cib_value("boolean", "0"))
-        self.assertFalse(utils.is_valid_cib_value("boolean", "-1"))
-        self.assertFalse(utils.is_valid_cib_value("boolean", "not"))
-        self.assertFalse(utils.is_valid_cib_value("boolean", "random_string"))
-        self.assertFalse(utils.is_valid_cib_value("boolean", "truth"))
-
-    def test_is_valid_cib_value_time(self):
-        self.assertTrue(utils.is_valid_cib_value("time", "10"))
-        self.assertTrue(utils.is_valid_cib_value("time", "0"))
-        self.assertTrue(utils.is_valid_cib_value("time", "9s"))
-        self.assertTrue(utils.is_valid_cib_value("time", "10sec"))
-        self.assertTrue(utils.is_valid_cib_value("time", "10min"))
-        self.assertTrue(utils.is_valid_cib_value("time", "10m"))
-        self.assertTrue(utils.is_valid_cib_value("time", "10h"))
-        self.assertTrue(utils.is_valid_cib_value("time", "10hr"))
-        self.assertFalse(utils.is_valid_cib_value("time", "5.2"))
-        self.assertFalse(utils.is_valid_cib_value("time", "-10"))
-        self.assertFalse(utils.is_valid_cib_value("time", "10m 2s"))
-        self.assertFalse(utils.is_valid_cib_value("time", "hour"))
-        self.assertFalse(utils.is_valid_cib_value("time", "day"))
-
-    def test_validate_cluster_property(self):
-        definition = {
-            "property-int": {
-                "name": "property-int",
-                "shortdesc": "int description",
-                "longdesc": "long int description",
-                "type": "integer",
-                "default": "0",
-                "source": "pacemaker-schedulerd",
-            },
-            "property-enum": {
-                "name": "property-enum",
-                "shortdesc": "What to do when the cluster does not have quorum",
-                "longdesc": (
-                    "What to do when the cluster does not have quorum  "
-                    "Allowed values: stop, freeze, ignore, suicide"
-                ),
-                "type": "enum",
-                "default": "stop",
-                "enum": ["stop", "freeze", "ignore", "suicide"],
-                "source": "pacemaker-schedulerd",
-            },
-            "property-bool": {
-                "name": "property-bool",
-                "shortdesc": "Enable CIB ACL",
-                "longdesc": "Enable CIB ACL",
-                "type": "boolean",
-                "default": "false",
-                "source": "cib",
-            },
-        }
-        self.assertTrue(
-            utils.is_valid_cluster_property(definition, "property-int", "10")
-        )
-        self.assertTrue(
-            utils.is_valid_cluster_property(definition, "property-int", "-1")
-        )
-        self.assertTrue(
-            utils.is_valid_cluster_property(
-                definition, "property-enum", "freeze"
-            )
-        )
-        self.assertTrue(
-            utils.is_valid_cluster_property(
-                definition, "property-enum", "suicide"
-            )
-        )
-        self.assertTrue(
-            utils.is_valid_cluster_property(definition, "property-bool", "true")
-        )
-        self.assertTrue(
-            utils.is_valid_cluster_property(
-                definition, "property-bool", "false"
-            )
-        )
-        self.assertTrue(
-            utils.is_valid_cluster_property(definition, "property-bool", "on")
-        )
-        self.assertTrue(
-            utils.is_valid_cluster_property(definition, "property-bool", "OFF")
-        )
-        self.assertFalse(
-            utils.is_valid_cluster_property(definition, "property-int", "test")
-        )
-        self.assertFalse(
-            utils.is_valid_cluster_property(definition, "property-int", "1.2")
-        )
-        self.assertFalse(
-            utils.is_valid_cluster_property(
-                definition, "property-enum", "invalid"
-            )
-        )
-        self.assertFalse(
-            utils.is_valid_cluster_property(definition, "property-bool", "not")
-        )
-        self.assertRaises(
-            utils.UnknownPropertyException,
-            utils.is_valid_cluster_property,
-            definition,
-            "unknown",
-            "value",
-        )
-
     def assert_element_id(self, node, node_id, tag=None):
         self.assertTrue(
             isinstance(node, xml.dom.minidom.Element),
@@ -1856,6 +1666,7 @@ class UtilsTest(TestCase):
 class RunParallelTest(TestCase):
     @staticmethod
     def fixture_create_worker(log, name, sleepSeconds=0):
+        # pylint: disable=invalid-name
         def worker():
             sleep(sleepSeconds)
             log.append(name)
