@@ -83,21 +83,16 @@ def get_invalid_option_messages_regexp(
 
 class PropertyMixin(
     get_assert_pcs_effect_mixin(
-        lambda cib: etree.tostring(
-            # pylint:disable=undefined-variable
-            etree.parse(cib).findall(".//crm_config")[0]
-        )
+        lambda cib: etree.tostring(etree.parse(cib).findall(".//crm_config")[0])
     )
 ):
     def setUp(self):
-        # pylint: disable=invalid-name
         self.maxDiff = None
         self.temp_cib = get_tmp_file("tier1_cluster_property")
         write_file_to_tmpfile(property_cib, self.temp_cib)
         self.pcs_runner = PcsRunner(self.temp_cib.name)
 
     def tearDown(self):
-        # pylint: disable=invalid-name
         self.temp_cib.close()
 
 
@@ -467,8 +462,9 @@ class TestPropertyDefaults(TestCase, AssertPcsMixin):
         )
 
     def test_notexistent(self):
-        self.assert_pcs_success(
-            "property defaults nonexistent".split(), stdout_full=""
+        self.assert_pcs_fail(
+            "property defaults nonexistent".split(),
+            stderr_full="Error: No default value for property: 'nonexistent'\n",
         )
 
     def test_unsupported_option(self):
@@ -533,6 +529,12 @@ class TestPropertyDescribe(TestCase, AssertPcsMixin):
             stdout_full=FIXTURE_BATCH_LIMIT_DESC + FIXTURE_STONITH_ENABLED_DESC,
         )
 
+    def test_notexistent(self):
+        self.assert_pcs_fail(
+            "property describe nonexistent".split(),
+            stderr_full="Error: No description for property: 'nonexistent'\n",
+        )
+
     def test_success_output_format_json(self):
         self.assert_pcs_success(
             "property describe --output-format=json".split(),
