@@ -1,4 +1,3 @@
-# pylint: disable=line-too-long
 import re
 from textwrap import dedent
 from unittest import TestCase
@@ -215,7 +214,7 @@ class StonithWarningTest(TestCase, AssertPcsMixin):
             ),
         )
         self.pcs_runner.corosync_conf_opt = self.corosync_conf
-        self.pcs_runner.mock_settings = get_mock_settings("crm_resource_binary")
+        self.pcs_runner.mock_settings = get_mock_settings("crm_resource_exec")
         if PCMK_2_0_3_PLUS:
             self.assert_pcs_success(
                 ["status"],
@@ -278,13 +277,11 @@ class ResourceStonithStatusBase(AssertPcsMixin):
     no_active_resources_msg = "No active resources\n"
 
     def setUp(self):
-        # pylint: disable=invalid-name
         self.temp_cib = get_tmp_file("tier1_status_resource_stonith_status")
         write_file_to_tmpfile(self.cib_file, self.temp_cib)
         self.pcs_runner = PcsRunner(self.temp_cib.name)
 
     def tearDown(self):
-        # pylint: disable=invalid-name
         self.temp_cib.close()
 
     def test_not_resource_or_tag_id(self):
@@ -736,7 +733,7 @@ class XmlStatus(AssertPcsMixin, TestCase):
               <status code="0" message="OK"/>
             </pacemaker-result>
         """.format(
-            crm_mon=settings.crm_mon
+            crm_mon=settings.crm_mon_exec
         )
         self.assert_pcs_success(
             ["status", "xml"],
