@@ -18,20 +18,15 @@ tags_cib = rc("cib-tags.xml")
 
 class TestTagMixin(
     get_assert_pcs_effect_mixin(
-        lambda cib: etree.tostring(
-            # pylint:disable=undefined-variable
-            etree.parse(cib).findall(".//tags")[0]
-        )
+        lambda cib: etree.tostring(etree.parse(cib).findall(".//tags")[0])
     )
 ):
     def setUp(self):
-        # pylint: disable=invalid-name
         self.temp_cib = get_tmp_file("tier1_tag")
         write_file_to_tmpfile(tags_cib, self.temp_cib)
         self.pcs_runner = PcsRunner(self.temp_cib.name)
 
     def tearDown(self):
-        # pylint: disable=invalid-name
         self.temp_cib.close()
 
     @staticmethod
