@@ -1,6 +1,5 @@
 from pcs_test.tools.assertions import (
     AssertPcsMixin,
-    AssertPcsMixinOld,
     assert_xml_equal,
 )
 from pcs_test.tools.misc import write_data_to_tmpfile
@@ -32,78 +31,6 @@ def xml_format(xml_string):
     return "\n".join(reindented_lines)
 
 
-# TODO remove this function
-def get_assert_pcs_effect_mixin_old(get_cib_part):
-    class AssertPcsEffectMixin(AssertPcsMixinOld):
-        def assert_resources_xml_in_cib(
-            self,
-            expected_xml_resources,
-            get_cib_part_func=None,
-        ):
-            self.temp_cib.seek(0)
-            if get_cib_part_func is not None:
-                xml = get_cib_part_func(self.temp_cib)
-            else:
-                xml = get_cib_part(self.temp_cib)
-            try:
-                assert_xml_equal(expected_xml_resources, xml.decode())
-            except AssertionError as e:
-                raise AssertionError(
-                    "{0}\n\nCopy format ;)\n{1}".format(
-                        e.args[0], xml_format(xml.decode())
-                    )
-                ) from e
-
-        def assert_effect_single(
-            self,
-            command,
-            expected_xml,
-            output=None,
-            output_start=None,
-            output_regexp=None,
-        ):
-            self.assert_pcs_success(
-                command, output, output_start, output_regexp
-            )
-            self.assert_resources_xml_in_cib(expected_xml)
-
-        def assert_effect(
-            self,
-            alternative_cmds,
-            expected_xml,
-            output=None,
-            output_start=None,
-            output_regexp=None,
-        ):
-            alternative_list = (
-                alternative_cmds
-                if isinstance(alternative_cmds[0], list)
-                else [alternative_cmds]
-            )
-            self.temp_cib.seek(0)
-            cib_content = self.temp_cib.read()
-            self.temp_cib.seek(0)
-            for alternative in alternative_list[:-1]:
-                self.assert_effect_single(
-                    alternative,
-                    expected_xml,
-                    output,
-                    output_start,
-                    output_regexp,
-                )
-                write_data_to_tmpfile(cib_content, self.temp_cib)
-
-            self.assert_effect_single(
-                alternative_list[-1],
-                expected_xml,
-                output,
-                output_start,
-                output_regexp,
-            )
-
-    return AssertPcsEffectMixin
-
-
 def get_assert_pcs_effect_mixin(get_cib_part):
     class AssertPcsEffectMixin(AssertPcsMixin):
         def assert_resources_xml_in_cib(
