@@ -9,8 +9,6 @@ from pcs_test.tools.fixture_crm_mon import complete_state
 from pcs_test.tools.misc import get_test_resource as rc
 from pcs_test.tools.xml import etree_to_str
 
-# pylint: disable=too-many-arguments
-
 DEFAULT_WAIT_TIMEOUT = 10
 WAIT_TIMEOUT_EXPIRED_RETURNCODE = 124
 AGENT_FILENAME_MAP = {
@@ -30,6 +28,7 @@ RULE_NOT_YET_IN_EFFECT_RETURNCODE = 111
 
 
 class PcmkShortcuts:
+    # pylint: disable=too-many-arguments
     # pylint: disable=too-many-public-methods
     def __init__(self, calls):
         self.__calls = calls
@@ -382,7 +381,7 @@ class PcmkShortcuts:
             env = {}
         env["PATH"] = ":".join(
             [
-                settings.fence_agent_binaries,
+                settings.fence_agent_execs,
                 "/bin",
                 "/usr/bin",
             ]
@@ -475,7 +474,7 @@ class PcmkShortcuts:
         if stdout is None:
             with open(rc(name_to_metadata_file[agent_name])) as a_file:
                 stdout = a_file.read()
-        agent_path = settings.__dict__[agent_name.replace("-", "_")]
+        agent_path = settings.__dict__[agent_name.replace("-", "_") + "_exec"]
         self.__calls.place(
             name,
             RunnerCall(
