@@ -1,21 +1,23 @@
-from functools import lru_cache
 import logging
 import os
 import re
 import tempfile
-from unittest import mock, skipUnless
+from functools import lru_cache
+from unittest import (
+    mock,
+    skipUnless,
+)
 
 from lxml import etree
 
-from pcs_test.tools.custom_mock import MockLibraryReportProcessor
-
 from pcs import settings
 from pcs.cli.common.parse_args import InputModifiers
-from pcs.lib.external import CommandRunner, is_service_enabled
+from pcs.common import str_tools
+from pcs.lib.external import CommandRunner
 
-# pylint: disable=invalid-name
-
-testdir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+from pcs_test import TEST_ROOT
+from pcs_test import settings as tests_settings
+from pcs_test.tools.custom_mock import MockLibraryReportProcessor
 
 runner = CommandRunner(
     mock.MagicMock(logging.Logger), MockLibraryReportProcessor(), os.environ
@@ -70,7 +72,7 @@ def dict_to_modifiers(options):
 
 def get_test_resource(name):
     """Return full path to a test resource file specified by name"""
-    return os.path.join(testdir, "resources", name)
+    return os.path.join(TEST_ROOT, "resources", name)
 
 
 def get_tmp_dir(name=None):
@@ -115,12 +117,15 @@ def read_test_resource(name):
 
 
 def cmp3(a, b):
+    # pylint: disable=invalid-name
+
     # python3 doesn't have the cmp function, this is an official workaround
     # https://docs.python.org/3.0/whatsnew/3.0.html#ordering-comparisons
     return (a > b) - (a < b)
 
 
 def compare_version(a, b):
+    # pylint: disable=invalid-name
     if a[0] == b[0]:
         if a[1] == b[1]:
             return cmp3(a[2], b[2])
@@ -129,7 +134,7 @@ def compare_version(a, b):
 
 
 def is_minimum_pacemaker_version(major, minor, rev):
-    return is_version_sufficient(
+    return _is_version_sufficient(
         _get_current_pacemaker_version(), (major, minor, rev)
     )
 
@@ -137,17 +142,14 @@ def is_minimum_pacemaker_version(major, minor, rev):
 @lru_cache()
 def _get_current_pacemaker_version():
     output, dummy_stderr, dummy_retval = runner.run(
-        [
-            os.path.join(settings.pacemaker_binaries, "crm_mon"),
-            "--version",
-        ]
+        [settings.crm_mon_exec, "--version"]
     )
-    pacemaker_version = output.split("\n")[0]
-    r = re.compile(r"Pacemaker (\d+)\.(\d+)\.(\d+)")
-    m = r.match(pacemaker_version)
-    major = int(m.group(1))
-    minor = int(m.group(2))
-    rev = int(m.group(3))
+    pacemaker_version = output.split("\n", maxsplit=1)[0]
+    regexp = re.compile(r"Pacemaker (\d+)\.(\d+)\.(\d+)")
+    match = regexp.match(pacemaker_version)
+    major = int(match.group(1))
+    minor = int(match.group(2))
+    rev = int(match.group(3))
     return major, minor, rev
 
 
@@ -155,7 +157,7 @@ def _get_current_pacemaker_version():
 def _get_current_cib_schema_version():
     regexp = re.compile(r"pacemaker-((\d+)\.(\d+))")
     all_versions = set()
-    xml = etree.parse("/usr/share/pacemaker/versions.rng").getroot()
+    xml = etree.parse(tests_settings.pacemaker_version_rng).getroot()
     for value_el in xml.xpath(
         ".//x:attribute[@name='validate-with']//x:value",
         namespaces={"x": "http://relaxng.org/ns/structure/1.0"},
@@ -171,46 +173,57 @@ def _is_minimum_cib_schema_version(cmajor, cminor, crev):
     return compare_version((major, minor, 0), (cmajor, cminor, crev)) > -1
 
 
-def is_version_sufficient(current_version, minimal_version):
+def _is_version_sufficient(current_version, minimal_version):
     return compare_version(current_version, minimal_version) > -1
 
 
-def format_version(version_tuple):
+def _format_version(version_tuple):
     return ".".join([str(x) for x in version_tuple])
 
 
 def is_minimum_pacemaker_features(cmajor, cminor, crev):
-    major, minor, rev = _get_current_pacemaker_features()
+    major, minor, rev = _get_current_pacemaker_features()[0]
     return compare_version((major, minor, rev), (cmajor, cminor, crev)) > -1
 
 
+def _has_pacemaker_features(requested_features):
+    requested = frozenset(requested_features)
+    actual = _get_current_pacemaker_features()[1]
+    return actual >= requested
+
+
 @lru_cache()
 def _get_current_pacemaker_features():
     output, dummy_stderr, dummy_retval = runner.run(
-        [
-            os.path.join(settings.pacemaker_binaries, "pacemakerd"),
-            "--features",
-        ]
+        [settings.pacemakerd_exec, "--features"]
     )
-    features_version = output.split("\n")[1]
-    r = re.compile(r"Supporting v(\d+)\.(\d+)\.(\d+):")
-    m = r.search(features_version)
-    major = int(m.group(1))
-    minor = int(m.group(2))
-    rev = int(m.group(3))
-    return major, minor, rev
+    features_string = output.split("\n")[1]
+    regexp = re.compile(r"Supporting v(\d+)\.(\d+)\.(\d+):\s*(.*)")
+    match = regexp.search(features_string)
+    major = int(match.group(1))
+    minor = int(match.group(2))
+    rev = int(match.group(3))
+    features_list = frozenset(match.group(4).split())
+    return (major, minor, rev), features_list
+
+
+@lru_cache()
+def is_pacemaker_21_without_20_compatibility():
+    return is_minimum_pacemaker_version(
+        2, 1, 0
+    ) and not _has_pacemaker_features(["compat-2.0"])
 
 
 def skip_unless_pacemaker_version(version_tuple, feature):
     current_version = _get_current_pacemaker_version()
     return skipUnless(
-        is_version_sufficient(current_version, version_tuple),
+        _is_version_sufficient(current_version, version_tuple),
         (
             "Pacemaker version is too old (current: {current_version},"
             " must be >= {minimal_version}) to test {feature}"
         ).format(
-            current_version=format_version(current_version),
-            minimal_version=format_version(version_tuple),
+            current_version=_format_version(current_version),
+            minimal_version=_format_version(version_tuple),
             feature=feature,
         ),
     )
@@ -222,7 +235,7 @@ def skip_unless_pacemaker_features(version_tuple, feature):
         (
             "Pacemaker must support feature set version {version} to test "
             "{feature}"
-        ).format(version=format_version(version_tuple), feature=feature),
+        ).format(version=_format_version(version_tuple), feature=feature),
     )
 
 
@@ -234,8 +247,8 @@ def skip_unless_cib_schema_version(version_tuple, feature):
             "Pacemaker supported CIB schema version is too low (current: "
             "{current_version}, must be >= {minimal_version}) to test {feature}"
         ).format(
-            current_version=format_version(current_version),
-            minimal_version=format_version(version_tuple),
+            current_version=_format_version(current_version),
+            minimal_version=_format_version(version_tuple),
             feature=feature,
         ),
     )
@@ -247,12 +260,6 @@ def skip_unless_crm_rule():
     )
 
 
-def skip_unless_pacemaker_supports_bundle():
-    return skip_unless_pacemaker_features(
-        (3, 1, 0), "bundle resources with promoted-max attribute"
-    )
-
-
 def skip_unless_pacemaker_supports_rsc_and_op_rules():
     return skip_unless_cib_schema_version(
         (3, 4, 0), "rsc_expression and op_expression elements in rule elements"
@@ -265,22 +272,31 @@ def skip_unless_pacemaker_supports_op_onfail_demote():
     )
 
 
-def skip_if_service_enabled(service_name):
-    return skipUnless(
-        not is_service_enabled(runner, service_name),
-        "Service {0} must be disabled".format(service_name),
-    )
-
-
 def skip_unless_root():
     return skipUnless(os.getuid() == 0, "Root user required")
 
 
+@lru_cache()
+def _is_booth_resource_agent_installed():
+    output, dummy_stderr, dummy_retval = runner.run(
+        [settings.crm_resource_exec, "--list-agents", "ocf:pacemaker"]
+    )
+    return "booth-site" in output
+
+
+def skip_unless_booth_resource_agent_installed():
+    return skipUnless(
+        _is_booth_resource_agent_installed(),
+        "test requires resource agent ocf:pacemaker:booth-site"
+        " which is not installed",
+    )
+
+
 def create_patcher(target_prefix_or_module):
     """
     Return function for patching tests with preconfigured target prefix
     string|module target_prefix_or_module could be:
-        * a prefix for patched names. Typicaly tested module:
+        * a prefix for patched names. Typically tested module:
             "pcs.lib.commands.booth"
         * a (imported) module: pcs.lib.cib
         Between prefix and target is "." (dot)
@@ -296,11 +312,7 @@ def create_patcher(target_prefix_or_module):
 
 
 def outdent(text):
-    line_list = text.splitlines()
-    smallest_indentation = min(
-        [len(line) - len(line.lstrip(" ")) for line in line_list if line]
-    )
-    return "\n".join([line[smallest_indentation:] for line in line_list])
+    return "\n".join(str_tools.outdent(text.splitlines()))
 
 
 def create_setup_patch_mixin(module_specification_or_patcher):
