@@ -7,6 +7,7 @@ from pcs.common.pacemaker.nvset import (
     CibNvsetDto,
 )
 from pcs.common.pacemaker.resource.bundle import (
+    CONTAINER_TYPE_DOCKER,
     CibResourceBundleContainerRuntimeOptionsDto,
     CibResourceBundleDto,
     CibResourceBundleNetworkOptionsDto,
@@ -15,7 +16,7 @@ from pcs.common.pacemaker.resource.bundle import (
 )
 from pcs.common.pacemaker.resource.clone import CibResourceCloneDto
 from pcs.common.pacemaker.resource.group import CibResourceGroupDto
-from pcs.common.pacemaker.resource.list import ListCibResourcesDto
+from pcs.common.pacemaker.resource.list import CibResourcesDto
 from pcs.common.pacemaker.resource.operations import CibResourceOperationDto
 from pcs.common.pacemaker.resource.primitive import CibResourcePrimitiveDto
 from pcs.common.resource_agent.dto import ResourceAgentNameDto
@@ -505,7 +506,7 @@ BUNDLE_B1 = CibResourceBundleDto(
     id="B1",
     description=None,
     member_id=None,
-    container_type="docker",
+    container_type=CONTAINER_TYPE_DOCKER,
     container_options=CibResourceBundleContainerRuntimeOptionsDto(
         image="pcs:test",
         replicas=4,
@@ -597,7 +598,7 @@ BUNDLE_B2 = CibResourceBundleDto(
     id="B2",
     description=None,
     member_id="R1",
-    container_type="docker",
+    container_type=CONTAINER_TYPE_DOCKER,
     container_options=CibResourceBundleContainerRuntimeOptionsDto(
         image="pcs:test",
         replicas=None,
@@ -614,7 +615,7 @@ BUNDLE_B2 = CibResourceBundleDto(
     instance_attributes=[],
 )
 
-ALL_RESOURCES = ListCibResourcesDto(
+ALL_RESOURCES = CibResourcesDto(
     primitives=[
         PRIMITIVE_R1,
         PRIMITIVE_R7,
