@@ -122,7 +122,7 @@ end
 
 class TestPcsdSettings < Test::Unit::TestCase
   def teardown()
-    FileUtils.rm(CFG_PCSD_SETTINGS, {:force => true})
+    FileUtils.rm(CFG_PCSD_SETTINGS, :force => true)
   end
 
   def test_basics()
@@ -191,7 +191,7 @@ end
 
 class TestPcsdKnownHosts < Test::Unit::TestCase
   def teardown()
-    FileUtils.rm(CFG_PCSD_KNOWN_HOSTS, {:force => true})
+    FileUtils.rm(CFG_PCSD_KNOWN_HOSTS, :force => true)
   end
 
   def test_basics()
@@ -242,7 +242,7 @@ class TestPcsdKnownHosts < Test::Unit::TestCase
   end
 end
 
-class TestConfigSyncControll < Test::Unit::TestCase
+class TestConfigSyncControl < Test::Unit::TestCase
   def setup()
     file = File.open(CFG_SYNC_CONTROL, 'w')
     file.write(JSON.pretty_generate({}))
@@ -256,7 +256,7 @@ class TestConfigSyncControll < Test::Unit::TestCase
   end
 
   def test_bad_file()
-    FileUtils.rm(CFG_SYNC_CONTROL, {:force => true})
+    FileUtils.rm(CFG_SYNC_CONTROL, :force => true)
     assert(!Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
@@ -318,20 +318,26 @@ class TestConfigSyncControll < Test::Unit::TestCase
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
 
-    assert(Cfgsync::ConfigSyncControl.sync_thread_pause(2))
+    start = Time::now().to_i
+    assert(Cfgsync::ConfigSyncControl.sync_thread_pause(10))
     assert(Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_allowed?())
-    sleep(4)
+    now = Time::now().to_i
+    # sleep for the rest of the pause time and a bit more
+    sleep(10 - (start - now) + 3)
     assert(!Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
 
-    assert(Cfgsync::ConfigSyncControl.sync_thread_pause('2'))
+    start = Time::now().to_i
+    assert(Cfgsync::ConfigSyncControl.sync_thread_pause('10'))
     assert(Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_allowed?())
-    sleep(4)
+    now = Time::now().to_i
+    # sleep for the rest of the pause time and a bit more
+    sleep(10 - (start - now) + 3)
     assert(!Cfgsync::ConfigSyncControl.sync_thread_paused?())
     assert(!Cfgsync::ConfigSyncControl.sync_thread_disabled?())
     assert(Cfgsync::ConfigSyncControl.sync_thread_allowed?())
@@ -729,7 +735,7 @@ class TestMergeKnownHosts < Test::Unit::TestCase
   end
 
   def teardown()
-    FileUtils.rm(CFG_PCSD_KNOWN_HOSTS, {:force => true})
+    FileUtils.rm(CFG_PCSD_KNOWN_HOSTS, :force => true)
   end
 
   def fixture_old_cfg()
